@@ -52,9 +52,9 @@ fail() {
 }
 runLog() {
   local o
-  o=$1 && shift && echo "$(green Running) $(yellow "$@" '>>' "$o")" && echo Running "$*" >>"$o" && "$@" >>"$o"
+  o=$1 && shift && echo "$(green Running) $(yellow "$@" '>>' "$o")" && echo Running "$@" >>"$o" && eval "$@" >>"$o"
 }
-run() { echo "$(green Running) $(yellow "$@")" && "$@"; }
+run() { echo "$(green Running) $(yellow "$@")" && eval "$@"; }
 
 currentBranch() {
   local b
