@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.client;
 
@@ -35,7 +37,7 @@ import org.apache.accumulo.core.security.Authorizations;
  * @deprecated since 2.0.0. Use {@link AccumuloClient} for writing new code. Connector is available
  *             for existing code. Use {@link #from(AccumuloClient)} as a bridge between the two.
  */
-@Deprecated
+@Deprecated(since = "2.0.0")
 public abstract class Connector {
 
   /**
@@ -85,7 +87,7 @@ public abstract class Connector {
    *             {@link #createBatchDeleter(String, Authorizations, int, BatchWriterConfig)}
    *             instead.
    */
-  @Deprecated
+  @Deprecated(since = "1.5.0")
   public abstract BatchDeleter createBatchDeleter(String tableName, Authorizations authorizations,
       int numQueryThreads, long maxMemory, long maxLatency, int maxWriteThreads)
       throws TableNotFoundException;
@@ -130,7 +132,7 @@ public abstract class Connector {
    *           when the specified table doesn't exist
    * @deprecated since 1.5.0; Use {@link #createBatchWriter(String, BatchWriterConfig)} instead.
    */
-  @Deprecated
+  @Deprecated(since = "1.5.0")
   public abstract BatchWriter createBatchWriter(String tableName, long maxMemory, long maxLatency,
       int maxWriteThreads) throws TableNotFoundException;
 
@@ -165,7 +167,7 @@ public abstract class Connector {
    * @return MultiTableBatchWriter object for configuring and writing data to
    * @deprecated since 1.5.0; Use {@link #createMultiTableBatchWriter(BatchWriterConfig)} instead.
    */
-  @Deprecated
+  @Deprecated(since = "1.5.0")
   public abstract MultiTableBatchWriter createMultiTableBatchWriter(long maxMemory, long maxLatency,
       int maxWriteThreads);
 
@@ -282,4 +284,26 @@ public abstract class Connector {
       throws AccumuloSecurityException, AccumuloException {
     return new ConnectorImpl((ClientContext) client);
   }
+
+  /**
+   * Creates a new Accumulo Client from a Connector. The returned client should be closed and
+   * closing it will not affect the Connector from which it was derived. This method is useful for
+   * cases where code written using Connector must call code written using AccumuloClient. Below is
+   * an example.
+   *
+   * <pre>
+   * <code>
+   *   Connector conn = getMyConnector();
+   *   try(AccumuloClient client = Connector.newClient(conn) {
+   *      doSomething(client);
+   *   }
+   * </code>
+   * </pre>
+   *
+   * @since 2.1.0
+   */
+  public static AccumuloClient newClient(Connector conn) {
+    return Accumulo.newClient().from(((ConnectorImpl) conn).getAccumuloClient().getProperties())
+        .build();
+  }
 }
