@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.client;
 
@@ -29,7 +31,7 @@ import org.apache.accumulo.core.client.security.tokens.PasswordToken;
  * @deprecated since 2.0.0, use {@link Accumulo#newClient()} and {@link java.util.Properties}
  *             instead
  */
-@Deprecated
+@Deprecated(since = "2.0.0")
 public interface Instance {
   /**
    * Returns the location of the tablet server that is serving the root tablet.
@@ -39,7 +41,7 @@ public interface Instance {
   String getRootTabletLocation();
 
   /**
-   * Returns the location(s) of the accumulo master and any redundant servers.
+   * Returns the location(s) of the accumulo manager and any redundant servers.
    *
    * @return a list of locations in "hostname:port" form
    */
@@ -88,7 +90,7 @@ public interface Instance {
    * @deprecated since 1.5, use {@link #getConnector(String, AuthenticationToken)} with
    *             {@link PasswordToken}
    */
-  @Deprecated
+  @Deprecated(since = "1.5.0")
   default Connector getConnector(String user, byte[] pass)
       throws AccumuloException, AccumuloSecurityException {
     return getConnector(user, new PasswordToken(pass));
@@ -109,7 +111,7 @@ public interface Instance {
    * @deprecated since 1.5, use {@link #getConnector(String, AuthenticationToken)} with
    *             {@link PasswordToken}
    */
-  @Deprecated
+  @Deprecated(since = "1.5.0")
   default Connector getConnector(String user, ByteBuffer pass)
       throws AccumuloException, AccumuloSecurityException {
     return getConnector(user, new PasswordToken(pass));
@@ -130,7 +132,7 @@ public interface Instance {
    * @deprecated since 1.5, use {@link #getConnector(String, AuthenticationToken)} with
    *             {@link PasswordToken}
    */
-  @Deprecated
+  @Deprecated(since = "1.5.0")
   default Connector getConnector(String user, CharSequence pass)
       throws AccumuloException, AccumuloSecurityException {
     return getConnector(user, new PasswordToken(pass));
