@@ -1,23 +1,26 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.client.admin;
 
 import static com.google.common.base.Preconditions.checkArgument;
 import static java.util.Objects.requireNonNull;
+import static java.util.concurrent.TimeUnit.MILLISECONDS;
 
 import java.util.concurrent.TimeUnit;
 
@@ -32,7 +35,7 @@ public class DelegationTokenConfig {
   private long lifetime = 0;
 
   /**
-   * Requests a specific lifetime for the token that is different than the default system lifetime.
+   * Requests a specific lifetime for the token that is different from the default system lifetime.
    * The lifetime must not exceed the secret key lifetime configured on the servers.
    *
    * @param lifetime
@@ -44,7 +47,7 @@ public class DelegationTokenConfig {
   public DelegationTokenConfig setTokenLifetime(long lifetime, TimeUnit unit) {
     checkArgument(lifetime >= 0, "Lifetime must be non-negative");
     requireNonNull(unit, "TimeUnit was null");
-    this.lifetime = TimeUnit.MILLISECONDS.convert(lifetime, unit);
+    this.lifetime = MILLISECONDS.convert(lifetime, unit);
     return this;
   }
 
@@ -58,7 +61,7 @@ public class DelegationTokenConfig {
    */
   public long getTokenLifetime(TimeUnit unit) {
     requireNonNull(unit);
-    return unit.convert(lifetime, TimeUnit.MILLISECONDS);
+    return unit.convert(lifetime, MILLISECONDS);
   }
 
   @Override
