@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.client.admin;
 
@@ -20,6 +22,7 @@ import java.util.EnumSet;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.SortedSet;
+import java.util.function.Consumer;
 
 import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
@@ -167,6 +170,32 @@ public interface NamespaceOperations {
   void setProperty(String namespace, String property, String value)
       throws AccumuloException, AccumuloSecurityException, NamespaceNotFoundException;
 
+  /**
+   * For a detailed overview of the behavior of this method see
+   * {@link InstanceOperations#modifyProperties(Consumer)} which operates on a different layer of
+   * properties but has the same behavior and better documentation.
+   *
+   * <p>
+   * Accumulo has multiple layers of properties that for many APIs and SPIs are presented as a
+   * single merged view. This API does not offer that merged view, it only offers the properties set
+   * at this namespace's layer to the mapMutator.
+   * </p>
+   *
+   * @param mapMutator
+   *          This consumer should modify the passed in snapshot of namespace properties to contain
+   *          the desired keys and values. It should be safe for Accumulo to call this consumer
+   *          multiple times, this may be done automatically when certain retryable errors happen.
+   *          The consumer should probably avoid accessing the Accumulo client as that could lead to
+   *          undefined behavior.
+   *
+   * @return The map that became Accumulo's new properties for this namespace. This map is immutable
+   *         and contains the snapshot passed to mapMutator and the changes made by mapMutator.
+   *
+   * @since 2.1.0
+   */
+  Map<String,String> modifyProperties(String namespace, Consumer<Map<String,String>> mapMutator)
+      throws AccumuloException, AccumuloSecurityException, NamespaceNotFoundException;
+
   /**
    * Removes a property from a namespace. Note that it may take a few seconds to propagate the
    * change everywhere.
@@ -188,7 +217,8 @@ public interface NamespaceOperations {
 
   /**
    * Gets properties of a namespace, which are inherited by tables in this namespace. Note that
-   * recently changed properties may not be available immediately.
+   * recently changed properties may not be available immediately. Method calls
+   * {@link #getConfiguration(String)} and then calls .entrySet() on the map.
    *
    * @param namespace
    *          the name of the namespace
@@ -202,7 +232,48 @@ public interface NamespaceOperations {
    *           if the specified namespace doesn't exist
    * @since 1.6.0
    */
-  Iterable<Entry<String,String>> getProperties(String namespace)
+  default Iterable<Entry<String,String>> getProperties(String namespace)
+      throws AccumuloException, AccumuloSecurityException, NamespaceNotFoundException {
+    return getConfiguration(namespace).entrySet();
+  }
+
+  /**
+   * Gets properties of a namespace, which are inherited by tables in this namespace. Note that
+   * recently changed properties may not be available immediately. This new method returns a Map
+   * instead of an Iterable.
+   *
+   * @param namespace
+   *          the name of the namespace
+   * @return all properties visible by this namespace (system and per-table properties). Note that
+   *         recently changed properties may not be visible immediately.
+   * @throws AccumuloException
+   *           if a general error occurs
+   * @throws AccumuloSecurityException
+   *           if the user does not have permission
+   * @throws NamespaceNotFoundException
+   *           if the specified namespace doesn't exist
+   * @since 2.1.0
+   */
+  Map<String,String> getConfiguration(String namespace)
+      throws AccumuloException, AccumuloSecurityException, NamespaceNotFoundException;
+
+  /**
+   * Gets properties specific to this namespace. Note that recently changed properties may not be
+   * available immediately. This new method returns a Map instead of an Iterable.
+   *
+   * @param namespace
+   *          the name of the namespace
+   * @return per-table properties specific to this namespace. Note that recently changed properties
+   *         may not be visible immediately.
+   * @throws AccumuloException
+   *           if a general error occurs
+   * @throws AccumuloSecurityException
+   *           if the user does not have permission
+   * @throws NamespaceNotFoundException
+   *           if the specified namespace doesn't exist
+   * @since 2.1.0
+   */
+  Map<String,String> getNamespaceProperties(String namespace)
       throws AccumuloException, AccumuloSecurityException, NamespaceNotFoundException;
 
   /**
