@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.client.admin;
 
@@ -25,6 +27,7 @@ import java.util.Map.Entry;
 import java.util.Set;
 import java.util.SortedSet;
 import java.util.concurrent.Executor;
+import java.util.function.Consumer;
 import java.util.function.Predicate;
 
 import org.apache.accumulo.core.client.AccumuloException;
@@ -103,7 +106,7 @@ public interface TableOperations {
    *           if the table already exists
    * @deprecated since 1.7.0; use {@link #create(String, NewTableConfiguration)} instead.
    */
-  @Deprecated
+  @Deprecated(since = "1.7.0")
   default void create(String tableName, boolean limitVersion)
       throws AccumuloException, AccumuloSecurityException, TableExistsException {
     if (limitVersion)
@@ -128,7 +131,7 @@ public interface TableOperations {
    *           if the table already exists
    * @deprecated since 1.7.0; use {@link #create(String, NewTableConfiguration)} instead.
    */
-  @Deprecated
+  @Deprecated(since = "1.7.0")
   default void create(String tableName, boolean versioningIter, TimeType timeType)
       throws AccumuloException, AccumuloSecurityException, TableExistsException {
     NewTableConfiguration ntc = new NewTableConfiguration().setTimeType(timeType);
@@ -175,10 +178,29 @@ public interface TableOperations {
    * @param tableName
    *          Name of a table to create and import into.
    * @param importDir
-   *          Directory that contains the files copied by distcp from exportTable
+   *          A directory containing the files copied by distcp from exportTable
    * @since 1.5.0
+   *
    */
-  void importTable(String tableName, String importDir)
+  default void importTable(String tableName, String importDir)
+      throws TableExistsException, AccumuloException, AccumuloSecurityException {
+    importTable(tableName, Set.of(importDir), ImportConfiguration.empty());
+  }
+
+  /**
+   * Imports a table exported via {@link #exportTable(String, String)} and then copied via hadoop
+   * distcp.
+   *
+   * @param tableName
+   *          Name of a table to create and import into.
+   * @param ic
+   *          ImportConfiguration for the table being created. If no configuration is needed pass
+   *          {@link ImportConfiguration#empty}
+   * @param importDirs
+   *          A set of directories containing the files copied by distcp from exportTable
+   * @since 2.1.0
+   */
+  void importTable(String tableName, Set<String> importDirs, ImportConfiguration ic)
       throws TableExistsException, AccumuloException, AccumuloSecurityException;
 
   /**
@@ -187,7 +209,8 @@ public interface TableOperations {
    * To avoid losing access to a table it can be cloned and the clone taken offline for export.
    *
    * <p>
-   * See https://github.com/apache/accumulo-examples/blob/master/docs/export.md
+   * See the <a href="https://github.com/apache/accumulo-examples/blob/main/docs/export.md">export
+   * example</a>
    *
    * @param tableName
    *          Name of the table to export.
@@ -240,7 +263,7 @@ public interface TableOperations {
    *           if the table does not exist
    * @deprecated since 1.5.0; use {@link #listSplits(String)} instead.
    */
-  @Deprecated
+  @Deprecated(since = "1.5.0")
   default Collection<Text> getSplits(String tableName) throws TableNotFoundException {
     try {
       return listSplits(tableName);
@@ -273,7 +296,7 @@ public interface TableOperations {
    *         fewer splits so as not to exceed maxSplits
    * @deprecated since 1.5.0; use {@link #listSplits(String, int)} instead.
    */
-  @Deprecated
+  @Deprecated(since = "1.5.0")
   default Collection<Text> getSplits(String tableName, int maxSplits)
       throws TableNotFoundException {
     try {
@@ -406,12 +429,24 @@ public interface TableOperations {
 
   /**
    * Starts a full major compaction of the tablets in the range (start, end]. If the config does not
-   * specify a compaction strategy, then all files in a tablet are compacted. The compaction is
-   * performed even for tablets that have only one file.
+   * specify a compaction selector (or a deprecated strategy), then all files in a tablet are
+   * compacted. The compaction is performed even for tablets that have only one file.
    *
    * <p>
-   * Only one compact call at a time can pass iterators and/or a compaction strategy. If two threads
-   * call compaction with iterators and/or a compaction strategy, then one will fail.
+   * The following optional settings can only be set by one compact call per table at the same time.
+   *
+   * <ul>
+   * <li>Execution hints : {@link CompactionConfig#setExecutionHints(Map)}</li>
+   * <li>Selector : {@link CompactionConfig#setSelector(PluginConfig)}</li>
+   * <li>Configurer : {@link CompactionConfig#setConfigurer(PluginConfig)}</li>
+   * <li>Iterators : {@link CompactionConfig#setIterators(List)}</li>
+   * <li>Compaction strategy (deprecated) :
+   * {@code CompactionConfig.setCompactionStrategy(CompactionStrategyConfig)}</li>
+   * </ul>
+   *
+   * <p>
+   * If two threads call this method concurrently for the same table and set one or more of the
+   * above then one thread will fail.
    *
    * @param tableName
    *          the table to compact
@@ -481,6 +516,26 @@ public interface TableOperations {
       Map<String,String> propertiesToSet, Set<String> propertiesToExclude) throws AccumuloException,
       AccumuloSecurityException, TableNotFoundException, TableExistsException;
 
+  /**
+   * Clone a table from an existing table. The cloned table will have the same data as the source
+   * table it was created from. After cloning, the two tables can mutate independently. Initially
+   * the cloned table should not use any extra space, however as the source table and cloned table
+   * major compact extra space will be used by the clone.
+   *
+   * Initially the cloned table is only readable and writable by the user who created it.
+   *
+   * @param srcTableName
+   *          the table to clone
+   * @param newTableName
+   *          the name of the clone
+   * @param config
+   *          the clone command configuration
+   * @since 1.10 and 2.1
+   */
+  void clone(String srcTableName, String newTableName, CloneConfiguration config)
+      throws AccumuloException, AccumuloSecurityException, TableNotFoundException,
+      TableExistsException;
+
   /**
    * Rename a table
    *
@@ -550,6 +605,39 @@ public interface TableOperations {
   void setProperty(String tableName, String property, String value)
       throws AccumuloException, AccumuloSecurityException;
 
+  /**
+   *
+   * For a detailed overview of the behavior of this method see
+   * {@link InstanceOperations#modifyProperties(Consumer)} which operates on a different layer of
+   * properties but has the same behavior and better documentation.
+   *
+   * <p>
+   * Accumulo has multiple layers of properties that for many APIs and SPIs are presented as a
+   * single merged view. This API does not offer that merged view, it only offers the properties set
+   * at this table's layer to the mapMutator.
+   * </p>
+   *
+   * @param mapMutator
+   *          This consumer should modify the passed in snapshot of table properties contain the
+   *          desired keys and values. It should be safe for Accumulo to call this consumer multiple
+   *          times, this may be done automatically when certain retryable errors happen. The
+   *          consumer should probably avoid accessing the Accumulo client as that could lead to
+   *          undefined behavior.
+   *
+   * @return The map that became Accumulo's new properties for this table. This map is immutable and
+   *         contains the snapshot passed to mapMutator and the changes made by mapMutator.
+   *
+   * @throws AccumuloException
+   *           if a general error occurs
+   * @throws AccumuloSecurityException
+   *           if the user does not have permission
+   * @throws IllegalArgumentException
+   *           if the Consumer alters the map by adding properties that cannot be stored
+   * @since 2.1.0
+   */
+  Map<String,String> modifyProperties(String tableName, Consumer<Map<String,String>> mapMutator)
+      throws AccumuloException, AccumuloSecurityException, IllegalArgumentException;
+
   /**
    * Removes a property from a table. This operation is asynchronous and eventually consistent. Not
    * all tablets in a table will acknowledge this altered value immediately nor at the same time.
@@ -572,7 +660,8 @@ public interface TableOperations {
    * Gets properties of a table. This operation is asynchronous and eventually consistent. It is not
    * guaranteed that all tablets in a table will return the same values. Within a few seconds
    * without another change, all tablets in a table should be consistent. The clone table feature
-   * can be used if consistency is required.
+   * can be used if consistency is required. Method calls {@link #getConfiguration(String)} and then
+   * calls .entrySet() on the map.
    *
    * @param tableName
    *          the name of the table
@@ -580,8 +669,45 @@ public interface TableOperations {
    *         recently changed properties may not be visible immediately.
    * @throws TableNotFoundException
    *           if the table does not exist
+   * @since 1.6.0
    */
-  Iterable<Entry<String,String>> getProperties(String tableName)
+  default Iterable<Entry<String,String>> getProperties(String tableName)
+      throws AccumuloException, TableNotFoundException {
+    return getConfiguration(tableName).entrySet();
+  }
+
+  /**
+   * Gets properties of a table. This operation is asynchronous and eventually consistent. It is not
+   * guaranteed that all tablets in a table will return the same values. Within a few seconds
+   * without another change, all tablets in a table should be consistent. The clone table feature
+   * can be used if consistency is required. This new method returns a Map instead of an Iterable.
+   *
+   * @param tableName
+   *          the name of the table
+   * @return all properties visible by this table (system and per-table properties). Note that
+   *         recently changed properties may not be visible immediately.
+   * @throws TableNotFoundException
+   *           if the table does not exist
+   * @since 2.1.0
+   */
+  Map<String,String> getConfiguration(String tableName)
+      throws AccumuloException, TableNotFoundException;
+
+  /**
+   * Gets per-table properties of a table. This operation is asynchronous and eventually consistent.
+   * It is not guaranteed that all tablets in a table will return the same values. Within a few
+   * seconds without another change, all tablets in a table should be consistent. The clone table
+   * feature can be used if consistency is required.
+   *
+   * @param tableName
+   *          the name of the table
+   * @return per-table properties visible by this table. Note that recently changed properties may
+   *         not be visible immediately.
+   * @throws TableNotFoundException
+   *           if the table does not exist
+   * @since 2.1.0
+   */
+  Map<String,String> getTableProperties(String tableName)
       throws AccumuloException, TableNotFoundException;
 
   /**
@@ -637,7 +763,7 @@ public interface TableOperations {
 
   /**
    * Bulk import all the files in a directory into a table. Files can be created using
-   * {@code AccumuloFileOutputFormat} and {@link RFile#newWriter()}
+   * {@link RFile#newWriter()}
    *
    * @param tableName
    *          the name of the table
@@ -659,7 +785,7 @@ public interface TableOperations {
    *
    * @deprecated since 2.0.0 use {@link #importDirectory(String)} instead.
    */
-  @Deprecated
+  @Deprecated(since = "2.0.0")
   void importDirectory(String tableName, String dir, String failureDir, boolean setTime)
       throws TableNotFoundException, IOException, AccumuloException, AccumuloSecurityException;
 
@@ -679,6 +805,13 @@ public interface TableOperations {
      */
     ImportMappingOptions tableTime(boolean value);
 
+    /**
+     * Ignores empty bulk import source directory, rather than throwing an IllegalArgumentException.
+     *
+     * @since 2.1.0
+     */
+    ImportMappingOptions ignoreEmptyDir(boolean ignore);
+
     /**
      * Loads the files into the table.
      */
@@ -697,7 +830,7 @@ public interface TableOperations {
      * This is the default number of threads used to determine where to load files. A suffix of
      * {@code C} means to multiply by the number of cores.
      */
-    public static final String BULK_LOAD_THREADS_DEFAULT = "8C";
+    String BULK_LOAD_THREADS_DEFAULT = "8C";
 
     /**
      * Load files in the directory to the row ranges specified in the plan. The plan should contain
@@ -747,7 +880,7 @@ public interface TableOperations {
 
   /**
    * Bulk import the files in a directory into a table. Files can be created using
-   * {@code AccumuloFileOutputFormat} and {@link RFile#newWriter()}.
+   * {@link RFile#newWriter()}.
    * <p>
    * This new method of bulk import examines files in the current process outside of holding a table
    * lock. The old bulk import method ({@link #importDirectory(String, String, String, boolean)})
@@ -824,6 +957,22 @@ public interface TableOperations {
   void online(String tableName, boolean wait)
       throws AccumuloSecurityException, AccumuloException, TableNotFoundException;
 
+  /**
+   * Check if a table is online through its current goal state only. Could run into issues if the
+   * current state of the table is in between states. If you require a specific state, call
+   * <code>online(tableName, true)</code> or <code>offline(tableName, true)</code>, this will wait
+   * until the table reaches the desired state before proceeding.
+   *
+   * @param tableName
+   *          the table to check if online
+   * @throws AccumuloException
+   *           when there is a general accumulo error
+   * @return true if table's goal state is online
+   *
+   * @since 2.1.0
+   */
+  boolean isOnline(String tableName) throws AccumuloException, TableNotFoundException;
+
   /**
    * Clears the tablet locator cache for a specified table
    *
@@ -978,11 +1127,21 @@ public interface TableOperations {
       throws AccumuloException, TableNotFoundException;
 
   /**
-   * Gets the number of bytes being used in the files for a set of tables
+   * Gets the number of bytes being used by the files for a set of tables. This operation will scan
+   * the metadata table for file size information to compute the size metrics for the tables.
+   *
+   * Because the metadata table is used for computing usage and not the actual files in HDFS the
+   * results will be an estimate. Older entries may exist with no file metadata (resulting in size
+   * 0) and other actions in the cluster can impact the estimated size such as flushes, tablet
+   * splits, compactions, etc.
+   *
+   * For more accurate information a compaction should first be run on all files for the set of
+   * tables being computed.
    *
    * @param tables
    *          a set of tables
-   * @return a list of disk usage objects containing linked table names and sizes
+   * @return a list of disk usage objects containing linked table names and sizes set of tables to
+   *         compute usage across
    * @since 1.6.0
    */
   List<DiskUsage> getDiskUsage(Set<String> tables)
@@ -1105,4 +1264,17 @@ public interface TableOperations {
       throws AccumuloException, TableNotFoundException {
     throw new UnsupportedOperationException();
   }
+
+  /**
+   * Return the TimeType for the given table
+   *
+   * @param tableName
+   *          The name of table to query
+   * @return the TimeType of the supplied table, representing either Logical or Milliseconds
+   * @since 2.1.0
+   */
+  default TimeType getTimeType(String tableName) throws TableNotFoundException {
+    throw new UnsupportedOperationException();
+  }
+
 }
