@@ -1,22 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
-
 package org.apache.accumulo.core.client.rfile;
 
+import static com.google.common.base.Preconditions.checkArgument;
+
 import java.io.IOException;
 import java.io.OutputStream;
 import java.util.Collections;
@@ -24,20 +27,26 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Objects;
+import java.util.stream.Stream;
 
 import org.apache.accumulo.core.client.rfile.RFile.WriterFSOptions;
 import org.apache.accumulo.core.client.rfile.RFile.WriterOptions;
 import org.apache.accumulo.core.client.sample.SamplerConfiguration;
+import org.apache.accumulo.core.client.summary.SummarizerConfiguration;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
+import org.apache.accumulo.core.conf.DefaultConfiguration;
+import org.apache.accumulo.core.crypto.CryptoFactoryLoader;
 import org.apache.accumulo.core.file.FileOperations;
+import org.apache.accumulo.core.metadata.ValidationUtil;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
+import org.apache.accumulo.core.spi.crypto.CryptoEnvironment;
+import org.apache.accumulo.core.spi.crypto.CryptoService;
 import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 
 import com.google.common.base.Preconditions;
-import com.google.common.collect.Iterables;
 
 class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions {
 
@@ -59,32 +68,44 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
   }
 
   private OutputArgs out;
-  private SamplerConfiguration sampler = null;
   private Map<String,String> tableConfig = Collections.emptyMap();
   private int visCacheSize = 1000;
+  private Map<String,String> samplerProps = Collections.emptyMap();
+  private Map<String,String> summarizerProps = Collections.emptyMap();
+
+  private void checkDisjoint(Map<String,String> props, Map<String,String> derivedProps,
+      String kind) {
+    checkArgument(Collections.disjoint(props.keySet(), derivedProps.keySet()),
+        "Properties and derived %s properties are not disjoint", kind);
+  }
 
   @Override
   public WriterOptions withSampler(SamplerConfiguration samplerConf) {
     Objects.requireNonNull(samplerConf);
-    SamplerConfigurationImpl.checkDisjoint(tableConfig, samplerConf);
-    this.sampler = samplerConf;
+    Map<String,String> tmp = new SamplerConfigurationImpl(samplerConf).toTablePropertiesMap();
+    checkDisjoint(tableConfig, tmp, "sampler");
+    this.samplerProps = tmp;
     return this;
   }
 
   @Override
   public RFileWriter build() throws IOException {
     FileOperations fileops = FileOperations.getInstance();
-    AccumuloConfiguration acuconf = AccumuloConfiguration.getDefaultConfiguration();
+    AccumuloConfiguration acuconf = DefaultConfiguration.getInstance();
     HashMap<String,String> userProps = new HashMap<>();
-    if (sampler != null) {
-      userProps.putAll(new SamplerConfigurationImpl(sampler).toTablePropertiesMap());
-    }
-    userProps.putAll(tableConfig);
 
-    if (userProps.size() > 0) {
-      acuconf = new ConfigurationCopy(Iterables.concat(acuconf, userProps.entrySet()));
+    userProps.putAll(tableConfig);
+    userProps.putAll(summarizerProps);
+    userProps.putAll(samplerProps);
+
+    if (!userProps.isEmpty()) {
+      acuconf =
+          new ConfigurationCopy(Stream.concat(acuconf.stream(), userProps.entrySet().stream()));
     }
 
+    CryptoService cs =
+        CryptoFactoryLoader.getServiceForClient(CryptoEnvironment.Scope.TABLE, tableConfig);
+
     if (out.getOutputStream() != null) {
       FSDataOutputStream fsdo;
       if (out.getOutputStream() instanceof FSDataOutputStream) {
@@ -92,12 +113,14 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
       } else {
         fsdo = new FSDataOutputStream(out.getOutputStream(), new FileSystem.Statistics("foo"));
       }
-      return new RFileWriter(fileops.newWriterBuilder().forOutputStream(".rf", fsdo, out.getConf())
-          .withTableConfiguration(acuconf).build(), visCacheSize);
+      return new RFileWriter(
+          fileops.newWriterBuilder().forOutputStream(".rf", fsdo, out.getConf(), cs)
+              .withTableConfiguration(acuconf).withStartDisabled().build(),
+          visCacheSize);
     } else {
       return new RFileWriter(fileops.newWriterBuilder()
-          .forFile(out.path.toString(), out.getFileSystem(), out.getConf())
-          .withTableConfiguration(acuconf).build(), visCacheSize);
+          .forFile(out.path.toString(), out.getFileSystem(), out.getConf(), cs)
+          .withTableConfiguration(acuconf).withStartDisabled().build(), visCacheSize);
     }
   }
 
@@ -110,11 +133,7 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
 
   @Override
   public WriterFSOptions to(String filename) {
-    Objects.requireNonNull(filename);
-    if (!filename.endsWith(".rf")) {
-      throw new IllegalArgumentException(
-          "Provided filename (" + filename + ") does not end with '.rf'");
-    }
+    ValidationUtil.validateRFileName(filename);
     this.out = new OutputArgs(filename);
     return this;
   }
@@ -134,7 +153,8 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
       cfg.put(entry.getKey(), entry.getValue());
     }
 
-    SamplerConfigurationImpl.checkDisjoint(cfg, sampler);
+    checkDisjoint(cfg, samplerProps, "sampler");
+    checkDisjoint(cfg, summarizerProps, "summarizer");
     this.tableConfig = cfg;
     return this;
   }
@@ -151,4 +171,13 @@ class RFileWriterBuilder implements RFile.OutputArguments, RFile.WriterFSOptions
     this.visCacheSize = maxSize;
     return this;
   }
+
+  @Override
+  public WriterOptions withSummarizers(SummarizerConfiguration... summarizerConf) {
+    Objects.requireNonNull(summarizerConf);
+    Map<String,String> tmp = SummarizerConfiguration.toTableProperties(summarizerConf);
+    checkDisjoint(tableConfig, tmp, "summarizer");
+    this.summarizerProps = tmp;
+    return this;
+  }
 }
