@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.client.security.tokens;
 
@@ -63,7 +65,7 @@ public interface AuthenticationToken extends Writable, Destroyable, Cloneable {
         byte[] tokenBytes) {
       T type = null;
       try {
-        type = tokenType.newInstance();
+        type = tokenType.getDeclaredConstructor().newInstance();
       } catch (Exception e) {
         throw new IllegalArgumentException("Cannot instantiate " + tokenType.getName(), e);
       }
@@ -92,16 +94,13 @@ public interface AuthenticationToken extends Writable, Destroyable, Cloneable {
      * @see #serialize(AuthenticationToken)
      */
     public static AuthenticationToken deserialize(String tokenClassName, byte[] tokenBytes) {
-      Class<? extends AuthenticationToken> tokenType = null;
       try {
         @SuppressWarnings("unchecked")
-        Class<? extends AuthenticationToken> tmpTokenType =
-            (Class<? extends AuthenticationToken>) Class.forName(tokenClassName);
-        tokenType = tmpTokenType;
+        var tokenType = (Class<? extends AuthenticationToken>) Class.forName(tokenClassName);
+        return deserialize(tokenType, tokenBytes);
       } catch (ClassNotFoundException e) {
         throw new IllegalArgumentException("Class not available " + tokenClassName, e);
       }
-      return deserialize(tokenType, tokenBytes);
     }
 
     /**
@@ -116,20 +115,12 @@ public interface AuthenticationToken extends Writable, Destroyable, Cloneable {
      * @see #deserialize(Class, byte[])
      */
     public static byte[] serialize(AuthenticationToken token) {
-      ByteArrayOutputStream baos = new ByteArrayOutputStream();
-      DataOutputStream out = new DataOutputStream(baos);
-      try {
+      try (var baos = new ByteArrayOutputStream(); var out = new DataOutputStream(baos)) {
         token.write(out);
+        return baos.toByteArray();
       } catch (IOException e) {
         throw new RuntimeException("Bug found in serialization code", e);
       }
-      byte[] bytes = baos.toByteArray();
-      try {
-        out.close();
-      } catch (IOException e) {
-        throw new IllegalStateException("Shouldn't happen with ByteArrayOutputStream", e);
-      }
-      return bytes;
     }
   }
 
