@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.conf;
 
@@ -21,6 +23,7 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.function.Predicate;
+import java.util.stream.Stream;
 
 /**
  * An {@link AccumuloConfiguration} which holds a flat copy of properties defined in another
@@ -40,6 +43,16 @@ public class ConfigurationCopy extends AccumuloConfiguration {
     this(config.entrySet());
   }
 
+  /**
+   * Creates a new configuration.
+   *
+   * @param config
+   *          configuration property stream to use for copying
+   */
+  public ConfigurationCopy(Stream<Entry<String,String>> config) {
+    this(config::iterator);
+  }
+
   /**
    * Creates a new configuration.
    *
@@ -47,9 +60,7 @@ public class ConfigurationCopy extends AccumuloConfiguration {
    *          configuration property iterable to use for copying
    */
   public ConfigurationCopy(Iterable<Entry<String,String>> config) {
-    for (Entry<String,String> entry : config) {
-      copy.put(entry.getKey(), entry.getValue());
-    }
+    config.forEach(e -> copy.put(e.getKey(), e.getValue()));
   }
 
   /**
@@ -109,4 +120,9 @@ public class ConfigurationCopy extends AccumuloConfiguration {
       return updateCount;
     }
   }
+
+  @Override
+  public boolean isPropertySet(Property prop) {
+    return copy.containsKey(prop.getKey());
+  }
 }
