@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.conf;
 
@@ -24,8 +26,9 @@ import java.util.function.Function;
 import java.util.function.Predicate;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
+import java.util.stream.IntStream;
+import java.util.stream.Stream;
 
-import org.apache.accumulo.core.util.Pair;
 import org.apache.commons.lang3.Range;
 import org.apache.hadoop.fs.Path;
 
@@ -42,8 +45,8 @@ public enum PropertyType {
       "A non-negative integer optionally followed by a unit of time (whitespace"
           + " disallowed), as in 30s.\n"
           + "If no unit of time is specified, seconds are assumed. Valid units"
-          + " are 'ms', 's', 'm', 'h' for milliseconds, seconds," + " minutes, and" + " hours.\n"
-          + "Examples of valid durations are '600', '30s', '45m', '30000ms'," + " '3d', and '1h'.\n"
+          + " are 'ms', 's', 'm', 'h' for milliseconds, seconds, minutes, and hours.\n"
+          + "Examples of valid durations are '600', '30s', '45m', '30000ms', '3d', and '1h'.\n"
           + "Examples of invalid durations are '1w', '1h30m', '1s 200ms', 'ms', '',"
           + " and 'a'.\nUnless otherwise stated, the max value for the duration"
           + " represented in milliseconds is " + Long.MAX_VALUE),
@@ -64,7 +67,7 @@ public enum PropertyType {
           + "If a percentage is specified, memory will be a percentage of the"
           + " max memory allocated to a Java process (set by the JVM option -Xmx).\n"
           + "If no unit is specified, bytes are assumed. Valid units are 'B',"
-          + " 'K', 'M', 'G', '%' for bytes, kilobytes, megabytes, gigabytes, and" + " percentage.\n"
+          + " 'K', 'M', 'G', '%' for bytes, kilobytes, megabytes, gigabytes, and percentage.\n"
           + "Examples of valid memories are '1024', '20B', '100K', '1500M', '2G', '20%'.\n"
           + "Examples of invalid memories are '1M500K', '1M 2K', '1MB', '1.5G',"
           + " '1,024K', '', and 'a'.\n"
@@ -79,8 +82,9 @@ public enum PropertyType {
           + " 'localhost:2000,www.example.com,10.10.1.1:500' and 'localhost'.\n"
           + "Examples of invalid host lists are '', ':1000', and 'localhost:80000'"),
 
-  @SuppressWarnings("unchecked")
-  PORT("port", or(new Bounds(1024, 65535), in(true, "0"), new PortRange("\\d{4,5}-\\d{4,5}")),
+  PORT("port",
+      x -> Stream.of(new Bounds(1024, 65535), in(true, "0"), new PortRange("\\d{4,5}-\\d{4,5}"))
+          .anyMatch(y -> y.test(x)),
       "An positive integer in the range 1024-65535 (not already in use or"
           + " specified elsewhere in the configuration),\n"
           + "zero to indicate any open ephemeral port, or a range of positive"
@@ -94,7 +98,7 @@ public enum PropertyType {
           + " suffixed with the '%' character, a percentage.\n"
           + "Examples of valid fractions/percentages are '10', '1000%', '0.05',"
           + " '5%', '0.2%', '0.0005'.\n"
-          + "Examples of invalid fractions/percentages are '', '10 percent'," + " 'Hulk Hogan'"),
+          + "Examples of invalid fractions/percentages are '', '10 percent', 'Hulk Hogan'"),
 
   PATH("path", x -> true,
       "A string that represents a filesystem path, which can be either relative"
@@ -103,11 +107,12 @@ public enum PropertyType {
           + "config file using '${env:ACCUMULO_HOME}' or similar."),
 
   // VFS_CLASSLOADER_CACHE_DIR's default value is a special case, for documentation purposes
+  @SuppressWarnings("removal")
   ABSOLUTEPATH("absolute path",
       x -> x == null || x.trim().isEmpty() || new Path(x.trim()).isAbsolute()
           || x.equals(Property.VFS_CLASSLOADER_CACHE_DIR.getDefaultValue()),
       "An absolute filesystem path. The filesystem depends on the property."
-          + " This is the same as path, but enforces that its root is explicitly" + " specified."),
+          + " This is the same as path, but enforces that its root is explicitly specified."),
 
   CLASSNAME("java class", new Matches("[\\w$.]*"),
       "A fully qualified java class name representing a class on the classpath.\n"
@@ -120,6 +125,9 @@ public enum PropertyType {
   DURABILITY("durability", in(false, null, "default", "none", "log", "flush", "sync"),
       "One of 'none', 'log', 'flush' or 'sync'."),
 
+  GC_POST_ACTION("gc_post_action", in(true, null, "none", "flush", "compact"),
+      "One of 'none', 'flush', or 'compact'."),
+
   STRING("string", x -> true,
       "An arbitrary string of characters whose format is unspecified and"
           + " interpreted based on the context of the property to which it applies."),
@@ -170,11 +178,6 @@ public enum PropertyType {
     return predicate.test(value);
   }
 
-  @SuppressWarnings("unchecked")
-  private static Predicate<String> or(final Predicate<String>... others) {
-    return (x) -> Arrays.stream(others).anyMatch(y -> y.test(x));
-  }
-
   private static Predicate<String> in(final boolean caseSensitive, final String... allowedSet) {
     if (caseSensitive) {
       return x -> Arrays.stream(allowedSet)
@@ -228,7 +231,7 @@ public enum PropertyType {
       }
       try {
         double d;
-        if (input.length() > 0 && input.charAt(input.length() - 1) == '%') {
+        if (!input.isEmpty() && input.charAt(input.length() - 1) == '%') {
           d = Double.parseDouble(input.substring(0, input.length() - 1));
         } else {
           d = Double.parseDouble(input);
@@ -307,7 +310,7 @@ public enum PropertyType {
 
   public static class PortRange extends Matches {
 
-    private static final Range<Integer> VALID_RANGE = Range.between(1024, 65535);
+    public static final Range<Integer> VALID_RANGE = Range.between(1024, 65535);
 
     public PortRange(final String pattern) {
       super(pattern);
@@ -327,7 +330,7 @@ public enum PropertyType {
       }
     }
 
-    public static Pair<Integer,Integer> parse(String portRange) {
+    public static IntStream parse(String portRange) {
       int idx = portRange.indexOf('-');
       if (idx != -1) {
         int low = Integer.parseInt(portRange.substring(0, idx));
@@ -336,7 +339,7 @@ public enum PropertyType {
           throw new IllegalArgumentException(
               "Invalid port range specified, only 1024 to 65535 supported.");
         }
-        return new Pair<>(low, high);
+        return IntStream.rangeClosed(low, high);
       }
       throw new IllegalArgumentException(
           "Invalid port range specification, must use M-N notation.");
