@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.data;
 
@@ -25,7 +27,7 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 
-import org.apache.accumulo.core.data.thrift.TRange;
+import org.apache.accumulo.core.dataImpl.thrift.TRange;
 import org.apache.hadoop.io.Text;
 import org.apache.hadoop.io.WritableComparable;
 
@@ -147,7 +149,7 @@ public class Range implements WritableComparable<Range> {
    * @param endRow
    *          ending row; set to null for positive infinity
    * @param endRowInclusive
-   *          true to include end row, false to skip
+   *          true to include start row, false to skip
    * @throws IllegalArgumentException
    *           if end row is before start row
    */
@@ -167,7 +169,7 @@ public class Range implements WritableComparable<Range> {
    * @param endKey
    *          ending key; set to null for positive infinity
    * @param endKeyInclusive
-   *          true to include end key, false to skip
+   *          true to include start key, false to skip
    * @throws IllegalArgumentException
    *           if end key is before start key
    */
@@ -301,7 +303,7 @@ public class Range implements WritableComparable<Range> {
   }
 
   /**
-   * Implements logic of {@link #beforeStartKey(Key)}, but in a private method, so that it can be
+   * Implements logic of {@code #beforeStartKey(Key)}, but in a private method, so that it can be
    * safely used by constructors if a subclass overrides that {@link #beforeStartKey(Key)}
    */
   private boolean beforeStartKeyImpl(Key key) {
@@ -449,7 +451,7 @@ public class Range implements WritableComparable<Range> {
    * @return list of merged ranges
    */
   public static List<Range> mergeOverlapping(Collection<Range> ranges) {
-    if (ranges.size() == 0)
+    if (ranges.isEmpty())
       return Collections.emptyList();
     if (ranges.size() == 1)
       return Collections.singletonList(ranges.iterator().next());
@@ -481,10 +483,8 @@ public class Range implements WritableComparable<Range> {
         startKeysEqual = true;
       } else if (currentRange.infiniteStartKey) {
         startKeysEqual = false;
-      } else if (currentRange.start.equals(range.start)) {
-        startKeysEqual = true;
       } else {
-        startKeysEqual = false;
+        startKeysEqual = currentRange.start.equals(range.start);
       }
 
       if (startKeysEqual || currentRange.contains(range.start) || (!currentRange.stopKeyInclusive
@@ -684,18 +684,18 @@ public class Range implements WritableComparable<Range> {
   public void readFields(DataInput in) throws IOException {
     infiniteStartKey = in.readBoolean();
     infiniteStopKey = in.readBoolean();
-    if (!infiniteStartKey) {
+    if (infiniteStartKey) {
+      start = null;
+    } else {
       start = new Key();
       start.readFields(in);
-    } else {
-      start = null;
     }
 
-    if (!infiniteStopKey) {
+    if (infiniteStopKey) {
+      stop = null;
+    } else {
       stop = new Key();
       stop.readFields(in);
-    } else {
-      stop = null;
     }
 
     startKeyInclusive = in.readBoolean();
@@ -780,7 +780,7 @@ public class Range implements WritableComparable<Range> {
    * Creates a range that covers an exact row and column family.
    *
    * @param row
-   *          row to cover
+   *          row row to cover
    * @param cf
    *          column family to cover
    */
@@ -793,7 +793,7 @@ public class Range implements WritableComparable<Range> {
    * Creates a range that covers an exact row, column family, and column qualifier.
    *
    * @param row
-   *          row to cover
+   *          row row to cover
    * @param cf
    *          column family to cover
    * @param cq
@@ -809,7 +809,7 @@ public class Range implements WritableComparable<Range> {
    * visibility.
    *
    * @param row
-   *          row to cover
+   *          row row to cover
    * @param cf
    *          column family to cover
    * @param cq
@@ -828,7 +828,7 @@ public class Range implements WritableComparable<Range> {
    * and timestamp.
    *
    * @param row
-   *          row to cover
+   *          row row to cover
    * @param cf
    *          column family to cover
    * @param cq
@@ -950,7 +950,7 @@ public class Range implements WritableComparable<Range> {
    * Creates a range that covers an exact row and column family.
    *
    * @param row
-   *          row to cover
+   *          row row to cover
    * @param cf
    *          column family to cover
    * @see #exact(Text, Text)
@@ -963,7 +963,7 @@ public class Range implements WritableComparable<Range> {
    * Creates a range that covers an exact row, column family, and column qualifier.
    *
    * @param row
-   *          row to cover
+   *          row row to cover
    * @param cf
    *          column family to cover
    * @param cq
@@ -979,7 +979,7 @@ public class Range implements WritableComparable<Range> {
    * visibility.
    *
    * @param row
-   *          row to cover
+   *          row row to cover
    * @param cf
    *          column family to cover
    * @param cq
@@ -998,7 +998,7 @@ public class Range implements WritableComparable<Range> {
    * and timestamp.
    *
    * @param row
-   *          row to cover
+   *          row row to cover
    * @param cf
    *          column family to cover
    * @param cq
