@@ -7,54 +7,51 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
-
 package org.apache.accumulo.core.file;
 
-import static java.nio.charset.StandardCharsets.UTF_8;
+import static java.util.concurrent.TimeUnit.SECONDS;
 
 import java.io.DataInputStream;
 import java.io.DataOutputStream;
 import java.io.IOException;
 import java.io.PrintStream;
+import java.security.SecureRandom;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.Map;
-import java.util.Random;
 import java.util.Set;
-import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.ExecutorService;
-import java.util.concurrent.LinkedBlockingQueue;
-import java.util.concurrent.ThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import org.apache.accumulo.core.bloomfilter.DynamicBloomFilter;
+import org.apache.accumulo.core.classloader.ClassLoaderUtil;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.ConfigurationCopy;
+import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.PartialKey;
 import org.apache.accumulo.core.data.Range;
 import org.apache.accumulo.core.data.Value;
+import org.apache.accumulo.core.file.blockfile.impl.CacheProvider;
 import org.apache.accumulo.core.file.keyfunctor.KeyFunctor;
 import org.apache.accumulo.core.file.rfile.RFile;
 import org.apache.accumulo.core.iterators.IteratorEnvironment;
 import org.apache.accumulo.core.iterators.SortedKeyValueIterator;
 import org.apache.accumulo.core.sample.impl.SamplerConfigurationImpl;
-import org.apache.accumulo.core.util.CachedConfiguration;
-import org.apache.accumulo.core.util.NamingThreadFactory;
-import org.apache.accumulo.fate.util.LoggingRunnable;
-import org.apache.accumulo.start.classloader.vfs.AccumuloVFSClassLoader;
+import org.apache.accumulo.core.spi.crypto.NoCryptoServiceFactory;
+import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.io.Text;
@@ -66,9 +63,10 @@ import org.slf4j.LoggerFactory;
 /**
  * A class that sits on top of different accumulo file formats and provides bloom filter
  * functionality.
- *
  */
 public class BloomFilterLayer {
+
+  private static final SecureRandom random = new SecureRandom();
   private static final Logger LOG = LoggerFactory.getLogger(BloomFilterLayer.class);
   public static final String BLOOM_FILE_NAME = "acu_bloom";
   public static final int HASH_COUNT = 5;
@@ -81,9 +79,8 @@ public class BloomFilterLayer {
     }
 
     if (maxLoadThreads > 0) {
-      BlockingQueue<Runnable> q = new LinkedBlockingQueue<>();
-      loadThreadPool = new ThreadPoolExecutor(0, maxLoadThreads, 60, TimeUnit.SECONDS, q,
-          new NamingThreadFactory("bloom-loader"));
+      loadThreadPool = ThreadPools.getServerThreadPools().createThreadPool(0, maxLoadThreads, 60,
+          SECONDS, "bloom-loader", false);
     }
 
     return loadThreadPool;
@@ -99,12 +96,13 @@ public class BloomFilterLayer {
     private boolean closed = false;
     private long length = -1;
 
-    Writer(FileSKVWriter writer, AccumuloConfiguration acuconf) {
+    Writer(FileSKVWriter writer, AccumuloConfiguration acuconf, boolean useAccumuloStart) {
       this.writer = writer;
-      initBloomFilter(acuconf);
+      initBloomFilter(acuconf, useAccumuloStart);
     }
 
-    private synchronized void initBloomFilter(AccumuloConfiguration acuconf) {
+    private synchronized void initBloomFilter(AccumuloConfiguration acuconf,
+        boolean useAccumuloStart) {
 
       numKeys = acuconf.getCount(Property.TABLE_BLOOM_SIZE);
       // vector size should be <code>-kn / (ln(1 - c^(1/k)))</code> bits for
@@ -122,16 +120,15 @@ public class BloomFilterLayer {
        * load KeyFunctor
        */
       try {
-        String context = acuconf.get(Property.TABLE_CLASSPATH);
+        String context = ClassLoaderUtil.tableContext(acuconf);
         String classname = acuconf.get(Property.TABLE_BLOOM_KEY_FUNCTOR);
         Class<? extends KeyFunctor> clazz;
-        if (context != null && !context.equals(""))
-          clazz = AccumuloVFSClassLoader.getContextManager().loadClass(context, classname,
-              KeyFunctor.class);
+        if (!useAccumuloStart)
+          clazz = Writer.class.getClassLoader().loadClass(classname).asSubclass(KeyFunctor.class);
         else
-          clazz = AccumuloVFSClassLoader.loadClass(classname, KeyFunctor.class);
+          clazz = ClassLoaderUtil.loadClass(context, classname, KeyFunctor.class);
 
-        transformer = clazz.newInstance();
+        transformer = clazz.getDeclaredConstructor().newInstance();
 
       } catch (Exception e) {
         LOG.error("Failed to find KeyFunctor: " + acuconf.get(Property.TABLE_BLOOM_KEY_FUNCTOR), e);
@@ -214,76 +211,65 @@ public class BloomFilterLayer {
 
       loadThreshold = acuconf.getCount(Property.TABLE_BLOOM_LOAD_THRESHOLD);
 
-      final String context = acuconf.get(Property.TABLE_CLASSPATH);
+      final String context = ClassLoaderUtil.tableContext(acuconf);
 
-      loadTask = new Runnable() {
-        @Override
-        public void run() {
+      loadTask = () -> {
+        // no need to load the bloom filter if the map file is closed
+        if (closed)
+          return;
+        String ClassName = null;
+        DataInputStream in = null;
 
-          // no need to load the bloom filter if the map file is closed
+        try {
+          in = reader.getMetaStore(BLOOM_FILE_NAME);
+          DynamicBloomFilter tmpBloomFilter = new DynamicBloomFilter();
+
+          // check for closed again after open but before reading the bloom filter in
           if (closed)
             return;
-          String ClassName = null;
-          DataInputStream in = null;
 
-          try {
-            in = reader.getMetaStore(BLOOM_FILE_NAME);
-            DynamicBloomFilter tmpBloomFilter = new DynamicBloomFilter();
+          /**
+           * Load classname for keyFunctor
+           */
+          ClassName = in.readUTF();
 
-            // check for closed again after open but before reading the bloom filter in
-            if (closed)
-              return;
+          Class<? extends KeyFunctor> clazz =
+              ClassLoaderUtil.loadClass(context, ClassName, KeyFunctor.class);
+          transformer = clazz.getDeclaredConstructor().newInstance();
 
-            /**
-             * Load classname for keyFunctor
-             */
-            ClassName = in.readUTF();
+          /**
+           * read in bloom filter
+           */
 
-            Class<? extends KeyFunctor> clazz;
-            if (context != null && !context.equals(""))
-              clazz = AccumuloVFSClassLoader.getContextManager().loadClass(context, ClassName,
-                  KeyFunctor.class);
-            else
-              clazz = AccumuloVFSClassLoader.loadClass(ClassName, KeyFunctor.class);
-            transformer = clazz.newInstance();
+          tmpBloomFilter.readFields(in);
+          // only set the bloom filter after it is fully constructed
+          bloomFilter = tmpBloomFilter;
+        } catch (NoSuchMetaStoreException nsme) {
+          // file does not have a bloom filter, ignore it
+        } catch (IOException ioe) {
+          if (closed)
+            LOG.debug("Can't open BloomFilter, file closed : {}", ioe.getMessage());
+          else
+            LOG.warn("Can't open BloomFilter", ioe);
 
-            /**
-             * read in bloom filter
-             */
-
-            tmpBloomFilter.readFields(in);
-            // only set the bloom filter after it is fully constructed
-            bloomFilter = tmpBloomFilter;
-          } catch (NoSuchMetaStoreException nsme) {
-            // file does not have a bloom filter, ignore it
-          } catch (IOException ioe) {
-            if (!closed)
-              LOG.warn("Can't open BloomFilter", ioe);
-            else
-              LOG.debug("Can't open BloomFilter, file closed : {}", ioe.getMessage());
-
-            bloomFilter = null;
-          } catch (ClassNotFoundException e) {
-            LOG.error("Failed to find KeyFunctor in config: " + ClassName, e);
-            bloomFilter = null;
-          } catch (InstantiationException e) {
-            LOG.error("Could not instantiate KeyFunctor: " + ClassName, e);
-            bloomFilter = null;
-          } catch (IllegalAccessException e) {
-            LOG.error("Illegal acess exception", e);
-            bloomFilter = null;
-          } catch (RuntimeException rte) {
-            if (!closed)
-              throw rte;
-            else
-              LOG.debug("Can't open BloomFilter, RTE after closed ", rte);
-          } finally {
-            if (in != null) {
-              try {
-                in.close();
-              } catch (IOException e) {
-                LOG.warn("Failed to close ", e);
-              }
+          bloomFilter = null;
+        } catch (ClassNotFoundException e) {
+          LOG.error("Failed to find KeyFunctor in config: " + sanitize(ClassName), e);
+          bloomFilter = null;
+        } catch (ReflectiveOperationException e) {
+          LOG.error("Could not instantiate KeyFunctor: " + sanitize(ClassName), e);
+          bloomFilter = null;
+        } catch (RuntimeException rte) {
+          if (closed)
+            LOG.debug("Can't open BloomFilter, RTE after closed ", rte);
+          else
+            throw rte;
+        } finally {
+          if (in != null) {
+            try {
+              in.close();
+            } catch (IOException e) {
+              LOG.warn("Failed to close ", e);
             }
           }
         }
@@ -293,6 +279,14 @@ public class BloomFilterLayer {
 
     }
 
+    /**
+     * Prevent potential CRLF injection into logs from read in user data. See the
+     * <a href="https://find-sec-bugs.github.io/bugs.htm#CRLF_INJECTION_LOGS">bug description</a>
+     */
+    private String sanitize(String msg) {
+      return msg.replaceAll("[\r\n]", "");
+    }
+
     private synchronized void initiateLoad(int maxLoadThreads) {
       // ensure only one thread initiates loading of bloom filter by
       // only taking action when loadTask != null
@@ -304,7 +298,7 @@ public class BloomFilterLayer {
             loadTask.run();
           } else {
             // load the bloom filter in the background
-            ltp.execute(new LoggingRunnable(LOG, loadTask));
+            ltp.execute(loadTask);
           }
         } finally {
           // set load task to null so no one else can initiate the load
@@ -323,7 +317,7 @@ public class BloomFilterLayer {
      *          range of keys to check
      * @return false iff key doesn't exist, true if key probably exists.
      */
-    boolean probablyHasKey(Range range) throws IOException {
+    boolean probablyHasKey(Range range) {
       if (bloomFilter == null) {
         initiateLoad(maxLoadThreads);
         if (bloomFilter == null)
@@ -369,11 +363,11 @@ public class BloomFilterLayer {
     public void seek(Range range, Collection<ByteSequence> columnFamilies, boolean inclusive)
         throws IOException {
 
-      if (!bfl.probablyHasKey(range)) {
-        checkSuper = false;
-      } else {
+      if (bfl.probablyHasKey(range)) {
         reader.seek(range, columnFamilies, inclusive);
         checkSuper = true;
+      } else {
+        checkSuper = false;
       }
     }
 
@@ -411,7 +405,7 @@ public class BloomFilterLayer {
 
     @Override
     public void init(SortedKeyValueIterator<org.apache.accumulo.core.data.Key,Value> source,
-        Map<String,String> options, IteratorEnvironment env) throws IOException {
+        Map<String,String> options, IteratorEnvironment env) {
       throw new UnsupportedOperationException();
 
     }
@@ -441,24 +435,25 @@ public class BloomFilterLayer {
       return new BloomFilterLayer.Reader(reader.getSample(sampleConfig), bfl);
     }
 
+    @Override
+    public void setCacheProvider(CacheProvider cacheProvider) {
+      reader.setCacheProvider(cacheProvider);
+    }
   }
 
   public static void main(String[] args) throws IOException {
     PrintStream out = System.out;
 
-    Random r = new Random();
-
     HashSet<Integer> valsSet = new HashSet<>();
 
     for (int i = 0; i < 100000; i++) {
-      valsSet.add(r.nextInt(Integer.MAX_VALUE));
+      valsSet.add(random.nextInt(Integer.MAX_VALUE));
     }
 
     ArrayList<Integer> vals = new ArrayList<>(valsSet);
     Collections.sort(vals);
 
-    ConfigurationCopy acuconf =
-        new ConfigurationCopy(AccumuloConfiguration.getDefaultConfiguration());
+    ConfigurationCopy acuconf = new ConfigurationCopy(DefaultConfiguration.getInstance());
     acuconf.set(Property.TABLE_BLOOM_ENABLED, "true");
     acuconf.set(Property.TABLE_BLOOM_KEY_FUNCTOR,
         "accumulo.core.file.keyfunctor.ColumnFamilyFunctor");
@@ -466,13 +461,14 @@ public class BloomFilterLayer {
     acuconf.set(Property.TABLE_BLOOM_LOAD_THRESHOLD, "1");
     acuconf.set(Property.TSERV_BLOOM_LOAD_MAXCONCURRENT, "1");
 
-    Configuration conf = CachedConfiguration.getInstance();
+    Configuration conf = new Configuration();
     FileSystem fs = FileSystem.get(conf);
 
     String suffix = FileOperations.getNewFileExtension(acuconf);
     String fname = "/tmp/test." + suffix;
-    FileSKVWriter bmfw = FileOperations.getInstance().newWriterBuilder().forFile(fname, fs, conf)
-        .withTableConfiguration(acuconf).build();
+    FileSKVWriter bmfw = FileOperations.getInstance().newWriterBuilder()
+        .forFile(fname, fs, conf, NoCryptoServiceFactory.NONE).withTableConfiguration(acuconf)
+        .build();
 
     long t1 = System.currentTimeMillis();
 
@@ -481,9 +477,9 @@ public class BloomFilterLayer {
     for (Integer i : vals) {
       String fi = String.format("%010d", i);
       bmfw.append(new org.apache.accumulo.core.data.Key(new Text("r" + fi), new Text("cf1")),
-          new Value(("v" + fi).getBytes(UTF_8)));
+          new Value("v" + fi));
       bmfw.append(new org.apache.accumulo.core.data.Key(new Text("r" + fi), new Text("cf2")),
-          new Value(("v" + fi).getBytes(UTF_8)));
+          new Value("v" + fi));
     }
 
     long t2 = System.currentTimeMillis();
@@ -493,8 +489,9 @@ public class BloomFilterLayer {
     bmfw.close();
 
     t1 = System.currentTimeMillis();
-    FileSKVIterator bmfr = FileOperations.getInstance().newReaderBuilder().forFile(fname, fs, conf)
-        .withTableConfiguration(acuconf).build();
+    FileSKVIterator bmfr = FileOperations.getInstance().newReaderBuilder()
+        .forFile(fname, fs, conf, NoCryptoServiceFactory.NONE).withTableConfiguration(acuconf)
+        .build();
     t2 = System.currentTimeMillis();
     out.println("Opened " + fname + " in " + (t2 - t1));
 
@@ -502,13 +499,13 @@ public class BloomFilterLayer {
 
     int hits = 0;
     for (int i = 0; i < 5000; i++) {
-      int row = r.nextInt(Integer.MAX_VALUE);
+      int row = random.nextInt(Integer.MAX_VALUE);
       String fi = String.format("%010d", row);
       // bmfr.seek(new Range(new Text("r"+fi)));
       org.apache.accumulo.core.data.Key k1 =
           new org.apache.accumulo.core.data.Key(new Text("r" + fi), new Text("cf1"));
       bmfr.seek(new Range(k1, true, k1.followingKey(PartialKey.ROW_COLFAM), false),
-          new ArrayList<ByteSequence>(), false);
+          new ArrayList<>(), false);
       if (valsSet.contains(row)) {
         hits++;
         if (!bmfr.hasTop()) {
@@ -533,7 +530,7 @@ public class BloomFilterLayer {
       org.apache.accumulo.core.data.Key k1 =
           new org.apache.accumulo.core.data.Key(new Text("r" + fi), new Text("cf1"));
       bmfr.seek(new Range(k1, true, k1.followingKey(PartialKey.ROW_COLFAM), false),
-          new ArrayList<ByteSequence>(), false);
+          new ArrayList<>(), false);
 
       if (!bmfr.hasTop()) {
         out.println("ERROR 2 " + row);
@@ -548,7 +545,7 @@ public class BloomFilterLayer {
 
     t2 = System.currentTimeMillis();
 
-    out.printf("existant lookup rate %6.2f%n", 500 / ((t2 - t1) / 1000.0));
+    out.printf("existing lookup rate %6.2f%n", 500 / ((t2 - t1) / 1000.0));
     out.println("expected hits 500.  Receive hits: " + count);
     bmfr.close();
   }
