@@ -1,20 +1,21 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with this
- * work for additional information regarding copyright ownership. The ASF
- * licenses this file to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations under
- * the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
-
 package org.apache.accumulo.core.file.rfile.bcfile;
 
 import java.io.ByteArrayInputStream;
@@ -33,11 +34,8 @@ import java.util.Arrays;
 import java.util.Map;
 import java.util.TreeMap;
 
+import org.apache.accumulo.core.crypto.CryptoEnvironmentImpl;
 import org.apache.accumulo.core.crypto.CryptoUtils;
-import org.apache.accumulo.core.cryptoImpl.CryptoEnvironmentImpl;
-import org.apache.accumulo.core.cryptoImpl.NoFileDecrypter;
-import org.apache.accumulo.core.cryptoImpl.NoFileEncrypter;
-import org.apache.accumulo.core.file.rfile.bcfile.Compression.Algorithm;
 import org.apache.accumulo.core.file.rfile.bcfile.Utils.Version;
 import org.apache.accumulo.core.file.streams.BoundedRangeFileInputStream;
 import org.apache.accumulo.core.file.streams.RateLimitedOutputStream;
@@ -47,6 +45,8 @@ import org.apache.accumulo.core.spi.crypto.CryptoEnvironment.Scope;
 import org.apache.accumulo.core.spi.crypto.CryptoService;
 import org.apache.accumulo.core.spi.crypto.FileDecrypter;
 import org.apache.accumulo.core.spi.crypto.FileEncrypter;
+import org.apache.accumulo.core.spi.crypto.NoFileDecrypter;
+import org.apache.accumulo.core.spi.crypto.NoFileEncrypter;
 import org.apache.accumulo.core.util.ratelimit.RateLimiter;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -128,7 +128,7 @@ public final class BCFile {
      * Intermediate class that maintain the state of a Writable Compression Block.
      */
     private static final class WBlockState {
-      private final Algorithm compressAlgo;
+      private final CompressionAlgorithm compressAlgo;
       private Compressor compressor; // !null only if using native
       // Hadoop compression
       private final RateLimitedOutputStream fsOut;
@@ -137,7 +137,7 @@ public final class BCFile {
       private final SimpleBufferedOutputStream fsBufferedOutput;
       private OutputStream out;
 
-      public WBlockState(Algorithm compressionAlgo, RateLimitedOutputStream fsOut,
+      public WBlockState(CompressionAlgorithm compressionAlgo, RateLimitedOutputStream fsOut,
           BytesWritable fsOutputBuffer, Configuration conf, FileEncrypter encrypter)
           throws IOException {
         this.compressAlgo = compressionAlgo;
@@ -325,7 +325,7 @@ public final class BCFile {
       metaIndex = new MetaIndex();
       fsOutputBuffer = new BytesWritable();
       Magic.write(this.out);
-      this.cryptoEnvironment = new CryptoEnvironmentImpl(Scope.RFILE, null);
+      this.cryptoEnvironment = new CryptoEnvironmentImpl(Scope.TABLE, null, null);
       this.encrypter = cryptoService.getFileEncrypter(this.cryptoEnvironment);
     }
 
@@ -372,11 +372,11 @@ public final class BCFile {
       }
     }
 
-    private Algorithm getDefaultCompressionAlgorithm() {
+    private CompressionAlgorithm getDefaultCompressionAlgorithm() {
       return dataIndex.getDefaultCompressionAlgorithm();
     }
 
-    private BlockAppender prepareMetaBlock(String name, Algorithm compressAlgo)
+    private BlockAppender prepareMetaBlock(String name, CompressionAlgorithm compressAlgo)
         throws IOException, MetaBlockAlreadyExists {
       if (blkInProgress) {
         throw new IllegalStateException("Cannot create Meta Block until previous block is closed.");
@@ -438,9 +438,9 @@ public final class BCFile {
      */
     private class MetaBlockRegister {
       private final String name;
-      private final Algorithm compressAlgo;
+      private final CompressionAlgorithm compressAlgo;
 
-      MetaBlockRegister(String name, Algorithm compressAlgo) {
+      MetaBlockRegister(String name, CompressionAlgorithm compressAlgo) {
         this.name = name;
         this.compressAlgo = compressAlgo;
       }
@@ -469,15 +469,15 @@ public final class BCFile {
      * Intermediate class that maintain the state of a Readable Compression Block.
      */
     private static final class RBlockState {
-      private final Algorithm compressAlgo;
+      private final CompressionAlgorithm compressAlgo;
       private Decompressor decompressor;
       private final BlockRegion region;
       private final InputStream in;
       private volatile boolean closed;
 
-      public <InputStreamType extends InputStream & Seekable> RBlockState(Algorithm compressionAlgo,
-          InputStreamType fsin, BlockRegion region, Configuration conf, FileDecrypter decrypter)
-          throws IOException {
+      public <InputStreamType extends InputStream & Seekable> RBlockState(
+          CompressionAlgorithm compressionAlgo, InputStreamType fsin, BlockRegion region,
+          Configuration conf, FileDecrypter decrypter) throws IOException {
         this.compressAlgo = compressionAlgo;
         this.region = region;
         this.decompressor = compressionAlgo.getDecompressor();
@@ -609,7 +609,7 @@ public final class BCFile {
       // Do a version check - API_VERSION_2 used experimental crypto parameters, no longer supported
       if (!version.compatibleWith(BCFile.API_VERSION_3)
           && !version.compatibleWith(BCFile.API_VERSION_1)) {
-        throw new IOException("Unsupported BCFile Version found: " + version.toString() + ". "
+        throw new IOException("Unsupported BCFile Version found: " + version + ". "
             + "Only support " + API_VERSION_1 + " or " + API_VERSION_3);
       }
 
@@ -641,7 +641,7 @@ public final class BCFile {
         // read crypto parameters and get decrypter
         this.in.seek(offsetCryptoParameters);
         decryptionParams = CryptoUtils.readParams(this.in);
-        cryptoEnvironment = new CryptoEnvironmentImpl(Scope.RFILE, decryptionParams);
+        cryptoEnvironment = new CryptoEnvironmentImpl(Scope.TABLE, null, decryptionParams);
         this.decrypter = cryptoService.getFileDecrypter(cryptoEnvironment);
       }
 
@@ -665,7 +665,7 @@ public final class BCFile {
       dataIndex = new DataIndex(dis);
 
       decryptionParams = CryptoUtils.readParams(dis);
-      CryptoEnvironmentImpl env = new CryptoEnvironmentImpl(Scope.RFILE, decryptionParams);
+      CryptoEnvironmentImpl env = new CryptoEnvironmentImpl(Scope.TABLE, null, decryptionParams);
       this.decrypter = cryptoService.getFileDecrypter(env);
     }
 
@@ -746,7 +746,7 @@ public final class BCFile {
       return dataIndex.getBlockRegionList().get(blockIndex).getRawSize();
     }
 
-    private BlockReader createReader(Algorithm compressAlgo, BlockRegion region)
+    private BlockReader createReader(CompressionAlgorithm compressAlgo, BlockRegion region)
         throws IOException {
       RBlockState rbs = new RBlockState(compressAlgo, in, region, conf, decrypter);
       return new BlockReader(rbs);
@@ -798,7 +798,7 @@ public final class BCFile {
    */
   static final class MetaIndexEntry {
     private final String metaName;
-    private final Algorithm compressionAlgorithm;
+    private final CompressionAlgorithm compressionAlgorithm;
     private static final String defaultPrefix = "data:";
 
     private final BlockRegion region;
@@ -815,7 +815,8 @@ public final class BCFile {
       region = new BlockRegion(in);
     }
 
-    public MetaIndexEntry(String metaName, Algorithm compressionAlgorithm, BlockRegion region) {
+    public MetaIndexEntry(String metaName, CompressionAlgorithm compressionAlgorithm,
+        BlockRegion region) {
       this.metaName = metaName;
       this.compressionAlgorithm = compressionAlgorithm;
       this.region = region;
@@ -825,7 +826,7 @@ public final class BCFile {
       return metaName;
     }
 
-    public Algorithm getCompressionAlgorithm() {
+    public CompressionAlgorithm getCompressionAlgorithm() {
       return compressionAlgorithm;
     }
 
@@ -847,7 +848,7 @@ public final class BCFile {
   static class DataIndex {
     static final String BLOCK_NAME = "BCFile.index";
 
-    private final Algorithm defaultCompressionAlgorithm;
+    private final CompressionAlgorithm defaultCompressionAlgorithm;
 
     // for data blocks, each entry specifies a block's offset, compressed size
     // and raw size
@@ -873,7 +874,7 @@ public final class BCFile {
       listRegions = new ArrayList<>();
     }
 
-    public Algorithm getDefaultCompressionAlgorithm() {
+    public CompressionAlgorithm getDefaultCompressionAlgorithm() {
       return defaultCompressionAlgorithm;
     }
 
