@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.iterators;
 
@@ -52,12 +54,9 @@ public class FirstEntryInRowIterator extends SkippingIterator implements OptionD
   }
 
   // this must be public for OptionsDescriber
-  public FirstEntryInRowIterator() {
-    super();
-  }
+  public FirstEntryInRowIterator() {}
 
   public FirstEntryInRowIterator(FirstEntryInRowIterator other, IteratorEnvironment env) {
-    super();
     setSource(other.getSource().deepCopy(env));
   }
 
@@ -93,14 +92,13 @@ public class FirstEntryInRowIterator extends SkippingIterator implements OptionD
 
         // determine where to seek to, but don't go beyond the user-specified range
         Key nextKey = source.getTopKey().followingKey(PartialKey.ROW);
-        if (!latestRange.afterEndKey(nextKey))
+        if (latestRange.afterEndKey(nextKey)) {
+          finished = true;
+          break;
+        } else
           source.seek(
               new Range(nextKey, true, latestRange.getEndKey(), latestRange.isEndKeyInclusive()),
               latestColumnFamilies, latestInclusive);
-        else {
-          finished = true;
-          break;
-        }
       }
     }
     lastRowFound = source.hasTop() ? source.getTopKey().getRow(lastRowFound) : null;
