@@ -1,23 +1,26 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.iterators;
 
 import java.io.IOException;
 
+import org.apache.accumulo.core.client.PluginEnvironment;
 import org.apache.accumulo.core.client.SampleNotPresentException;
 import org.apache.accumulo.core.client.sample.SamplerConfiguration;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
@@ -33,7 +36,7 @@ public interface IteratorEnvironment {
   /**
    * @deprecated since 2.0.0. This is a legacy method used for internal backwards compatibility.
    */
-  @Deprecated
+  @Deprecated(since = "2.0.0")
   default SortedKeyValueIterator<Key,Value> reserveMapFileReader(String mapFileName)
       throws IOException {
     throw new UnsupportedOperationException();
@@ -41,9 +44,9 @@ public interface IteratorEnvironment {
 
   /**
    * @deprecated since 2.0.0. This method was using an unstable non public type. Use
-   *             {@link #getServiceEnv()}
+   *             {@link #getPluginEnv()}
    */
-  @Deprecated
+  @Deprecated(since = "2.0.0")
   default AccumuloConfiguration getConfig() {
     throw new UnsupportedOperationException();
   }
@@ -67,7 +70,7 @@ public interface IteratorEnvironment {
   /**
    * @deprecated since 2.0.0. This was an experimental feature and was never tested or documented.
    */
-  @Deprecated
+  @Deprecated(since = "2.0.0")
   default void registerSideChannel(SortedKeyValueIterator<Key,Value> iter) {
     throw new UnsupportedOperationException();
   }
@@ -155,11 +158,28 @@ public interface IteratorEnvironment {
    * </pre>
    *
    * @since 2.0.0
+   * @deprecated since 2.1.0. This method was using a non public API type. Use
+   *             {@link #getPluginEnv()} instead because it has better stability guarantees.
    */
+  @Deprecated(since = "2.1.0")
   default ServiceEnvironment getServiceEnv() {
     throw new UnsupportedOperationException();
   }
 
+  /**
+   * Returns an object containing information about the server where this iterator was run. To
+   * obtain a table configuration, use the following methods:
+   *
+   * <pre>
+   * iterEnv.getPluginEnv().getConfiguration(env.getTableId())
+   * </pre>
+   *
+   * @since 2.1.0
+   */
+  default PluginEnvironment getPluginEnv() {
+    return getServiceEnv();
+  }
+
   /**
    * Return the table Id associated with this iterator.
    *
