@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.metadata;
 
@@ -30,6 +32,8 @@ import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.data.Value;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection;
+import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.CurrentLocationColumnFamily;
+import org.apache.accumulo.core.metadata.schema.MetadataSchema.TabletsSection.TabletColumnFamily;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.hadoop.io.Text;
 
@@ -64,8 +68,8 @@ abstract class TableMetadataServicer extends MetadataServicer {
 
     Scanner scanner = context.createScanner(getServicingTableName(), Authorizations.EMPTY);
 
-    TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.fetch(scanner);
-    scanner.fetchColumnFamily(TabletsSection.CurrentLocationColumnFamily.NAME);
+    TabletColumnFamily.PREV_ROW_COLUMN.fetch(scanner);
+    scanner.fetchColumnFamily(CurrentLocationColumnFamily.NAME);
 
     // position at first entry in metadata table for given table
     scanner.setRange(TabletsSection.getRange(getServicedTableId()));
@@ -73,14 +77,12 @@ abstract class TableMetadataServicer extends MetadataServicer {
     Text colf = new Text();
     Text colq = new Text();
 
-    KeyExtent currentKeyExtent = null;
     String location = null;
     Text row = null;
     // acquire this table's tablets from the metadata table which services it
     for (Entry<Key,Value> entry : scanner) {
       if (row != null) {
         if (!row.equals(entry.getKey().getRow())) {
-          currentKeyExtent = null;
           location = null;
           row = entry.getKey().getRow();
         }
@@ -91,12 +93,11 @@ abstract class TableMetadataServicer extends MetadataServicer {
       colf = entry.getKey().getColumnFamily(colf);
       colq = entry.getKey().getColumnQualifier(colq);
 
-      if (TabletsSection.TabletColumnFamily.PREV_ROW_COLUMN.equals(colf, colq)) {
-        currentKeyExtent = new KeyExtent(entry.getKey().getRow(), entry.getValue());
+      if (TabletColumnFamily.PREV_ROW_COLUMN.equals(colf, colq)) {
+        KeyExtent currentKeyExtent = KeyExtent.fromMetaPrevRow(entry);
         tablets.put(currentKeyExtent, location);
-        currentKeyExtent = null;
         location = null;
-      } else if (colf.equals(TabletsSection.CurrentLocationColumnFamily.NAME)) {
+      } else if (colf.equals(CurrentLocationColumnFamily.NAME)) {
         location = entry.getValue().toString();
       }
 
@@ -109,32 +110,32 @@ abstract class TableMetadataServicer extends MetadataServicer {
     SortedSet<KeyExtent> tabletsKeys = (SortedSet<KeyExtent>) tablets.keySet();
     // sanity check of metadata table entries
     // make sure tablets has no holes, and that it starts and ends w/ null
-    if (tabletsKeys.size() == 0)
+    if (tabletsKeys.isEmpty())
       throw new AccumuloException(
           "No entries found in metadata table for table " + getServicedTableId());
 
-    if (tabletsKeys.first().getPrevEndRow() != null)
+    if (tabletsKeys.first().prevEndRow() != null)
       throw new AccumuloException("Problem with metadata table, first entry for table "
           + getServicedTableId() + "- " + tabletsKeys.first() + " - has non null prev end row");
 
-    if (tabletsKeys.last().getEndRow() != null)
+    if (tabletsKeys.last().endRow() != null)
       throw new AccumuloException("Problem with metadata table, last entry for table "
           + getServicedTableId() + "- " + tabletsKeys.first() + " - has non null end row");
 
     Iterator<KeyExtent> tabIter = tabletsKeys.iterator();
-    Text lastEndRow = tabIter.next().getEndRow();
+    Text lastEndRow = tabIter.next().endRow();
     while (tabIter.hasNext()) {
       KeyExtent tabke = tabIter.next();
 
-      if (tabke.getPrevEndRow() == null)
+      if (tabke.prevEndRow() == null)
         throw new AccumuloException(
             "Problem with metadata table, it has null prev end row in middle of table " + tabke);
 
-      if (!tabke.getPrevEndRow().equals(lastEndRow))
+      if (!tabke.prevEndRow().equals(lastEndRow))
         throw new AccumuloException("Problem with metadata table, it has a hole "
-            + tabke.getPrevEndRow() + " != " + lastEndRow);
+            + tabke.prevEndRow() + " != " + lastEndRow);
 
-      lastEndRow = tabke.getEndRow();
+      lastEndRow = tabke.endRow();
     }
 
     // end METADATA table sanity check
