@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.replication;
 
@@ -49,6 +51,7 @@ public class ReplicationSchema {
    * </code>
    * </pre>
    */
+  @Deprecated
   public static class WorkSection {
     public static final Text NAME = new Text("work");
     private static final ByteSequence BYTE_SEQ_NAME = new ArrayByteSequence("work");
@@ -92,6 +95,7 @@ public class ReplicationSchema {
    * </code>
    * </pre>
    */
+  @Deprecated
   public static class StatusSection {
     public static final Text NAME = new Text("repl");
     private static final ByteSequence BYTE_SEQ_NAME = new ArrayByteSequence("repl");
@@ -150,6 +154,7 @@ public class ReplicationSchema {
    * </code>
    * </pre>
    */
+  @Deprecated
   public static class OrderSection {
     public static final Text NAME = new Text("order");
     public static final Text ROW_SEPARATOR = new Text(new byte[] {0});
