@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.rpc;
 
@@ -23,7 +25,6 @@ import java.util.Arrays;
 
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.commons.lang3.StringUtils;
 import org.apache.thrift.transport.TSSLTransportFactory.TSSLTransportParameters;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -80,11 +81,11 @@ public class SslConnectionParams {
 
     String ciphers = conf.get(Property.RPC_SSL_CIPHER_SUITES);
     if (ciphers != null && !ciphers.isEmpty()) {
-      result.cipherSuites = StringUtils.split(ciphers, ',');
+      result.cipherSuites = ciphers.split(",");
     }
 
     String enabledProtocols = conf.get(Property.RPC_SSL_ENABLED_PROTOCOLS);
-    result.serverProtocols = StringUtils.split(enabledProtocols, ',');
+    result.serverProtocols = enabledProtocols.split(",");
 
     result.clientProtocol = conf.get(Property.RPC_SSL_CLIENT_PROTOCOL);
 
@@ -94,12 +95,12 @@ public class SslConnectionParams {
   private static String passwordFromConf(AccumuloConfiguration conf, String defaultPassword,
       Property passwordOverrideProperty) {
     String keystorePassword = conf.get(passwordOverrideProperty);
-    if (!keystorePassword.isEmpty()) {
+    if (keystorePassword.isEmpty()) {
+      keystorePassword = defaultPassword;
+    } else {
       if (log.isTraceEnabled())
         log.trace("Using explicit SSL private key password from {}",
             passwordOverrideProperty.getKey());
-    } else {
-      keystorePassword = defaultPassword;
     }
     return keystorePassword;
   }
@@ -263,7 +264,7 @@ public class SslConnectionParams {
     }
     hash = 31 * hash + clientProtocol.hashCode();
     hash = 31 * hash + Arrays.hashCode(serverProtocols);
-    return super.hashCode();
+    return hash;
   }
 
   @Override
