@@ -1,23 +1,28 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
-
 package org.apache.accumulo.core.summary;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
+import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.FILES;
+import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.LAST;
+import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.LOCATION;
+import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.PREV_ROW;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -36,6 +41,7 @@ import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.function.Function;
 import java.util.function.Predicate;
 import java.util.function.Supplier;
 import java.util.regex.Pattern;
@@ -45,7 +51,6 @@ import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
 import org.apache.accumulo.core.client.summary.SummarizerConfiguration;
 import org.apache.accumulo.core.clientImpl.ClientContext;
-import org.apache.accumulo.core.clientImpl.ServerClient;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Key;
@@ -55,12 +60,13 @@ import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.TRowRange;
 import org.apache.accumulo.core.dataImpl.thrift.TSummaries;
 import org.apache.accumulo.core.dataImpl.thrift.TSummaryRequest;
+import org.apache.accumulo.core.metadata.TabletFile;
 import org.apache.accumulo.core.metadata.schema.TabletMetadata;
 import org.apache.accumulo.core.metadata.schema.TabletsMetadata;
 import org.apache.accumulo.core.rpc.ThriftUtil;
+import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
 import org.apache.accumulo.core.spi.cache.BlockCache;
 import org.apache.accumulo.core.spi.crypto.CryptoService;
-import org.apache.accumulo.core.tabletserver.thrift.TabletClientService;
 import org.apache.accumulo.core.tabletserver.thrift.TabletClientService.Client;
 import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.trace.thrift.TInfo;
@@ -73,7 +79,6 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.Text;
-import org.apache.thrift.TApplicationException;
 import org.apache.thrift.TException;
 import org.apache.thrift.transport.TTransportException;
 import org.slf4j.Logger;
@@ -81,7 +86,6 @@ import org.slf4j.LoggerFactory;
 
 import com.google.common.base.Preconditions;
 import com.google.common.cache.Cache;
-import com.google.common.collect.Lists;
 import com.google.common.hash.Hashing;
 
 /**
@@ -160,18 +164,17 @@ public class Gatherer {
    * @return A map of the form : {@code map<tserver location, map<path, list<range>>} . The ranges
    *         associated with a file represent the tablets that use the file.
    */
-  private Map<String,Map<String,List<TRowRange>>>
-      getFilesGroupedByLocation(Predicate<String> fileSelector) {
+  private Map<String,Map<TabletFile,List<TRowRange>>>
+      getFilesGroupedByLocation(Predicate<TabletFile> fileSelector) {
 
-    Iterable<TabletMetadata> tmi =
-        TabletsMetadata.builder().forTable(tableId).overlapping(startRow, endRow).fetchFiles()
-            .fetchLocation().fetchLast().fetchPrev().build(ctx);
+    Iterable<TabletMetadata> tmi = TabletsMetadata.builder(ctx).forTable(tableId)
+        .overlapping(startRow, endRow).fetch(FILES, LOCATION, LAST, PREV_ROW).build();
 
     // get a subset of files
-    Map<String,List<TabletMetadata>> files = new HashMap<>();
+    Map<TabletFile,List<TabletMetadata>> files = new HashMap<>();
 
     for (TabletMetadata tm : tmi) {
-      for (String file : tm.getFiles()) {
+      for (TabletFile file : tm.getFiles()) {
         if (fileSelector.test(file)) {
           // TODO push this filtering to server side and possibly use batch scanner
           files.computeIfAbsent(file, s -> new ArrayList<>()).add(tm);
@@ -181,22 +184,22 @@ public class Gatherer {
 
     // group by location, then file
 
-    Map<String,Map<String,List<TRowRange>>> locations = new HashMap<>();
+    Map<String,Map<TabletFile,List<TRowRange>>> locations = new HashMap<>();
 
     List<String> tservers = null;
 
-    for (Entry<String,List<TabletMetadata>> entry : files.entrySet()) {
+    for (Entry<TabletFile,List<TabletMetadata>> entry : files.entrySet()) {
 
       String location = entry.getValue().stream().filter(tm -> tm.getLocation() != null) // filter
                                                                                          // tablets
                                                                                          // w/o a
                                                                                          // location
-          .map(tm -> tm.getLocation().getHostAndPort().toString()) // convert to host:port strings
+          .map(tm -> tm.getLocation().getHostPort()) // convert to host:port strings
           .min(String::compareTo) // find minimum host:port
           .orElse(entry.getValue().stream().filter(tm -> tm.getLast() != null) // if no locations,
                                                                                // then look at last
                                                                                // locations
-              .map(tm -> tm.getLast().getHostAndPort().toString()) // convert to host:port strings
+              .map(tm -> tm.getLast().getHostPort()) // convert to host:port strings
               .min(String::compareTo).orElse(null)); // find minimum last location or return null
 
       if (location == null) {
@@ -207,14 +210,15 @@ public class Gatherer {
 
         // When no location, the approach below will consistently choose the same tserver for the
         // same file (as long as the set of tservers is stable).
-        int idx = Math.abs(Hashing.murmur3_32().hashString(entry.getKey(), UTF_8).asInt())
+        int idx = Math
+            .abs(Hashing.murmur3_32_fixed().hashString(entry.getKey().getPathStr(), UTF_8).asInt())
             % tservers.size();
         location = tservers.get(idx);
       }
 
       // merge contiguous ranges
-      List<Range> merged = Range
-          .mergeOverlapping(Lists.transform(entry.getValue(), tm -> tm.getExtent().toDataRange()));
+      List<Range> merged = Range.mergeOverlapping(entry.getValue().stream()
+          .map(tm -> tm.getExtent().toDataRange()).collect(Collectors.toList()));
       List<TRowRange> ranges =
           merged.stream().map(r -> toClippedExtent(r).toThrift()).collect(Collectors.toList()); // clip
                                                                                                 // ranges
@@ -237,7 +241,7 @@ public class Gatherer {
     return () -> {
       Iterator<Entry<K,V>> esi = map.entrySet().iterator();
 
-      return new Iterator<Map<K,V>>() {
+      return new Iterator<>() {
         @Override
         public boolean hasNext() {
           return esi.hasNext();
@@ -258,7 +262,7 @@ public class Gatherer {
 
   private static class ProcessedFiles {
     final SummaryCollection summaries;
-    final Set<String> failedFiles;
+    final Set<TabletFile> failedFiles;
 
     public ProcessedFiles() {
       this.summaries = new SummaryCollection();
@@ -283,12 +287,12 @@ public class Gatherer {
   private class FilesProcessor implements Supplier<ProcessedFiles> {
 
     HostAndPort location;
-    Map<String,List<TRowRange>> allFiles;
+    Map<TabletFile,List<TRowRange>> allFiles;
     private TInfo tinfo;
     private AtomicBoolean cancelFlag;
 
-    public FilesProcessor(TInfo tinfo, HostAndPort location, Map<String,List<TRowRange>> allFiles,
-        AtomicBoolean cancelFlag) {
+    public FilesProcessor(TInfo tinfo, HostAndPort location,
+        Map<TabletFile,List<TRowRange>> allFiles, AtomicBoolean cancelFlag) {
       this.location = location;
       this.allFiles = allFiles;
       this.tinfo = tinfo;
@@ -301,25 +305,24 @@ public class Gatherer {
 
       Client client = null;
       try {
-        client = ThriftUtil.getTServerClient(location, ctx);
+        client = ThriftUtil.getClient(ThriftClientTypes.TABLET_SERVER, location, ctx);
         // partition files into smaller chunks so that not too many are sent to a tserver at once
-        for (Map<String,List<TRowRange>> files : partition(allFiles, 500)) {
-          if (pfiles.failedFiles.size() > 0) {
+        for (Map<TabletFile,List<TRowRange>> files : partition(allFiles, 500)) {
+          if (!pfiles.failedFiles.isEmpty()) {
             // there was a previous failure on this tserver, so just fail the rest of the files
             pfiles.failedFiles.addAll(files.keySet());
             continue;
           }
 
           try {
-            TSummaries tSums =
-                client.startGetSummariesFromFiles(tinfo, ctx.rpcCreds(), getRequest(), files);
+            TSummaries tSums = client.startGetSummariesFromFiles(tinfo, ctx.rpcCreds(),
+                getRequest(), files.entrySet().stream().collect(
+                    Collectors.toMap(entry -> entry.getKey().getPathStr(), Entry::getValue)));
             while (!tSums.finished && !cancelFlag.get()) {
               tSums = client.contiuneGetSummaries(tinfo, tSums.sessionId);
             }
 
             pfiles.summaries.merge(new SummaryCollection(tSums), factory);
-          } catch (TApplicationException tae) {
-            throw new RuntimeException(tae);
           } catch (TTransportException e) {
             pfiles.failedFiles.addAll(files.keySet());
             continue;
@@ -331,7 +334,7 @@ public class Gatherer {
       } catch (TTransportException e1) {
         pfiles.failedFiles.addAll(allFiles.keySet());
       } finally {
-        ThriftUtil.returnClient(client);
+        ThriftUtil.returnClient(client, ctx);
       }
 
       if (cancelFlag.get()) {
@@ -343,30 +346,18 @@ public class Gatherer {
   }
 
   private class PartitionFuture implements Future<SummaryCollection> {
-
-    private CompletableFuture<ProcessedFiles> future;
-    private int modulus;
-    private int remainder;
-    private ExecutorService execSrv;
-    private TInfo tinfo;
-    private AtomicBoolean cancelFlag = new AtomicBoolean(false);
+    private final CompletableFuture<SummaryCollection> future;
+    private final AtomicBoolean cancelFlag = new AtomicBoolean(false);
 
     PartitionFuture(TInfo tinfo, ExecutorService execSrv, int modulus, int remainder) {
-      this.tinfo = tinfo;
-      this.execSrv = execSrv;
-      this.modulus = modulus;
-      this.remainder = remainder;
-    }
-
-    private synchronized void initiateProcessing(ProcessedFiles previousWork) {
-      try {
-        Predicate<String> fileSelector =
-            file -> Math.abs(Hashing.murmur3_32().hashString(file, UTF_8).asInt()) % modulus
-                == remainder;
+      Function<ProcessedFiles,CompletableFuture<ProcessedFiles>> go = previousWork -> {
+        Predicate<TabletFile> fileSelector = file -> Math
+            .abs(Hashing.murmur3_32_fixed().hashString(file.getPathStr(), UTF_8).asInt()) % modulus
+            == remainder;
         if (previousWork != null) {
           fileSelector = fileSelector.and(previousWork.failedFiles::contains);
         }
-        Map<String,Map<String,List<TRowRange>>> filesGBL;
+        Map<String,Map<TabletFile,List<TRowRange>>> filesGBL;
         filesGBL = getFilesGroupedByLocation(fileSelector);
 
         List<CompletableFuture<ProcessedFiles>> futures = new ArrayList<>();
@@ -375,58 +366,25 @@ public class Gatherer {
               .completedFuture(new ProcessedFiles(previousWork.summaries, factory)));
         }
 
-        for (Entry<String,Map<String,List<TRowRange>>> entry : filesGBL.entrySet()) {
+        for (Entry<String,Map<TabletFile,List<TRowRange>>> entry : filesGBL.entrySet()) {
           HostAndPort location = HostAndPort.fromString(entry.getKey());
-          Map<String,List<TRowRange>> allFiles = entry.getValue();
+          Map<TabletFile,List<TRowRange>> allFiles = entry.getValue();
 
           futures.add(CompletableFuture
               .supplyAsync(new FilesProcessor(tinfo, location, allFiles, cancelFlag), execSrv));
         }
 
-        future = CompletableFutureUtil.merge(futures,
+        return CompletableFutureUtil.merge(futures,
             (pf1, pf2) -> ProcessedFiles.merge(pf1, pf2, factory), ProcessedFiles::new);
-
-        // when all processing is done, check for failed files... and if found starting processing
-        // again
-        future.thenRun(this::updateFuture);
-      } catch (Exception e) {
-        future = CompletableFuture.completedFuture(new ProcessedFiles());
-        // force future to have this exception
-        future.obtrudeException(e);
-      }
-    }
-
-    private ProcessedFiles _get() {
-      try {
-        return future.get();
-      } catch (InterruptedException e) {
-        Thread.currentThread().interrupt();
-        throw new RuntimeException(e);
-      } catch (ExecutionException e) {
-        throw new RuntimeException(e);
-      }
-    }
-
-    private synchronized CompletableFuture<ProcessedFiles> updateFuture() {
-      if (future.isDone()) {
-        if (!future.isCancelled() && !future.isCompletedExceptionally()) {
-          ProcessedFiles pf = _get();
-          if (pf.failedFiles.size() > 0) {
-            initiateProcessing(pf);
-          }
-        }
-      }
-
-      return future;
-    }
-
-    synchronized void initiateProcessing() {
-      Preconditions.checkState(future == null);
-      initiateProcessing(null);
+      };
+      future = CompletableFutureUtil
+          .iterateUntil(go,
+              previousWork -> previousWork != null && previousWork.failedFiles.isEmpty(), null)
+          .thenApply(pf -> pf.summaries);
     }
 
     @Override
-    public synchronized boolean cancel(boolean mayInterruptIfRunning) {
+    public boolean cancel(boolean mayInterruptIfRunning) {
       boolean canceled = future.cancel(mayInterruptIfRunning);
       if (canceled) {
         cancelFlag.set(true);
@@ -435,58 +393,24 @@ public class Gatherer {
     }
 
     @Override
-    public synchronized boolean isCancelled() {
+    public boolean isCancelled() {
       return future.isCancelled();
     }
 
     @Override
-    public synchronized boolean isDone() {
-      updateFuture();
-      if (future.isDone()) {
-        if (future.isCancelled() || future.isCompletedExceptionally()) {
-          return true;
-        }
-
-        ProcessedFiles pf = _get();
-        if (pf.failedFiles.size() == 0) {
-          return true;
-        } else {
-          updateFuture();
-        }
-      }
-
-      return false;
+    public boolean isDone() {
+      return future.isDone();
     }
 
     @Override
     public SummaryCollection get() throws InterruptedException, ExecutionException {
-      CompletableFuture<ProcessedFiles> futureRef = updateFuture();
-      ProcessedFiles processedFiles = futureRef.get();
-      while (processedFiles.failedFiles.size() > 0) {
-        futureRef = updateFuture();
-        processedFiles = futureRef.get();
-      }
-      return processedFiles.summaries;
+      return future.get();
     }
 
     @Override
     public SummaryCollection get(long timeout, TimeUnit unit)
         throws InterruptedException, ExecutionException, TimeoutException {
-      long nanosLeft = unit.toNanos(timeout);
-      long t1, t2;
-      CompletableFuture<ProcessedFiles> futureRef = updateFuture();
-      t1 = System.nanoTime();
-      ProcessedFiles processedFiles = futureRef.get(Long.max(1, nanosLeft), TimeUnit.NANOSECONDS);
-      t2 = System.nanoTime();
-      nanosLeft -= (t2 - t1);
-      while (processedFiles.failedFiles.size() > 0) {
-        futureRef = updateFuture();
-        t1 = System.nanoTime();
-        processedFiles = futureRef.get(Long.max(1, nanosLeft), TimeUnit.NANOSECONDS);
-        t2 = System.nanoTime();
-        nanosLeft -= (t2 - t1);
-      }
-      return processedFiles.summaries;
+      return future.get(timeout, unit);
     }
 
   }
@@ -497,10 +421,7 @@ public class Gatherer {
    */
   public Future<SummaryCollection> processPartition(ExecutorService execSrv, int modulus,
       int remainder) {
-    PartitionFuture future =
-        new PartitionFuture(TraceUtil.traceInfo(), execSrv, modulus, remainder);
-    future.initiateProcessing();
-    return future;
+    return new PartitionFuture(TraceUtil.traceInfo(), execSrv, modulus, remainder);
   }
 
   public interface FileSystemResolver {
@@ -516,7 +437,8 @@ public class Gatherer {
     List<CompletableFuture<SummaryCollection>> futures = new ArrayList<>();
     for (Entry<String,List<TRowRange>> entry : files.entrySet()) {
       futures.add(CompletableFuture.supplyAsync(() -> {
-        List<RowRange> rrl = Lists.transform(entry.getValue(), RowRange::new);
+        List<RowRange> rrl =
+            entry.getValue().stream().map(RowRange::new).collect(Collectors.toList());
         return getSummaries(volMgr, entry.getKey(), rrl, summaryCache, indexCache, fileLenCache);
       }, srp));
     }
@@ -527,8 +449,8 @@ public class Gatherer {
 
   private int countFiles() {
     // TODO use a batch scanner + iterator to parallelize counting files
-    return TabletsMetadata.builder().forTable(tableId).overlapping(startRow, endRow).fetchFiles()
-        .fetchPrev().build(ctx).stream().mapToInt(tm -> tm.getFiles().size()).sum();
+    return TabletsMetadata.builder(ctx).forTable(tableId).overlapping(startRow, endRow)
+        .fetch(FILES, PREV_ROW).build().stream().mapToInt(tm -> tm.getFiles().size()).sum();
   }
 
   private class GatherRequest implements Supplier<SummaryCollection> {
@@ -551,7 +473,7 @@ public class Gatherer {
 
       TSummaries tSums;
       try {
-        tSums = ServerClient.execute(ctx, new TabletClientService.Client.Factory(), client -> {
+        tSums = ThriftClientTypes.TABLET_SERVER.execute(ctx, client -> {
           TSummaries tsr =
               client.startGetSummariesForPartition(tinfo, ctx.rpcCreds(), req, modulus, remainder);
           while (!tsr.finished && !cancelFlag.get()) {
@@ -624,8 +546,8 @@ public class Gatherer {
     private Text endRow;
 
     public RowRange(KeyExtent ke) {
-      this.startRow = ke.getPrevEndRow();
-      this.endRow = ke.getEndRow();
+      this.startRow = ke.prevEndRow();
+      this.endRow = ke.endRow();
     }
 
     public RowRange(TRowRange trr) {
