@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.util.format;
 
@@ -27,6 +29,7 @@ import org.apache.hadoop.io.Text;
 /**
  * A simple formatter that print the row, column family, column qualifier, and value as hex
  */
+@Deprecated(since = "2.1.0")
 public class HexFormatter implements Formatter, ScanInterpreter {
 
   private char[] chars =
@@ -90,7 +93,7 @@ public class HexFormatter implements Formatter, ScanInterpreter {
     sb.append(entry.getKey().getColumnVisibilityData());
     sb.append("] ");
     if (config.willPrintTimestamps()) {
-      sb.append(Long.toString(entry.getKey().getTimestamp()));
+      sb.append(entry.getKey().getTimestamp());
       sb.append("  ");
     }
     toHex(sb, entry.getValue().get());
