@@ -1,25 +1,27 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.client;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.ArrayList;
 import java.util.Iterator;
@@ -31,7 +33,7 @@ import java.util.TreeMap;
 
 import org.apache.accumulo.core.data.Key;
 import org.apache.accumulo.core.data.Value;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class RowIteratorTest {
 
@@ -40,7 +42,7 @@ public class RowIteratorTest {
     for (String s : args) {
       final String[] parts = s.split("[ \t]");
       final Key key = new Key(parts[0], parts[1], parts[2]);
-      final Value value = new Value(parts[3].getBytes());
+      final Value value = new Value(parts[3]);
       result.put(key, value);
     }
     return result.entrySet().iterator();
@@ -72,10 +74,7 @@ public class RowIteratorTest {
     assertEquals(1, rows.get(1).size());
 
     RowIterator i = new RowIterator(makeIterator());
-    try {
-      i.next();
-      fail();
-    } catch (NoSuchElementException ex) {}
+    assertThrows(NoSuchElementException.class, i::next);
 
     i = new RowIterator(makeIterator("a b c d", "a 1 2 3"));
     assertTrue(i.hasNext());
@@ -85,17 +84,11 @@ public class RowIteratorTest {
     assertTrue(row.hasNext());
     row.next();
     assertFalse(row.hasNext());
-    try {
-      row.next();
-      fail();
-    } catch (NoSuchElementException ex) {}
+    assertThrows(NoSuchElementException.class, row::next);
     assertEquals(0, i.getKVCount());
     assertFalse(i.hasNext());
     assertEquals(2, i.getKVCount());
-    try {
-      i.next();
-      fail();
-    } catch (NoSuchElementException ex) {}
+    assertThrows(NoSuchElementException.class, i::next);
   }
 
   @Test
@@ -110,13 +103,7 @@ public class RowIteratorTest {
     assertEquals(2, i.getKVCount());
     assertFalse(i.hasNext());
     assertEquals(3, i.getKVCount());
-    try {
-      firstRow.hasNext();
-      fail();
-    } catch (IllegalStateException e) {}
-    try {
-      nextRow.next();
-      fail();
-    } catch (IllegalStateException e) {}
+    assertThrows(IllegalStateException.class, firstRow::hasNext);
+    assertThrows(IllegalStateException.class, nextRow::next);
   }
 }
