@@ -1,24 +1,26 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.core.file.rfile;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.ByteArrayOutputStream;
 import java.io.DataOutputStream;
@@ -31,7 +33,7 @@ import org.apache.accumulo.core.file.blockfile.impl.CachableBlockFile;
 import org.apache.accumulo.core.file.rfile.BlockIndex.BlockIndexEntry;
 import org.apache.accumulo.core.file.rfile.MultiLevelIndex.IndexEntry;
 import org.apache.accumulo.core.spi.cache.CacheEntry;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class BlockIndexTest {
 
@@ -73,7 +75,7 @@ public class BlockIndexTest {
     for (int i = 0; i < num; i++) {
       Key key = new Key(RFileTest.formatString("", i), "cf1", "cq1");
       new RelativeKey(prevKey, key).write(out);
-      new Value(new byte[0]).write(out);
+      new Value().write(out);
       prevKey = key;
     }
 
@@ -131,21 +133,21 @@ public class BlockIndexTest {
     for (int i = 0; i < num; i++) {
       Key key = new Key(RFileTest.formatString("", 1), "cf1", "cq1");
       new RelativeKey(prevKey, key).write(out);
-      new Value(new byte[0]).write(out);
+      new Value().write(out);
       prevKey = key;
     }
 
     for (int i = 0; i < num; i++) {
       Key key = new Key(RFileTest.formatString("", 3), "cf1", "cq1");
       new RelativeKey(prevKey, key).write(out);
-      new Value(new byte[0]).write(out);
+      new Value().write(out);
       prevKey = key;
     }
 
     for (int i = 0; i < num; i++) {
       Key key = new Key(RFileTest.formatString("", 5), "cf1", "cq1");
       new RelativeKey(prevKey, key).write(out);
-      new Value(new byte[0]).write(out);
+      new Value().write(out);
       prevKey = key;
     }
 
