@@ -1,22 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.cluster.standalone;
 
 import static com.google.common.base.Preconditions.checkArgument;
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static java.util.Objects.requireNonNull;
 
 import java.io.BufferedReader;
@@ -31,11 +34,12 @@ import java.util.Map.Entry;
 import org.apache.accumulo.cluster.ClusterControl;
 import org.apache.accumulo.cluster.RemoteShell;
 import org.apache.accumulo.cluster.RemoteShellOptions;
-import org.apache.accumulo.core.master.thrift.MasterGoalState;
-import org.apache.accumulo.master.state.SetGoalState;
+import org.apache.accumulo.compactor.Compactor;
+import org.apache.accumulo.coordinator.CompactionCoordinator;
+import org.apache.accumulo.core.manager.thrift.ManagerGoalState;
+import org.apache.accumulo.manager.state.SetGoalState;
 import org.apache.accumulo.minicluster.ServerType;
 import org.apache.accumulo.server.util.Admin;
-import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.util.Shell.ExitCodeException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -52,9 +56,8 @@ public class StandaloneClusterControl implements ClusterControl {
 
   private static final String ACCUMULO_SERVICE_SCRIPT = "accumulo-service",
       ACCUMULO_SCRIPT = "accumulo";
-  private static final String MASTER_HOSTS_FILE = "masters", GC_HOSTS_FILE = "gc",
-      TSERVER_HOSTS_FILE = "tservers", TRACER_HOSTS_FILE = "tracers",
-      MONITOR_HOSTS_FILE = "monitor";
+  private static final String MANAGER_HOSTS_FILE = "managers", GC_HOSTS_FILE = "gc",
+      TSERVER_HOSTS_FILE = "tservers", MONITOR_HOSTS_FILE = "monitor";
 
   String accumuloHome;
   String clientAccumuloConfDir;
@@ -105,7 +108,7 @@ public class StandaloneClusterControl implements ClusterControl {
 
   @Override
   public Entry<Integer,String> execWithStdout(Class<?> clz, String[] args) throws IOException {
-    String master = getHosts(MASTER_HOSTS_FILE).get(0);
+    String manager = getHosts(MANAGER_HOSTS_FILE).get(0);
     List<String> cmd = new ArrayList<>();
     cmd.add(clientCmdPrefix);
     cmd.add(accumuloPath);
@@ -114,13 +117,13 @@ public class StandaloneClusterControl implements ClusterControl {
     for (String arg : args) {
       cmd.add("'" + arg + "'");
     }
-    log.info("Running: '{}' on {}", sanitize(StringUtils.join(cmd, " ")), sanitize(master));
-    return exec(master, cmd.toArray(new String[cmd.size()]));
+    log.info("Running: '{}' on {}", sanitize(String.join(" ", cmd)), sanitize(manager));
+    return exec(manager, cmd.toArray(new String[cmd.size()]));
   }
 
   /**
-   * Prevent potential CRLF injection into logs from read in user data See
-   * https://find-sec-bugs.github.io/bugs.htm#CRLF_INJECTION_LOGS
+   * Prevent potential CRLF injection into logs from read in user data. See the
+   * <a href="https://find-sec-bugs.github.io/bugs.htm#CRLF_INJECTION_LOGS">bug description</a>
    */
   private String sanitize(String msg) {
     return msg.replaceAll("[\r\n]", "");
@@ -128,10 +131,10 @@ public class StandaloneClusterControl implements ClusterControl {
 
   @Override
   public void adminStopAll() throws IOException {
-    String master = getHosts(MASTER_HOSTS_FILE).get(0);
+    String manager = getHosts(MANAGER_HOSTS_FILE).get(0);
     String[] cmd = {serverCmdPrefix, accumuloPath, Admin.class.getName(), "stopAll"};
     // Directly invoke the RemoteShell
-    Entry<Integer,String> pair = exec(master, cmd);
+    Entry<Integer,String> pair = exec(manager, cmd);
     if (pair.getKey() != 0) {
       throw new IOException("stopAll did not finish successfully, retcode=" + pair.getKey()
           + ", stdout=" + pair.getValue());
@@ -148,10 +151,10 @@ public class StandaloneClusterControl implements ClusterControl {
    */
   public void setGoalState(String goalState) throws IOException {
     requireNonNull(goalState, "Goal state must not be null");
-    checkArgument(MasterGoalState.valueOf(goalState) != null, "Unknown goal state: " + goalState);
-    String master = getHosts(MASTER_HOSTS_FILE).get(0);
+    checkArgument(ManagerGoalState.valueOf(goalState) != null, "Unknown goal state: " + goalState);
+    String manager = getHosts(MANAGER_HOSTS_FILE).get(0);
     String[] cmd = {serverCmdPrefix, accumuloPath, SetGoalState.class.getName(), goalState};
-    Entry<Integer,String> pair = exec(master, cmd);
+    Entry<Integer,String> pair = exec(manager, cmd);
     if (pair.getKey() != 0) {
       throw new IOException("SetGoalState did not finish successfully, retcode=" + pair.getKey()
           + ", stdout=" + pair.getValue());
@@ -159,6 +162,7 @@ public class StandaloneClusterControl implements ClusterControl {
   }
 
   @Override
+  @SuppressWarnings("removal")
   public void startAllServers(ServerType server) throws IOException {
     switch (server) {
       case TABLET_SERVER:
@@ -167,14 +171,15 @@ public class StandaloneClusterControl implements ClusterControl {
         }
         break;
       case MASTER:
-        for (String master : getHosts(MASTER_HOSTS_FILE)) {
-          start(server, master);
+      case MANAGER:
+        for (String manager : getHosts(MANAGER_HOSTS_FILE)) {
+          start(server, manager);
         }
         break;
       case GARBAGE_COLLECTOR:
         List<String> hosts = getHosts(GC_HOSTS_FILE);
         if (hosts.isEmpty()) {
-          hosts = getHosts(MASTER_HOSTS_FILE);
+          hosts = getHosts(MANAGER_HOSTS_FILE);
           if (hosts.isEmpty()) {
             throw new IOException("Found hosts to run garbage collector on");
           }
@@ -184,11 +189,6 @@ public class StandaloneClusterControl implements ClusterControl {
           start(server, gc);
         }
         break;
-      case TRACER:
-        for (String tracer : getHosts(TRACER_HOSTS_FILE)) {
-          start(server, tracer);
-        }
-        break;
       case MONITOR:
         for (String monitor : getHosts(MONITOR_HOSTS_FILE)) {
           start(server, monitor);
@@ -211,6 +211,7 @@ public class StandaloneClusterControl implements ClusterControl {
   }
 
   @Override
+  @SuppressWarnings("removal")
   public void stopAllServers(ServerType server) throws IOException {
     switch (server) {
       case TABLET_SERVER:
@@ -219,8 +220,9 @@ public class StandaloneClusterControl implements ClusterControl {
         }
         break;
       case MASTER:
-        for (String master : getHosts(MASTER_HOSTS_FILE)) {
-          stop(server, master);
+      case MANAGER:
+        for (String manager : getHosts(MANAGER_HOSTS_FILE)) {
+          stop(server, manager);
         }
         break;
       case GARBAGE_COLLECTOR:
@@ -228,11 +230,6 @@ public class StandaloneClusterControl implements ClusterControl {
           stop(server, gc);
         }
         break;
-      case TRACER:
-        for (String tracer : getHosts(TRACER_HOSTS_FILE)) {
-          stop(server, tracer);
-        }
-        break;
       case MONITOR:
         for (String monitor : getHosts(MONITOR_HOSTS_FILE)) {
           stop(server, monitor);
@@ -246,7 +243,7 @@ public class StandaloneClusterControl implements ClusterControl {
 
   @Override
   public void stop(ServerType server, String hostname) throws IOException {
-    // TODO Use `accumulo admin stop` for tservers, instrument clean stop for GC, monitor, tracer
+    // TODO Use `accumulo admin stop` for tservers, instrument clean stop for GC, monitor
     // instead kill
 
     kill(server, hostname);
@@ -316,6 +313,7 @@ public class StandaloneClusterControl implements ClusterControl {
         "'{print \\$2}'", "|", "head", "-1", "|", "tr", "-d", "'\\n'"};
   }
 
+  @SuppressWarnings("removal")
   protected String getProcessString(ServerType server) {
     switch (server) {
       case TABLET_SERVER:
@@ -323,9 +321,8 @@ public class StandaloneClusterControl implements ClusterControl {
       case GARBAGE_COLLECTOR:
         return "gc";
       case MASTER:
-        return "master";
-      case TRACER:
-        return "tracer";
+      case MANAGER:
+        return "manager";
       case MONITOR:
         return "monitor";
       default:
@@ -366,7 +363,7 @@ public class StandaloneClusterControl implements ClusterControl {
    * Read the provided file and return all lines which don't start with a '#' character
    */
   protected List<String> getHosts(File f) throws IOException {
-    try (BufferedReader reader = new BufferedReader(new FileReader(f))) {
+    try (BufferedReader reader = new BufferedReader(new FileReader(f, UTF_8))) {
       List<String> hosts = new ArrayList<>();
       String line;
       while ((line = reader.readLine()) != null) {
@@ -379,4 +376,16 @@ public class StandaloneClusterControl implements ClusterControl {
       return hosts;
     }
   }
+
+  @Override
+  public void startCompactors(Class<? extends Compactor> compactor, int limit, String queueName)
+      throws IOException {
+    throw new UnsupportedOperationException("Not yet implemented.");
+  }
+
+  @Override
+  public void startCoordinator(Class<? extends CompactionCoordinator> coordinator)
+      throws IOException {
+    throw new UnsupportedOperationException("Not yet implemented.");
+  }
 }
