@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.minicluster;
 
@@ -69,7 +71,9 @@ public class MiniAccumuloRunner {
   private static final String ROOT_PASSWORD_PROP = "rootPassword";
   private static final String SHUTDOWN_PORT_PROP = "shutdownPort";
   private static final String DEFAULT_MEMORY_PROP = "defaultMemory";
+  @Deprecated(since = "2.1.0")
   private static final String MASTER_MEMORY_PROP = "masterMemory";
+  private static final String MANAGER_MEMORY_PROP = "managerMemory";
   private static final String TSERVER_MEMORY_PROP = "tserverMemory";
   private static final String ZOO_KEEPER_MEMORY_PROP = "zooKeeperMemory";
   private static final String JDWP_ENABLED_PROP = "jdwpEnabled";
@@ -83,7 +87,7 @@ public class MiniAccumuloRunner {
   private static void printProperties() {
     System.out.println("#mini Accumulo cluster runner properties.");
     System.out.println("#");
-    System.out.println("#uncomment following propeties to use, propeties not"
+    System.out.println("#uncomment following properties to use, properties not"
         + " set will use default or random value");
     System.out.println();
     System.out.println("#" + INSTANCE_NAME_PROP + "=devTest");
@@ -94,7 +98,7 @@ public class MiniAccumuloRunner {
     System.out.println("#" + ZOO_KEEPER_STARTUP_TIME_PROP + "=39000");
     System.out.println("#" + SHUTDOWN_PORT_PROP + "=41414");
     System.out.println("#" + DEFAULT_MEMORY_PROP + "=128M");
-    System.out.println("#" + MASTER_MEMORY_PROP + "=128M");
+    System.out.println("#" + MANAGER_MEMORY_PROP + "=128M");
     System.out.println("#" + TSERVER_MEMORY_PROP + "=128M");
     System.out.println("#" + ZOO_KEEPER_MEMORY_PROP + "=128M");
     System.out.println("#" + JDWP_ENABLED_PROP + "=false");
@@ -103,10 +107,9 @@ public class MiniAccumuloRunner {
     System.out.println();
     System.out.println("# Configuration normally placed in accumulo.properties can be added using"
         + " a site.* prefix.");
-    System.out.println(
-        "# For example the following line will set tserver.compaction.major.concurrent.max");
+    System.out.println("# For example the following line will set tserver.compaction.major.delay");
     System.out.println();
-    System.out.println("#site.tserver.compaction.major.concurrent.max=4");
+    System.out.println("#site.tserver.compaction.major.delay=60s");
 
   }
 
@@ -131,7 +134,7 @@ public class MiniAccumuloRunner {
     }
   }
 
-  private static final String FORMAT_STRING = "  %-21s %s";
+  private static final String FORMAT_STRING = "  %-21s %s%n";
 
   public static class Opts extends Help {
     @Parameter(names = "-p", required = false, description = "properties file name",
@@ -139,7 +142,7 @@ public class MiniAccumuloRunner {
     Properties prop = new Properties();
 
     @Parameter(names = {"-c", "--printProperties"}, required = false,
-        description = "prints an example propeties file, redirect to file to use")
+        description = "prints an example properties file, redirect to file to use")
     boolean printProps = false;
   }
 
@@ -196,8 +199,12 @@ public class MiniAccumuloRunner {
     if (opts.prop.containsKey(TSERVER_MEMORY_PROP))
       setMemoryOnConfig(config, opts.prop.getProperty(TSERVER_MEMORY_PROP),
           ServerType.TABLET_SERVER);
-    if (opts.prop.containsKey(MASTER_MEMORY_PROP))
-      setMemoryOnConfig(config, opts.prop.getProperty(MASTER_MEMORY_PROP), ServerType.MASTER);
+    if (opts.prop.containsKey(MASTER_MEMORY_PROP)) {
+      log.warn("{} is deprecated. Use {} instead.", MASTER_MEMORY_PROP, MANAGER_MEMORY_PROP);
+      setMemoryOnConfig(config, opts.prop.getProperty(MASTER_MEMORY_PROP), ServerType.MANAGER);
+    }
+    if (opts.prop.containsKey(MANAGER_MEMORY_PROP))
+      setMemoryOnConfig(config, opts.prop.getProperty(MANAGER_MEMORY_PROP), ServerType.MANAGER);
     if (opts.prop.containsKey(DEFAULT_MEMORY_PROP))
       setMemoryOnConfig(config, opts.prop.getProperty(DEFAULT_MEMORY_PROP));
     if (opts.prop.containsKey(SHUTDOWN_PORT_PROP))
@@ -281,22 +288,19 @@ public class MiniAccumuloRunner {
 
   private static void printInfo(MiniAccumuloCluster accumulo, int shutdownPort) {
     System.out.println("Mini Accumulo Cluster\n");
-    System.out.println(String.format(FORMAT_STRING, "Directory:",
-        accumulo.getConfig().getDir().getAbsoluteFile()));
-    System.out.println(String.format(FORMAT_STRING, "Logs:",
-        accumulo.getConfig().getImpl().getLogDir().getAbsoluteFile()));
-    System.out.println(
-        String.format(FORMAT_STRING, "Instance Name:", accumulo.getConfig().getInstanceName()));
-    System.out.println(
-        String.format(FORMAT_STRING, "Root Password:", accumulo.getConfig().getRootPassword()));
-    System.out.println(String.format(FORMAT_STRING, "ZooKeeper:", accumulo.getZooKeepers()));
+    System.out.printf(FORMAT_STRING, "Directory:", accumulo.getConfig().getDir().getAbsoluteFile());
+    System.out.printf(FORMAT_STRING, "Logs:",
+        accumulo.getConfig().getImpl().getLogDir().getAbsoluteFile());
+    System.out.printf(FORMAT_STRING, "Instance Name:", accumulo.getConfig().getInstanceName());
+    System.out.printf(FORMAT_STRING, "Root Password:", accumulo.getConfig().getRootPassword());
+    System.out.printf(FORMAT_STRING, "ZooKeeper:", accumulo.getZooKeepers());
 
     for (Pair<ServerType,Integer> pair : accumulo.getDebugPorts()) {
-      System.out.println(String.format(FORMAT_STRING, pair.getFirst().prettyPrint() + " JDWP Host:",
-          "localhost:" + pair.getSecond()));
+      System.out.printf(FORMAT_STRING, pair.getFirst().prettyPrint() + " JDWP Host:",
+          "localhost:" + pair.getSecond());
     }
 
-    System.out.println(String.format(FORMAT_STRING, "Shutdown Port:", shutdownPort));
+    System.out.printf(FORMAT_STRING, "Shutdown Port:", shutdownPort);
 
     System.out.println();
     System.out.println("  To connect with shell, use the following command : ");
