@@ -1,22 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.client;
 
-import static org.apache.accumulo.fate.util.UtilWaitThread.sleepUninterruptibly;
+import static java.util.concurrent.TimeUnit.MINUTES;
+import static org.apache.accumulo.core.util.UtilWaitThread.sleepUninterruptibly;
 
 import java.io.IOException;
 import java.util.ArrayList;
@@ -31,45 +34,40 @@ import java.util.Map.Entry;
 import java.util.Set;
 import java.util.TreeMap;
 import java.util.concurrent.ExecutorService;
-import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
+import java.util.stream.Collectors;
 
 import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
-import org.apache.accumulo.core.client.impl.ClientContext;
-import org.apache.accumulo.core.client.impl.ServerClient;
-import org.apache.accumulo.core.client.impl.TabletLocator;
-import org.apache.accumulo.core.client.impl.TabletLocator.TabletLocation;
-import org.apache.accumulo.core.client.impl.Translator;
-import org.apache.accumulo.core.client.impl.Translators;
-import org.apache.accumulo.core.client.impl.thrift.ClientService;
-import org.apache.accumulo.core.client.impl.thrift.ThriftSecurityException;
-import org.apache.accumulo.core.client.impl.thrift.ThriftTableOperationException;
-import org.apache.accumulo.core.conf.AccumuloConfiguration;
+import org.apache.accumulo.core.clientImpl.ClientContext;
+import org.apache.accumulo.core.clientImpl.TabletLocator;
+import org.apache.accumulo.core.clientImpl.TabletLocator.TabletLocation;
+import org.apache.accumulo.core.clientImpl.bulk.BulkImport;
+import org.apache.accumulo.core.clientImpl.thrift.ClientService;
+import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.ByteSequence;
 import org.apache.accumulo.core.data.Range;
-import org.apache.accumulo.core.data.impl.KeyExtent;
-import org.apache.accumulo.core.data.thrift.TKeyExtent;
+import org.apache.accumulo.core.data.TableId;
+import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.file.FileOperations;
 import org.apache.accumulo.core.file.FileSKVIterator;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.rpc.ThriftUtil;
+import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
+import org.apache.accumulo.core.spi.crypto.CryptoService;
 import org.apache.accumulo.core.tabletserver.thrift.TabletClientService;
-import org.apache.accumulo.core.trace.Tracer;
-import org.apache.accumulo.core.util.CachedConfiguration;
+import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.core.util.HostAndPort;
-import org.apache.accumulo.core.util.NamingThreadFactory;
 import org.apache.accumulo.core.util.StopWatch;
-import org.apache.accumulo.fate.util.LoggingRunnable;
+import org.apache.accumulo.core.util.threads.ThreadPools;
+import org.apache.accumulo.server.ServerContext;
+import org.apache.accumulo.server.conf.TableConfiguration;
 import org.apache.accumulo.server.fs.VolumeManager;
-import org.apache.accumulo.server.fs.VolumeManagerImpl;
-import org.apache.accumulo.server.util.FileUtil;
-import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.Text;
-import org.apache.htrace.wrappers.TraceRunnable;
 import org.apache.thrift.TServiceClient;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -78,11 +76,9 @@ public class BulkImporter {
 
   private static final Logger log = LoggerFactory.getLogger(BulkImporter.class);
 
-  public static List<String> bulkLoad(ClientContext context, long tid, String tableId,
-      List<String> files, String errorDir, boolean setTime) throws IOException, AccumuloException,
-      AccumuloSecurityException, ThriftTableOperationException {
-    AssignmentStats stats =
-        new BulkImporter(context, tid, tableId, setTime).importFiles(files, new Path(errorDir));
+  public static List<String> bulkLoad(ServerContext context, long tid, String tableId,
+      List<String> files, boolean setTime) throws IOException {
+    AssignmentStats stats = new BulkImporter(context, tid, tableId, setTime).importFiles(files);
     List<String> result = new ArrayList<>();
     for (Path p : stats.completeFailures.keySet()) {
       result.add(p.toString());
@@ -92,24 +88,25 @@ public class BulkImporter {
 
   private StopWatch<Timers> timer;
 
-  private static enum Timers {
+  private enum Timers {
     EXAMINE_MAP_FILES, QUERY_METADATA, IMPORT_MAP_FILES, SLEEP, TOTAL
   }
 
-  private final ClientContext context;
-  private String tableId;
+  private final ServerContext context;
+  private TableId tableId;
   private long tid;
   private boolean setTime;
+  private TableConfiguration tableConf;
 
-  public BulkImporter(ClientContext context, long tid, String tableId, boolean setTime) {
+  public BulkImporter(ServerContext context, long tid, String tableId, boolean setTime) {
     this.context = context;
     this.tid = tid;
-    this.tableId = tableId;
+    this.tableId = TableId.of(tableId);
     this.setTime = setTime;
+    this.tableConf = context.getTableConfiguration(this.tableId);
   }
 
-  public AssignmentStats importFiles(List<String> files, Path failureDir) throws IOException,
-      AccumuloException, AccumuloSecurityException, ThriftTableOperationException {
+  public AssignmentStats importFiles(List<String> files) {
 
     int numThreads = context.getConfiguration().getCount(Property.TSERV_BULK_PROCESS_THREADS);
     int numAssignThreads =
@@ -118,9 +115,7 @@ public class BulkImporter {
     timer = new StopWatch<>(Timers.class);
     timer.start(Timers.TOTAL);
 
-    Configuration conf = CachedConfiguration.getInstance();
-    VolumeManagerImpl.get(context.getConfiguration());
-    final VolumeManager fs = VolumeManagerImpl.get(context.getConfiguration());
+    final VolumeManager fs = context.getVolumeManager();
 
     Set<Path> paths = new HashSet<>();
     for (String file : files) {
@@ -129,40 +124,39 @@ public class BulkImporter {
     AssignmentStats assignmentStats = new AssignmentStats(paths.size());
 
     final Map<Path,List<KeyExtent>> completeFailures =
-        Collections.synchronizedSortedMap(new TreeMap<Path,List<KeyExtent>>());
+        Collections.synchronizedSortedMap(new TreeMap<>());
 
     ClientService.Client client = null;
     final TabletLocator locator = TabletLocator.getLocator(context, tableId);
 
     try {
       final Map<Path,List<TabletLocation>> assignments =
-          Collections.synchronizedSortedMap(new TreeMap<Path,List<TabletLocation>>());
+          Collections.synchronizedSortedMap(new TreeMap<>());
 
       timer.start(Timers.EXAMINE_MAP_FILES);
-      ExecutorService threadPool =
-          Executors.newFixedThreadPool(numThreads, new NamingThreadFactory("findOverlapping"));
+      ExecutorService threadPool = ThreadPools.getServerThreadPools()
+          .createFixedThreadPool(numThreads, "findOverlapping", false);
 
       for (Path path : paths) {
         final Path mapFile = path;
-        Runnable getAssignments = new Runnable() {
-          @Override
-          public void run() {
-            List<TabletLocation> tabletsToAssignMapFileTo = Collections.emptyList();
-            try {
-              tabletsToAssignMapFileTo = findOverlappingTablets(context, fs, locator, mapFile);
-            } catch (Exception ex) {
-              log.warn("Unable to find tablets that overlap file " + mapFile.toString(), ex);
-            }
-            log.debug("Map file " + mapFile + " found to overlap " + tabletsToAssignMapFileTo.size()
-                + " tablets");
-            if (tabletsToAssignMapFileTo.size() == 0) {
-              List<KeyExtent> empty = Collections.emptyList();
-              completeFailures.put(mapFile, empty);
-            } else
-              assignments.put(mapFile, tabletsToAssignMapFileTo);
+        Runnable getAssignments = () -> {
+          List<TabletLocation> tabletsToAssignMapFileTo = Collections.emptyList();
+          try {
+            tabletsToAssignMapFileTo =
+                findOverlappingTablets(context, fs, locator, mapFile, tableConf.getCryptoService());
+          } catch (Exception ex) {
+            log.warn("Unable to find tablets that overlap file " + mapFile, ex);
           }
+          log.debug("Map file {} found to overlap {} tablets", mapFile,
+              tabletsToAssignMapFileTo.size());
+          if (tabletsToAssignMapFileTo.isEmpty()) {
+            List<KeyExtent> empty = Collections.emptyList();
+            completeFailures.put(mapFile, empty);
+          } else
+            assignments.put(mapFile, tabletsToAssignMapFileTo);
+
         };
-        threadPool.submit(new TraceRunnable(new LoggingRunnable(log, getAssignments)));
+        threadPool.execute(getAssignments);
       }
       threadPool.shutdown();
       while (!threadPool.isTerminated()) {
@@ -175,8 +169,8 @@ public class BulkImporter {
       timer.stop(Timers.EXAMINE_MAP_FILES);
 
       assignmentStats.attemptingAssignments(assignments);
-      Map<Path,List<KeyExtent>> assignmentFailures = assignMapFiles(context, conf, fs, tableId,
-          assignments, paths, numAssignThreads, numThreads);
+      Map<Path,List<KeyExtent>> assignmentFailures =
+          assignMapFiles(fs, assignments, paths, numAssignThreads, numThreads);
       assignmentStats.assignmentsFailed(assignmentFailures);
 
       Map<Path,Integer> failureCount = new TreeMap<>();
@@ -184,9 +178,9 @@ public class BulkImporter {
       for (Entry<Path,List<KeyExtent>> entry : assignmentFailures.entrySet())
         failureCount.put(entry.getKey(), 1);
 
-      long sleepTime = 2 * 1000;
-      while (assignmentFailures.size() > 0) {
-        sleepTime = Math.min(sleepTime * 2, 60 * 1000);
+      long sleepTime = 2_000;
+      while (!assignmentFailures.isEmpty()) {
+        sleepTime = Math.min(sleepTime * 2, MINUTES.toMillis(1));
         locator.invalidateCache();
         // assumption about assignment failures is that it caused by a split
         // happening or a missing location
@@ -198,8 +192,8 @@ public class BulkImporter {
         sleepUninterruptibly(sleepTime, TimeUnit.MILLISECONDS);
         timer.stop(Timers.SLEEP);
 
-        log.debug("Trying to assign " + assignmentFailures.size()
-            + " map files that previously failed on some key extents");
+        log.debug("Trying to assign {} map files that previously failed on some key extents",
+            assignmentFailures.size());
         assignments.clear();
 
         // for failed key extents, try to find children key extents to
@@ -214,8 +208,8 @@ public class BulkImporter {
 
             timer.start(Timers.QUERY_METADATA);
             try {
-              tabletsToAssignMapFileTo
-                  .addAll(findOverlappingTablets(context, fs, locator, entry.getKey(), ke));
+              tabletsToAssignMapFileTo.addAll(findOverlappingTablets(context, fs, locator,
+                  entry.getKey(), ke, tableConf.getCryptoService()));
               keListIter.remove();
             } catch (Exception ex) {
               log.warn("Exception finding overlapping tablets, will retry tablet " + ke, ex);
@@ -223,13 +217,13 @@ public class BulkImporter {
             timer.stop(Timers.QUERY_METADATA);
           }
 
-          if (tabletsToAssignMapFileTo.size() > 0)
+          if (!tabletsToAssignMapFileTo.isEmpty())
             assignments.put(entry.getKey(), tabletsToAssignMapFileTo);
         }
 
         assignmentStats.attemptingAssignments(assignments);
-        Map<Path,List<KeyExtent>> assignmentFailures2 = assignMapFiles(context, conf, fs, tableId,
-            assignments, paths, numAssignThreads, numThreads);
+        Map<Path,List<KeyExtent>> assignmentFailures2 =
+            assignMapFiles(fs, assignments, paths, numAssignThreads, numThreads);
         assignmentStats.assignmentsFailed(assignmentFailures2);
 
         // merge assignmentFailures2 into assignmentFailures
@@ -244,19 +238,13 @@ public class BulkImporter {
         }
 
         // remove map files that have no more key extents to assign
-        Iterator<Entry<Path,List<KeyExtent>>> afIter = assignmentFailures.entrySet().iterator();
-        while (afIter.hasNext()) {
-          Entry<Path,List<KeyExtent>> entry = afIter.next();
-          if (entry.getValue().size() == 0)
-            afIter.remove();
-        }
+        assignmentFailures.values().removeIf(List::isEmpty);
 
         Set<Entry<Path,Integer>> failureIter = failureCount.entrySet();
         for (Entry<Path,Integer> entry : failureIter) {
           int retries = context.getConfiguration().getCount(Property.TSERV_BULK_RETRY);
           if (entry.getValue() > retries && assignmentFailures.get(entry.getKey()) != null) {
-            log.error("Map file " + entry.getKey() + " failed more than " + retries
-                + " times, giving up.");
+            log.error("Map file {} failed more than {} times, giving up.", entry.getKey(), retries);
             completeFailures.put(entry.getKey(), assignmentFailures.get(entry.getKey()));
             assignmentFailures.remove(entry.getKey());
           }
@@ -271,7 +259,7 @@ public class BulkImporter {
       return assignmentStats;
     } finally {
       if (client != null) {
-        ServerClient.close(client);
+        ThriftUtil.close(client, context);
       }
     }
   }
@@ -291,7 +279,7 @@ public class BulkImporter {
     Collections.sort(files);
 
     log.debug("BULK IMPORT TIMING STATISTICS");
-    log.debug("Files: " + files);
+    log.debug("Files: {}", files);
     log.debug(String.format("Examine map files    : %,10.2f secs %6.2f%s",
         timer.getSecs(Timers.EXAMINE_MAP_FILES),
         100.0 * timer.get(Timers.EXAMINE_MAP_FILES) / timer.get(Timers.TOTAL), "%"));
@@ -316,7 +304,7 @@ public class BulkImporter {
 
     Set<Entry<Path,List<KeyExtent>>> es = completeFailures.entrySet();
 
-    if (completeFailures.size() == 0)
+    if (completeFailures.isEmpty())
       return Collections.emptySet();
 
     log.debug("The following map files failed ");
@@ -325,13 +313,13 @@ public class BulkImporter {
       List<KeyExtent> extents = entry.getValue();
 
       for (KeyExtent keyExtent : extents)
-        log.debug("\t" + entry.getKey() + " -> " + keyExtent);
+        log.debug("\t{} -> {}", entry.getKey(), keyExtent);
     }
 
     return Collections.emptySet();
   }
 
-  private class AssignmentInfo {
+  private static class AssignmentInfo {
     public AssignmentInfo(KeyExtent keyExtent, Long estSize) {
       this.ke = keyExtent;
       this.estSize = estSize;
@@ -348,16 +336,15 @@ public class BulkImporter {
     return result;
   }
 
-  private Map<Path,List<AssignmentInfo>> estimateSizes(final AccumuloConfiguration acuConf,
-      final Configuration conf, final VolumeManager vm, Map<Path,List<TabletLocation>> assignments,
-      Collection<Path> paths, int numThreads) {
+  private Map<Path,List<AssignmentInfo>> estimateSizes(final VolumeManager vm,
+      Map<Path,List<TabletLocation>> assignments, Collection<Path> paths, int numThreads) {
 
     long t1 = System.currentTimeMillis();
     final Map<Path,Long> mapFileSizes = new TreeMap<>();
 
     try {
       for (Path path : paths) {
-        FileSystem fs = vm.getVolumeByPath(path).getFileSystem();
+        FileSystem fs = vm.getFileSystemByPath(path);
         mapFileSizes.put(path, fs.getContentSummary(path).getLength());
       }
     } catch (IOException e) {
@@ -365,11 +352,10 @@ public class BulkImporter {
       throw new RuntimeException(e);
     }
 
-    final Map<Path,List<AssignmentInfo>> ais =
-        Collections.synchronizedMap(new TreeMap<Path,List<AssignmentInfo>>());
+    final Map<Path,List<AssignmentInfo>> ais = Collections.synchronizedMap(new TreeMap<>());
 
-    ExecutorService threadPool =
-        Executors.newFixedThreadPool(numThreads, new NamingThreadFactory("estimateSizes"));
+    ExecutorService threadPool = ThreadPools.getServerThreadPools()
+        .createFixedThreadPool(numThreads, "estimateSizes", false);
 
     for (final Entry<Path,List<TabletLocation>> entry : assignments.entrySet()) {
       if (entry.getValue().size() == 1) {
@@ -383,37 +369,38 @@ public class BulkImporter {
         continue;
       }
 
-      Runnable estimationTask = new Runnable() {
-        @Override
-        public void run() {
-          Map<KeyExtent,Long> estimatedSizes = null;
+      Runnable estimationTask = () -> {
+        Map<KeyExtent,Long> estimatedSizes = null;
 
-          try {
-            estimatedSizes = FileUtil.estimateSizes(acuConf, entry.getKey(),
-                mapFileSizes.get(entry.getKey()), extentsOf(entry.getValue()), conf, vm);
-          } catch (IOException e) {
-            log.warn("Failed to estimate map file sizes {}", e.getMessage());
-          }
+        try {
+          Path mapFile = entry.getKey();
+          FileSystem ns = context.getVolumeManager().getFileSystemByPath(mapFile);
 
-          if (estimatedSizes == null) {
-            // estimation failed, do a simple estimation
-            estimatedSizes = new TreeMap<>();
-            long estSize =
-                (long) (mapFileSizes.get(entry.getKey()) / (double) entry.getValue().size());
-            for (TabletLocation tl : entry.getValue())
-              estimatedSizes.put(tl.tablet_extent, estSize);
-          }
-
-          List<AssignmentInfo> assignmentInfoList = new ArrayList<>(estimatedSizes.size());
-
-          for (Entry<KeyExtent,Long> entry2 : estimatedSizes.entrySet())
-            assignmentInfoList.add(new AssignmentInfo(entry2.getKey(), entry2.getValue()));
-
-          ais.put(entry.getKey(), assignmentInfoList);
+          estimatedSizes = BulkImport.estimateSizes(context.getConfiguration(), mapFile,
+              mapFileSizes.get(entry.getKey()), extentsOf(entry.getValue()), ns, null,
+              tableConf.getCryptoService());
+        } catch (IOException e) {
+          log.warn("Failed to estimate map file sizes {}", e.getMessage());
         }
+
+        if (estimatedSizes == null) {
+          // estimation failed, do a simple estimation
+          estimatedSizes = new TreeMap<>();
+          long estSize =
+              (long) (mapFileSizes.get(entry.getKey()) / (double) entry.getValue().size());
+          for (TabletLocation tl : entry.getValue())
+            estimatedSizes.put(tl.tablet_extent, estSize);
+        }
+
+        List<AssignmentInfo> assignmentInfoList = new ArrayList<>(estimatedSizes.size());
+
+        for (Entry<KeyExtent,Long> entry2 : estimatedSizes.entrySet())
+          assignmentInfoList.add(new AssignmentInfo(entry2.getKey(), entry2.getValue()));
+
+        ais.put(entry.getKey(), assignmentInfoList);
       };
 
-      threadPool.submit(new TraceRunnable(new LoggingRunnable(log, estimationTask)));
+      threadPool.execute(estimationTask);
     }
 
     threadPool.shutdown();
@@ -445,18 +432,18 @@ public class BulkImporter {
     return result;
   }
 
-  private Map<Path,List<KeyExtent>> assignMapFiles(ClientContext context, Configuration conf,
-      VolumeManager fs, String tableId, Map<Path,List<TabletLocation>> assignments,
-      Collection<Path> paths, int numThreads, int numMapThreads) {
+  private Map<Path,List<KeyExtent>> assignMapFiles(VolumeManager fs,
+      Map<Path,List<TabletLocation>> assignments, Collection<Path> paths, int numThreads,
+      int numMapThreads) {
     timer.start(Timers.EXAMINE_MAP_FILES);
     Map<Path,List<AssignmentInfo>> assignInfo =
-        estimateSizes(context.getConfiguration(), conf, fs, assignments, paths, numMapThreads);
+        estimateSizes(fs, assignments, paths, numMapThreads);
     timer.stop(Timers.EXAMINE_MAP_FILES);
 
     Map<Path,List<KeyExtent>> ret;
 
     timer.start(Timers.IMPORT_MAP_FILES);
-    ret = assignMapFiles(tableId, assignInfo, locationsOf(assignments), numThreads);
+    ret = assignMapFiles(assignInfo, locationsOf(assignments), numThreads);
     timer.stop(Timers.IMPORT_MAP_FILES);
 
     return ret;
@@ -467,31 +454,23 @@ public class BulkImporter {
     HostAndPort location;
     private Map<KeyExtent,List<PathSize>> assignmentsPerTablet;
 
-    public AssignmentTask(Map<Path,List<KeyExtent>> assignmentFailures, String tableName,
-        String location, Map<KeyExtent,List<PathSize>> assignmentsPerTablet) {
+    public AssignmentTask(Map<Path,List<KeyExtent>> assignmentFailures, String location,
+        Map<KeyExtent,List<PathSize>> assignmentsPerTablet) {
       this.assignmentFailures = assignmentFailures;
       this.location = HostAndPort.fromString(location);
       this.assignmentsPerTablet = assignmentsPerTablet;
     }
 
     private void handleFailures(Collection<KeyExtent> failures, String message) {
-      for (KeyExtent ke : failures) {
+      failures.forEach(ke -> {
         List<PathSize> mapFiles = assignmentsPerTablet.get(ke);
         synchronized (assignmentFailures) {
-          for (PathSize pathSize : mapFiles) {
-            List<KeyExtent> existingFailures = assignmentFailures.get(pathSize.path);
-            if (existingFailures == null) {
-              existingFailures = new ArrayList<>();
-              assignmentFailures.put(pathSize.path, existingFailures);
-            }
-
-            existingFailures.add(ke);
-          }
+          mapFiles.forEach(pathSize -> assignmentFailures
+              .computeIfAbsent(pathSize.path, k -> new ArrayList<>()).add(ke));
         }
-
-        log.info("Could not assign {} map files to tablet {} because : {} .  Will retry ...",
+        log.info("Could not assign {} map files to tablet {} because : {}.  Will retry ...",
             mapFiles.size(), ke, message);
-      }
+      });
     }
 
     @Override
@@ -501,22 +480,20 @@ public class BulkImporter {
         for (PathSize ps : mapFiles)
           uniqMapFiles.add(ps.path);
 
-      log.debug("Assigning " + uniqMapFiles.size() + " map files to " + assignmentsPerTablet.size()
-          + " tablets at " + location);
+      log.debug("Assigning {} map files to {} tablets at {}", uniqMapFiles.size(),
+          assignmentsPerTablet.size(), location);
 
       try {
         List<KeyExtent> failures = assignMapFiles(context, location, assignmentsPerTablet);
         handleFailures(failures, "Not Serving Tablet");
-      } catch (AccumuloException e) {
-        handleFailures(assignmentsPerTablet.keySet(), e.getMessage());
-      } catch (AccumuloSecurityException e) {
+      } catch (AccumuloException | AccumuloSecurityException e) {
         handleFailures(assignmentsPerTablet.keySet(), e.getMessage());
       }
     }
 
   }
 
-  private class PathSize {
+  private static class PathSize {
     public PathSize(Path mapFile, long estSize) {
       this.path = mapFile;
       this.estSize = estSize;
@@ -531,73 +508,45 @@ public class BulkImporter {
     }
   }
 
-  private Map<Path,List<KeyExtent>> assignMapFiles(String tableName,
-      Map<Path,List<AssignmentInfo>> assignments, Map<KeyExtent,String> locations, int numThreads) {
+  private Map<Path,List<KeyExtent>> assignMapFiles(Map<Path,List<AssignmentInfo>> assignments,
+      Map<KeyExtent,String> locations, int numThreads) {
 
     // group assignments by tablet
     Map<KeyExtent,List<PathSize>> assignmentsPerTablet = new TreeMap<>();
-    for (Entry<Path,List<AssignmentInfo>> entry : assignments.entrySet()) {
-      Path mapFile = entry.getKey();
-      List<AssignmentInfo> tabletsToAssignMapFileTo = entry.getValue();
-
-      for (AssignmentInfo ai : tabletsToAssignMapFileTo) {
-        List<PathSize> mapFiles = assignmentsPerTablet.get(ai.ke);
-        if (mapFiles == null) {
-          mapFiles = new ArrayList<>();
-          assignmentsPerTablet.put(ai.ke, mapFiles);
-        }
-
-        mapFiles.add(new PathSize(mapFile, ai.estSize));
-      }
-    }
+    assignments.forEach((mapFile, tabletsToAssignMapFileTo) -> tabletsToAssignMapFileTo
+        .forEach(assignmentInfo -> assignmentsPerTablet
+            .computeIfAbsent(assignmentInfo.ke, k -> new ArrayList<>())
+            .add(new PathSize(mapFile, assignmentInfo.estSize))));
 
     // group assignments by tabletserver
 
-    Map<Path,List<KeyExtent>> assignmentFailures =
-        Collections.synchronizedMap(new TreeMap<Path,List<KeyExtent>>());
+    Map<Path,List<KeyExtent>> assignmentFailures = Collections.synchronizedMap(new TreeMap<>());
 
     TreeMap<String,Map<KeyExtent,List<PathSize>>> assignmentsPerTabletServer = new TreeMap<>();
 
-    for (Entry<KeyExtent,List<PathSize>> entry : assignmentsPerTablet.entrySet()) {
-      KeyExtent ke = entry.getKey();
+    assignmentsPerTablet.forEach((ke, pathSizes) -> {
       String location = locations.get(ke);
-
       if (location == null) {
-        for (PathSize pathSize : entry.getValue()) {
-          synchronized (assignmentFailures) {
-            List<KeyExtent> failures = assignmentFailures.get(pathSize.path);
-            if (failures == null) {
-              failures = new ArrayList<>();
-              assignmentFailures.put(pathSize.path, failures);
-            }
-
-            failures.add(ke);
-          }
+        synchronized (assignmentFailures) {
+          pathSizes.forEach(pathSize -> assignmentFailures
+              .computeIfAbsent(pathSize.path, k -> new ArrayList<>()).add(ke));
         }
-
-        log.warn("Could not assign " + entry.getValue().size() + " map files to tablet " + ke
-            + " because it had no location, will retry ...");
-
-        continue;
+        log.warn(
+            "Could not assign {} map files to tablet {} because it had no location, will retry ...",
+            pathSizes.size(), ke);
+      } else {
+        assignmentsPerTabletServer.computeIfAbsent(location, k -> new TreeMap<>()).put(ke,
+            pathSizes);
       }
-
-      Map<KeyExtent,List<PathSize>> apt = assignmentsPerTabletServer.get(location);
-      if (apt == null) {
-        apt = new TreeMap<>();
-        assignmentsPerTabletServer.put(location, apt);
-      }
-
-      apt.put(entry.getKey(), entry.getValue());
-    }
+    });
 
     ExecutorService threadPool =
-        Executors.newFixedThreadPool(numThreads, new NamingThreadFactory("submit"));
+        ThreadPools.getServerThreadPools().createFixedThreadPool(numThreads, "submit", false);
 
     for (Entry<String,Map<KeyExtent,List<PathSize>>> entry : assignmentsPerTabletServer
         .entrySet()) {
       String location = entry.getKey();
-      threadPool
-          .submit(new AssignmentTask(assignmentFailures, tableName, location, entry.getValue()));
+      threadPool.execute(new AssignmentTask(assignmentFailures, location, entry.getValue()));
     }
 
     threadPool.shutdown();
@@ -621,52 +570,55 @@ public class BulkImporter {
     try {
       long timeInMillis = context.getConfiguration().getTimeInMillis(Property.TSERV_BULK_TIMEOUT);
       TabletClientService.Iface client =
-          ThriftUtil.getTServerClient(location, context, timeInMillis);
+          ThriftUtil.getClient(ThriftClientTypes.TABLET_SERVER, location, context, timeInMillis);
       try {
-        HashMap<KeyExtent,Map<String,org.apache.accumulo.core.data.thrift.MapFileInfo>> files =
+        HashMap<KeyExtent,Map<String,org.apache.accumulo.core.dataImpl.thrift.MapFileInfo>> files =
             new HashMap<>();
         for (Entry<KeyExtent,List<PathSize>> entry : assignmentsPerTablet.entrySet()) {
-          HashMap<String,org.apache.accumulo.core.data.thrift.MapFileInfo> tabletFiles =
+          HashMap<String,org.apache.accumulo.core.dataImpl.thrift.MapFileInfo> tabletFiles =
               new HashMap<>();
           files.put(entry.getKey(), tabletFiles);
 
           for (PathSize pathSize : entry.getValue()) {
-            org.apache.accumulo.core.data.thrift.MapFileInfo mfi =
-                new org.apache.accumulo.core.data.thrift.MapFileInfo(pathSize.estSize);
+            org.apache.accumulo.core.dataImpl.thrift.MapFileInfo mfi =
+                new org.apache.accumulo.core.dataImpl.thrift.MapFileInfo(pathSize.estSize);
             tabletFiles.put(pathSize.path.toString(), mfi);
           }
         }
 
-        log.debug("Asking " + location + " to bulk load " + files);
-        List<TKeyExtent> failures = client.bulkImport(Tracer.traceInfo(), context.rpcCreds(), tid,
-            Translator.translate(files, Translators.KET), setTime);
+        log.debug("Asking {} to bulk load {}", location, files);
+        List<TKeyExtent> failures =
+            client.bulkImport(TraceUtil.traceInfo(), context.rpcCreds(), tid,
+                files.entrySet().stream()
+                    .collect(Collectors.toMap(entry -> entry.getKey().toThrift(), Entry::getValue)),
+                setTime);
 
-        return Translator.translate(failures, Translators.TKET);
+        return failures.stream().map(KeyExtent::fromThrift).collect(Collectors.toList());
       } finally {
-        ThriftUtil.returnClient((TServiceClient) client);
+        ThriftUtil.returnClient((TServiceClient) client, context);
       }
     } catch (ThriftSecurityException e) {
       throw new AccumuloSecurityException(e.user, e.code, e);
-    } catch (Throwable t) {
+    } catch (Exception t) {
       log.error("Encountered unknown exception in assignMapFiles.", t);
       throw new AccumuloException(t);
     }
   }
 
-  public static List<TabletLocation> findOverlappingTablets(ClientContext context, VolumeManager fs,
-      TabletLocator locator, Path file) throws Exception {
-    return findOverlappingTablets(context, fs, locator, file, null, null);
+  public static List<TabletLocation> findOverlappingTablets(ServerContext context, VolumeManager fs,
+      TabletLocator locator, Path file, CryptoService cs) throws Exception {
+    return findOverlappingTablets(context, fs, locator, file, null, null, cs);
   }
 
-  public static List<TabletLocation> findOverlappingTablets(ClientContext context, VolumeManager fs,
-      TabletLocator locator, Path file, KeyExtent failed) throws Exception {
+  public static List<TabletLocation> findOverlappingTablets(ServerContext context, VolumeManager fs,
+      TabletLocator locator, Path file, KeyExtent failed, CryptoService cs) throws Exception {
     locator.invalidateCache(failed);
     Text start = getStartRowForExtent(failed);
-    return findOverlappingTablets(context, fs, locator, file, start, failed.getEndRow());
+    return findOverlappingTablets(context, fs, locator, file, start, failed.endRow(), cs);
   }
 
   protected static Text getStartRowForExtent(KeyExtent extent) {
-    Text start = extent.getPrevEndRow();
+    Text start = extent.prevEndRow();
     if (start != null) {
       start = new Text(start);
       // ACCUMULO-3967 We want the first possible key in this tablet, not the following row from the
@@ -676,19 +628,19 @@ public class BulkImporter {
     return start;
   }
 
-  final static byte[] byte0 = {0};
+  static final byte[] byte0 = {0};
 
-  public static List<TabletLocation> findOverlappingTablets(ClientContext context, VolumeManager vm,
-      TabletLocator locator, Path file, Text startRow, Text endRow) throws Exception {
+  public static List<TabletLocation> findOverlappingTablets(ServerContext context, VolumeManager vm,
+      TabletLocator locator, Path file, Text startRow, Text endRow, CryptoService cs)
+      throws Exception {
     List<TabletLocation> result = new ArrayList<>();
     Collection<ByteSequence> columnFamilies = Collections.emptyList();
     String filename = file.toString();
     // log.debug(filename + " finding overlapping tablets " + startRow + " -> " + endRow);
-    FileSystem fs = vm.getVolumeByPath(file).getFileSystem();
-    FileSKVIterator reader =
-        FileOperations.getInstance().newReaderBuilder().forFile(filename, fs, fs.getConf())
-            .withTableConfiguration(context.getConfiguration()).seekToBeginning().build();
-    try {
+    FileSystem fs = vm.getFileSystemByPath(file);
+    try (FileSKVIterator reader =
+        FileOperations.getInstance().newReaderBuilder().forFile(filename, fs, fs.getConf(), cs)
+            .withTableConfiguration(context.getConfiguration()).seekToBeginning().build()) {
       Text row = startRow;
       if (row == null)
         row = new Text();
@@ -703,15 +655,13 @@ public class BulkImporter {
         TabletLocation tabletLocation = locator.locateTablet(context, row, false, true);
         // log.debug(filename + " found row " + row + " at location " + tabletLocation);
         result.add(tabletLocation);
-        row = tabletLocation.tablet_extent.getEndRow();
+        row = tabletLocation.tablet_extent.endRow();
         if (row != null && (endRow == null || row.compareTo(endRow) < 0)) {
           row = new Text(row);
           row.append(byte0, 0, byte0.length);
         } else
           break;
       }
-    } finally {
-      reader.close();
     }
     // log.debug(filename + " to be sent to " + result);
     return result;
@@ -804,7 +754,7 @@ public class BulkImporter {
       sb.append(String.format("# map files with failures : %,10d %6.2f%s%n",
           completeFailures.size(), completeFailures.size() * 100.0 / numUniqueMapFiles, "%"));
       sb.append(String.format("# failed failed map files : %,10d %s%n", failedFailures.size(),
-          failedFailures.size() > 0 ? " <-- THIS IS BAD" : ""));
+          failedFailures.isEmpty() ? "" : " <-- THIS IS BAD"));
       sb.append(String.format("# of tablets              : %,10d%n", counts.size()));
       sb.append(String.format("# tablets imported to     : %,10d %6.2f%s%n", tabletsImportedTo,
           tabletsImportedTo * 100.0 / counts.size(), "%"));
