@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.client;
 
@@ -24,47 +26,49 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Optional;
 import java.util.Set;
-import java.util.TreeSet;
+import java.util.SortedSet;
 
-import org.apache.accumulo.core.client.AccumuloException;
+import org.apache.accumulo.core.classloader.ClassLoaderUtil;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
-import org.apache.accumulo.core.client.Instance;
 import org.apache.accumulo.core.client.NamespaceNotFoundException;
 import org.apache.accumulo.core.client.TableNotFoundException;
-import org.apache.accumulo.core.client.impl.Credentials;
-import org.apache.accumulo.core.client.impl.Namespaces;
-import org.apache.accumulo.core.client.impl.Tables;
-import org.apache.accumulo.core.client.impl.thrift.ClientService;
-import org.apache.accumulo.core.client.impl.thrift.ConfigurationType;
-import org.apache.accumulo.core.client.impl.thrift.SecurityErrorCode;
-import org.apache.accumulo.core.client.impl.thrift.TDiskUsage;
-import org.apache.accumulo.core.client.impl.thrift.TableOperation;
-import org.apache.accumulo.core.client.impl.thrift.TableOperationExceptionType;
-import org.apache.accumulo.core.client.impl.thrift.ThriftSecurityException;
-import org.apache.accumulo.core.client.impl.thrift.ThriftTableOperationException;
 import org.apache.accumulo.core.client.security.tokens.AuthenticationToken;
 import org.apache.accumulo.core.client.security.tokens.KerberosToken;
 import org.apache.accumulo.core.client.security.tokens.PasswordToken;
+import org.apache.accumulo.core.clientImpl.ClientContext;
+import org.apache.accumulo.core.clientImpl.Credentials;
+import org.apache.accumulo.core.clientImpl.Namespaces;
+import org.apache.accumulo.core.clientImpl.thrift.ClientService;
+import org.apache.accumulo.core.clientImpl.thrift.ConfigurationType;
+import org.apache.accumulo.core.clientImpl.thrift.SecurityErrorCode;
+import org.apache.accumulo.core.clientImpl.thrift.TDiskUsage;
+import org.apache.accumulo.core.clientImpl.thrift.TVersionedProperties;
+import org.apache.accumulo.core.clientImpl.thrift.TableOperation;
+import org.apache.accumulo.core.clientImpl.thrift.TableOperationExceptionType;
+import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
+import org.apache.accumulo.core.clientImpl.thrift.ThriftTableOperationException;
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.Property;
+import org.apache.accumulo.core.data.NamespaceId;
+import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.master.thrift.BulkImportState;
 import org.apache.accumulo.core.master.thrift.BulkImportStatus;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.security.NamespacePermission;
 import org.apache.accumulo.core.security.SystemPermission;
 import org.apache.accumulo.core.security.TablePermission;
-import org.apache.accumulo.core.security.thrift.TCredentials;
+import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
 import org.apache.accumulo.core.trace.thrift.TInfo;
-import org.apache.accumulo.server.AccumuloServerContext;
-import org.apache.accumulo.server.conf.ServerConfigurationFactory;
-import org.apache.accumulo.server.fs.VolumeManager;
-import org.apache.accumulo.server.security.AuditedSecurityOperation;
+import org.apache.accumulo.server.ServerContext;
+import org.apache.accumulo.server.conf.store.NamespacePropKey;
+import org.apache.accumulo.server.conf.store.SystemPropKey;
+import org.apache.accumulo.server.conf.store.TablePropKey;
 import org.apache.accumulo.server.security.SecurityOperation;
 import org.apache.accumulo.server.util.ServerBulkImportStatus;
 import org.apache.accumulo.server.util.TableDiskUsage;
 import org.apache.accumulo.server.zookeeper.TransactionWatcher;
-import org.apache.accumulo.start.classloader.vfs.AccumuloVFSClassLoader;
 import org.apache.thrift.TException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -72,26 +76,21 @@ import org.slf4j.LoggerFactory;
 public class ClientServiceHandler implements ClientService.Iface {
   private static final Logger log = LoggerFactory.getLogger(ClientServiceHandler.class);
   protected final TransactionWatcher transactionWatcher;
-  private final AccumuloServerContext context;
-  private final Instance instance;
-  private final VolumeManager fs;
-  private final SecurityOperation security;
+  protected final ServerContext context;
+  protected final SecurityOperation security;
   private final ServerBulkImportStatus bulkImportStatus = new ServerBulkImportStatus();
 
-  public ClientServiceHandler(AccumuloServerContext context, TransactionWatcher transactionWatcher,
-      VolumeManager fs) {
+  public ClientServiceHandler(ServerContext context, TransactionWatcher transactionWatcher) {
     this.context = context;
-    this.instance = context.getInstance();
     this.transactionWatcher = transactionWatcher;
-    this.fs = fs;
-    this.security = AuditedSecurityOperation.getInstance(context);
+    this.security = context.getSecurityOperation();
   }
 
-  public static String checkTableId(Instance instance, String tableName, TableOperation operation)
-      throws ThriftTableOperationException {
+  public static TableId checkTableId(ClientContext context, String tableName,
+      TableOperation operation) throws ThriftTableOperationException {
     TableOperationExceptionType reason = null;
     try {
-      return Tables._getTableId(instance, tableName);
+      return context._getTableIdDetectNamespaceNotFound(tableName);
     } catch (NamespaceNotFoundException e) {
       reason = TableOperationExceptionType.NAMESPACE_NOTFOUND;
     } catch (TableNotFoundException e) {
@@ -100,16 +99,16 @@ public class ClientServiceHandler implements ClientService.Iface {
     throw new ThriftTableOperationException(null, tableName, operation, reason, null);
   }
 
-  public static String checkNamespaceId(Instance instance, String namespace,
+  public static NamespaceId checkNamespaceId(ClientContext context, String namespaceName,
       TableOperation operation) throws ThriftTableOperationException {
-    String namespaceId = Namespaces.getNameToIdMap(instance).get(namespace);
+    NamespaceId namespaceId = Namespaces.lookupNamespaceId(context, namespaceName);
     if (namespaceId == null) {
       // maybe the namespace exists, but the cache was not updated yet... so try to clear the cache
       // and check again
-      Tables.clearCache(instance);
-      namespaceId = Namespaces.getNameToIdMap(instance).get(namespace);
+      context.clearTableListCache();
+      namespaceId = Namespaces.lookupNamespaceId(context, namespaceName);
       if (namespaceId == null)
-        throw new ThriftTableOperationException(null, namespace, operation,
+        throw new ThriftTableOperationException(null, namespaceName, operation,
             TableOperationExceptionType.NAMESPACE_NOTFOUND, null);
     }
     return namespaceId;
@@ -117,23 +116,23 @@ public class ClientServiceHandler implements ClientService.Iface {
 
   @Override
   public String getInstanceId() {
-    return instance.getInstanceID();
+    return context.getInstanceID().canonical();
   }
 
   @Override
   public String getRootTabletLocation() {
-    return instance.getRootTabletLocation();
+    return context.getRootTabletLocation();
   }
 
   @Override
   public String getZooKeepers() {
-    return instance.getZooKeepers();
+    return context.getZooKeepers();
   }
 
   @Override
   public void ping(TCredentials credentials) {
     // anybody can call this; no authentication check
-    log.info("Master reports: I just got pinged!");
+    log.info("Manager reports: I just got pinged!");
   }
 
   @Override
@@ -176,7 +175,7 @@ public class ClientServiceHandler implements ClientService.Iface {
   public void createLocalUser(TInfo tinfo, TCredentials credentials, String principal,
       ByteBuffer password) throws ThriftSecurityException {
     AuthenticationToken token;
-    if (null != context.getSaslParams()) {
+    if (context.getSaslParams() != null) {
       try {
         token = new KerberosToken();
       } catch (IOException e) {
@@ -212,10 +211,10 @@ public class ClientServiceHandler implements ClientService.Iface {
   @Override
   public void grantTablePermission(TInfo tinfo, TCredentials credentials, String user,
       String tableName, byte permission) throws TException {
-    String tableId = checkTableId(instance, tableName, TableOperation.PERMISSION);
-    String namespaceId;
+    TableId tableId = checkTableId(context, tableName, TableOperation.PERMISSION);
+    NamespaceId namespaceId;
     try {
-      namespaceId = Tables.getNamespaceId(instance, tableId);
+      namespaceId = context.getNamespaceId(tableId);
     } catch (TableNotFoundException e) {
       throw new TException(e);
     }
@@ -227,7 +226,7 @@ public class ClientServiceHandler implements ClientService.Iface {
   @Override
   public void grantNamespacePermission(TInfo tinfo, TCredentials credentials, String user,
       String ns, byte permission) throws ThriftSecurityException, ThriftTableOperationException {
-    String namespaceId = checkNamespaceId(instance, ns, TableOperation.PERMISSION);
+    NamespaceId namespaceId = checkNamespaceId(context, ns, TableOperation.PERMISSION);
     security.grantNamespacePermission(credentials, user, namespaceId,
         NamespacePermission.getPermissionById(permission));
   }
@@ -242,10 +241,10 @@ public class ClientServiceHandler implements ClientService.Iface {
   @Override
   public void revokeTablePermission(TInfo tinfo, TCredentials credentials, String user,
       String tableName, byte permission) throws TException {
-    String tableId = checkTableId(instance, tableName, TableOperation.PERMISSION);
-    String namespaceId;
+    TableId tableId = checkTableId(context, tableName, TableOperation.PERMISSION);
+    NamespaceId namespaceId;
     try {
-      namespaceId = Tables.getNamespaceId(instance, tableId);
+      namespaceId = context.getNamespaceId(tableId);
     } catch (TableNotFoundException e) {
       throw new TException(e);
     }
@@ -265,7 +264,7 @@ public class ClientServiceHandler implements ClientService.Iface {
   public boolean hasTablePermission(TInfo tinfo, TCredentials credentials, String user,
       String tableName, byte tblPerm)
       throws ThriftSecurityException, ThriftTableOperationException {
-    String tableId = checkTableId(instance, tableName, TableOperation.PERMISSION);
+    TableId tableId = checkTableId(context, tableName, TableOperation.PERMISSION);
     return security.hasTablePermission(credentials, user, tableId,
         TablePermission.getPermissionById(tblPerm));
   }
@@ -273,7 +272,7 @@ public class ClientServiceHandler implements ClientService.Iface {
   @Override
   public boolean hasNamespacePermission(TInfo tinfo, TCredentials credentials, String user,
       String ns, byte perm) throws ThriftSecurityException, ThriftTableOperationException {
-    String namespaceId = checkNamespaceId(instance, ns, TableOperation.PERMISSION);
+    NamespaceId namespaceId = checkNamespaceId(context, ns, TableOperation.PERMISSION);
     return security.hasNamespacePermission(credentials, user, namespaceId,
         NamespacePermission.getPermissionById(perm));
   }
@@ -281,7 +280,7 @@ public class ClientServiceHandler implements ClientService.Iface {
   @Override
   public void revokeNamespacePermission(TInfo tinfo, TCredentials credentials, String user,
       String ns, byte permission) throws ThriftSecurityException, ThriftTableOperationException {
-    String namespaceId = checkNamespaceId(instance, ns, TableOperation.PERMISSION);
+    NamespaceId namespaceId = checkNamespaceId(context, ns, TableOperation.PERMISSION);
     security.revokeNamespacePermission(credentials, user, namespaceId,
         NamespacePermission.getPermissionById(permission));
   }
@@ -294,7 +293,6 @@ public class ClientServiceHandler implements ClientService.Iface {
 
   private Map<String,String> conf(TCredentials credentials, AccumuloConfiguration conf)
       throws TException {
-    security.authenticateUser(credentials, credentials);
     conf.invalidateCache();
 
     Map<String,String> result = new HashMap<>();
@@ -306,30 +304,102 @@ public class ClientServiceHandler implements ClientService.Iface {
     return result;
   }
 
+  private boolean checkSystemUserAndAuthenticate(TCredentials credentials)
+      throws ThriftSecurityException {
+    return security.isSystemUser(credentials)
+        && security.authenticateUser(credentials, credentials);
+  }
+
+  private void checkSystemPermission(TCredentials credentials) throws ThriftSecurityException {
+    if (!(checkSystemUserAndAuthenticate(credentials) || security.hasSystemPermission(credentials,
+        credentials.getPrincipal(), SystemPermission.SYSTEM))) {
+      throw new ThriftSecurityException(credentials.getPrincipal(),
+          SecurityErrorCode.PERMISSION_DENIED);
+    }
+  }
+
+  private void checkTablePermission(TCredentials credentials, TableId tableId,
+      TablePermission tablePermission) throws ThriftSecurityException {
+    if (!(checkSystemUserAndAuthenticate(credentials)
+        || security.hasSystemPermission(credentials, credentials.getPrincipal(),
+            SystemPermission.SYSTEM)
+        || security.hasTablePermission(credentials, credentials.getPrincipal(), tableId,
+            tablePermission))) {
+      throw new ThriftSecurityException(credentials.getPrincipal(),
+          SecurityErrorCode.PERMISSION_DENIED);
+    }
+  }
+
+  private void checkNamespacePermission(TCredentials credentials, NamespaceId namespaceId,
+      NamespacePermission namespacePermission) throws ThriftSecurityException {
+    if (!(checkSystemUserAndAuthenticate(credentials)
+        || security.hasSystemPermission(credentials, credentials.getPrincipal(),
+            SystemPermission.SYSTEM)
+        || security.hasNamespacePermission(credentials, credentials.getPrincipal(), namespaceId,
+            namespacePermission))) {
+      throw new ThriftSecurityException(credentials.getPrincipal(),
+          SecurityErrorCode.PERMISSION_DENIED);
+    }
+  }
+
   @Override
   public Map<String,String> getConfiguration(TInfo tinfo, TCredentials credentials,
       ConfigurationType type) throws TException {
-    ServerConfigurationFactory factory = context.getServerConfigurationFactory();
+    checkSystemPermission(credentials);
     switch (type) {
       case CURRENT:
-        return conf(credentials, factory.getConfiguration());
+        context.getPropStore().getCache().remove(SystemPropKey.of(context));
+        return conf(credentials, context.getConfiguration());
       case SITE:
-        return conf(credentials, factory.getSiteConfiguration());
+        return conf(credentials, context.getSiteConfiguration());
       case DEFAULT:
-        return conf(credentials, factory.getDefaultConfiguration());
+        return conf(credentials, context.getDefaultConfiguration());
     }
     throw new RuntimeException("Unexpected configuration type " + type);
   }
 
+  @Override
+  public Map<String,String> getSystemProperties(TInfo tinfo, TCredentials credentials)
+      throws ThriftSecurityException {
+    checkSystemPermission(credentials);
+    return context.getPropStore().get(SystemPropKey.of(context)).asMap();
+  }
+
+  @Override
+  public TVersionedProperties getVersionedSystemProperties(TInfo tinfo, TCredentials credentials)
+      throws ThriftSecurityException {
+    checkSystemPermission(credentials);
+    return Optional.of(context.getPropStore().get(SystemPropKey.of(context)))
+        .map(vProps -> new TVersionedProperties(vProps.getDataVersion(), vProps.asMap())).get();
+  }
+
   @Override
   public Map<String,String> getTableConfiguration(TInfo tinfo, TCredentials credentials,
       String tableName) throws TException, ThriftTableOperationException {
-    String tableId = checkTableId(instance, tableName, null);
-    AccumuloConfiguration config =
-        context.getServerConfigurationFactory().getTableConfiguration(tableId);
+    TableId tableId = checkTableId(context, tableName, null);
+    checkTablePermission(credentials, tableId, TablePermission.ALTER_TABLE);
+    context.getPropStore().getCache().remove(TablePropKey.of(context, tableId));
+    AccumuloConfiguration config = context.getTableConfiguration(tableId);
     return conf(credentials, config);
   }
 
+  @Override
+  public Map<String,String> getTableProperties(TInfo tinfo, TCredentials credentials,
+      String tableName) throws TException {
+    final TableId tableId = checkTableId(context, tableName, null);
+    checkTablePermission(credentials, tableId, TablePermission.ALTER_TABLE);
+    return context.getPropStore().get(TablePropKey.of(context, tableId)).asMap();
+  }
+
+  @Override
+  public TVersionedProperties getVersionedTableProperties(TInfo tinfo, TCredentials credentials,
+      String tableName) throws TException {
+    final TableId tableId = checkTableId(context, tableName, null);
+    checkTablePermission(credentials, tableId, TablePermission.ALTER_TABLE);
+    return Optional.of(context.getPropStore().get(TablePropKey.of(context, tableId)))
+        .map(vProps -> new TVersionedProperties(vProps.getDataVersion(), vProps.asMap())).get();
+  }
+
   @Override
   public List<String> bulkImportFiles(TInfo tinfo, final TCredentials credentials, final long tid,
       final String tableId, final List<String> files, final String errorDir, final boolean setTime)
@@ -339,11 +409,11 @@ public class ClientServiceHandler implements ClientService.Iface {
         throw new AccumuloSecurityException(credentials.getPrincipal(),
             SecurityErrorCode.PERMISSION_DENIED);
       bulkImportStatus.updateBulkImportStatus(files, BulkImportState.INITIAL);
-      log.debug("Got request to bulk import files to table(" + tableId + "): " + files);
+      log.debug("Got request to bulk import files to table({}): {}", tableId, files);
 
       bulkImportStatus.updateBulkImportStatus(files, BulkImportState.PROCESSING);
       try {
-        return BulkImporter.bulkLoad(context, tid, tableId, files, errorDir, setTime);
+        return BulkImporter.bulkLoad(context, tid, tableId, files, setTime);
       } finally {
         bulkImportStatus.removeBulkImportStatus(files);
       }
@@ -355,33 +425,23 @@ public class ClientServiceHandler implements ClientService.Iface {
   }
 
   @Override
-  public boolean isActive(TInfo tinfo, long tid) throws TException {
+  public boolean isActive(TInfo tinfo, long tid) {
     return transactionWatcher.isActive(tid);
   }
 
-  @SuppressWarnings({"rawtypes", "unchecked"})
   @Override
   public boolean checkClass(TInfo tinfo, TCredentials credentials, String className,
       String interfaceMatch) throws TException {
     security.authenticateUser(credentials, credentials);
 
     ClassLoader loader = getClass().getClassLoader();
-    Class shouldMatch;
+    Class<?> shouldMatch;
     try {
       shouldMatch = loader.loadClass(interfaceMatch);
-      Class test = AccumuloVFSClassLoader.loadClass(className, shouldMatch);
-      test.newInstance();
+      Class<?> test = ClassLoaderUtil.loadClass(className, shouldMatch);
+      test.getDeclaredConstructor().newInstance();
       return true;
-    } catch (ClassCastException e) {
-      log.warn("Error checking object types", e);
-      return false;
-    } catch (ClassNotFoundException e) {
-      log.warn("Error checking object types", e);
-      return false;
-    } catch (InstantiationException e) {
-      log.warn("Error checking object types", e);
-      return false;
-    } catch (IllegalAccessException e) {
+    } catch (ClassCastException | ReflectiveOperationException e) {
       log.warn("Error checking object types", e);
       return false;
     }
@@ -394,28 +454,16 @@ public class ClientServiceHandler implements ClientService.Iface {
 
     security.authenticateUser(credentials, credentials);
 
-    String tableId = checkTableId(instance, tableName, null);
+    TableId tableId = checkTableId(context, tableName, null);
 
     ClassLoader loader = getClass().getClassLoader();
     Class<?> shouldMatch;
     try {
       shouldMatch = loader.loadClass(interfaceMatch);
-
-      AccumuloConfiguration conf =
-          context.getServerConfigurationFactory().getTableConfiguration(tableId);
-
-      String context = conf.get(Property.TABLE_CLASSPATH);
-
-      ClassLoader currentLoader;
-
-      if (context != null && !context.equals("")) {
-        currentLoader = AccumuloVFSClassLoader.getContextManager().getClassLoader(context);
-      } else {
-        currentLoader = AccumuloVFSClassLoader.getClassLoader();
-      }
-
-      Class<?> test = currentLoader.loadClass(className).asSubclass(shouldMatch);
-      test.newInstance();
+      AccumuloConfiguration conf = context.getTableConfiguration(tableId);
+      String context = ClassLoaderUtil.tableContext(conf);
+      Class<?> test = ClassLoaderUtil.loadClass(context, className, shouldMatch);
+      test.getDeclaredConstructor().newInstance();
       return true;
     } catch (Exception e) {
       log.warn("Error checking object types", e);
@@ -430,28 +478,16 @@ public class ClientServiceHandler implements ClientService.Iface {
 
     security.authenticateUser(credentials, credentials);
 
-    String namespaceId = checkNamespaceId(instance, ns, null);
+    NamespaceId namespaceId = checkNamespaceId(context, ns, null);
 
     ClassLoader loader = getClass().getClassLoader();
     Class<?> shouldMatch;
     try {
       shouldMatch = loader.loadClass(interfaceMatch);
-
-      AccumuloConfiguration conf =
-          context.getServerConfigurationFactory().getNamespaceConfiguration(namespaceId);
-
-      String context = conf.get(Property.TABLE_CLASSPATH);
-
-      ClassLoader currentLoader;
-
-      if (context != null && !context.equals("")) {
-        currentLoader = AccumuloVFSClassLoader.getContextManager().getClassLoader(context);
-      } else {
-        currentLoader = AccumuloVFSClassLoader.getClassLoader();
-      }
-
-      Class<?> test = currentLoader.loadClass(className).asSubclass(shouldMatch);
-      test.newInstance();
+      AccumuloConfiguration conf = context.getNamespaceConfiguration(namespaceId);
+      String context = ClassLoaderUtil.tableContext(conf);
+      Class<?> test = ClassLoaderUtil.loadClass(context, className, shouldMatch);
+      test.getDeclaredConstructor().newInstance();
       return true;
     } catch (Exception e) {
       log.warn("Error checking object types", e);
@@ -463,34 +499,26 @@ public class ClientServiceHandler implements ClientService.Iface {
   public List<TDiskUsage> getDiskUsage(Set<String> tables, TCredentials credentials)
       throws ThriftTableOperationException, ThriftSecurityException, TException {
     try {
-      HashSet<String> tableIds = new HashSet<>();
+      HashSet<TableId> tableIds = new HashSet<>();
 
       for (String table : tables) {
         // ensure that table table exists
-        String tableId = checkTableId(instance, table, null);
+        TableId tableId = checkTableId(context, table, null);
         tableIds.add(tableId);
-        String namespaceId = Tables.getNamespaceId(instance, tableId);
+        NamespaceId namespaceId = context.getNamespaceId(tableId);
         if (!security.canScan(credentials, tableId, namespaceId))
           throw new ThriftSecurityException(credentials.getPrincipal(),
               SecurityErrorCode.PERMISSION_DENIED);
       }
 
       // use the same set of tableIds that were validated above to avoid race conditions
-      Map<TreeSet<String>,Long> diskUsage =
-          TableDiskUsage.getDiskUsage(context.getServerConfigurationFactory().getConfiguration(),
-              tableIds, fs, context.getConnector());
+      Map<SortedSet<String>,Long> diskUsage = TableDiskUsage.getDiskUsage(tableIds, context);
       List<TDiskUsage> retUsages = new ArrayList<>();
-      for (Map.Entry<TreeSet<String>,Long> usageItem : diskUsage.entrySet()) {
+      for (Map.Entry<SortedSet<String>,Long> usageItem : diskUsage.entrySet()) {
         retUsages.add(new TDiskUsage(new ArrayList<>(usageItem.getKey()), usageItem.getValue()));
       }
       return retUsages;
 
-    } catch (AccumuloSecurityException e) {
-      throw e.asThriftException();
-    } catch (AccumuloException e) {
-      throw new TException(e);
-    } catch (IOException e) {
-      throw new TException(e);
     } catch (TableNotFoundException e) {
       throw new TException(e);
     }
@@ -499,20 +527,55 @@ public class ClientServiceHandler implements ClientService.Iface {
   @Override
   public Map<String,String> getNamespaceConfiguration(TInfo tinfo, TCredentials credentials,
       String ns) throws ThriftTableOperationException, TException {
-    String namespaceId;
+    NamespaceId namespaceId;
     try {
-      namespaceId = Namespaces.getNamespaceId(instance, ns);
+      namespaceId = Namespaces.getNamespaceId(context, ns);
     } catch (NamespaceNotFoundException e) {
       String why = "Could not find namespace while getting configuration.";
       throw new ThriftTableOperationException(null, ns, null,
           TableOperationExceptionType.NAMESPACE_NOTFOUND, why);
     }
-    AccumuloConfiguration config =
-        context.getServerConfigurationFactory().getNamespaceConfiguration(namespaceId);
+    checkNamespacePermission(credentials, namespaceId, NamespacePermission.ALTER_NAMESPACE);
+    context.getPropStore().getCache().remove(NamespacePropKey.of(context, namespaceId));
+    AccumuloConfiguration config = context.getNamespaceConfiguration(namespaceId);
     return conf(credentials, config);
+
+  }
+
+  @Override
+  public Map<String,String> getNamespaceProperties(TInfo tinfo, TCredentials credentials, String ns)
+      throws TException {
+    NamespaceId namespaceId;
+    try {
+      namespaceId = Namespaces.getNamespaceId(context, ns);
+      checkNamespacePermission(credentials, namespaceId, NamespacePermission.ALTER_NAMESPACE);
+      return context.getPropStore().get(NamespacePropKey.of(context, namespaceId)).asMap();
+
+    } catch (NamespaceNotFoundException e) {
+      String why = "Could not find namespace while getting configuration.";
+      throw new ThriftTableOperationException(null, ns, null,
+          TableOperationExceptionType.NAMESPACE_NOTFOUND, why);
+    }
+  }
+
+  @Override
+  public TVersionedProperties getVersionedNamespaceProperties(TInfo tinfo, TCredentials credentials,
+      String ns) throws TException {
+    NamespaceId namespaceId;
+    try {
+      namespaceId = Namespaces.getNamespaceId(context, ns);
+      checkNamespacePermission(credentials, namespaceId, NamespacePermission.ALTER_NAMESPACE);
+      return Optional.of(context.getPropStore().get(NamespacePropKey.of(context, namespaceId)))
+          .map(vProps -> new TVersionedProperties(vProps.getDataVersion(), vProps.asMap())).get();
+    } catch (NamespaceNotFoundException e) {
+      String why = "Could not find namespace while getting configuration.";
+      throw new ThriftTableOperationException(null, ns, null,
+          TableOperationExceptionType.NAMESPACE_NOTFOUND, why);
+    }
   }
 
   public List<BulkImportStatus> getBulkLoadStatus() {
     return bulkImportStatus.getBulkLoadStatus();
   }
+
 }
