@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.fs;
 
@@ -21,38 +23,43 @@ import static java.util.Objects.requireNonNull;
 import java.io.IOException;
 import java.io.UncheckedIOException;
 import java.net.URI;
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.Objects;
+import java.util.Set;
+import java.util.concurrent.ExecutionException;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Future;
+import java.util.concurrent.TimeUnit;
 
 import org.apache.accumulo.core.conf.AccumuloConfiguration;
 import org.apache.accumulo.core.conf.DefaultConfiguration;
 import org.apache.accumulo.core.conf.Property;
-import org.apache.accumulo.core.data.Key;
-import org.apache.accumulo.core.data.TableId;
-import org.apache.accumulo.core.dataImpl.KeyExtent;
-import org.apache.accumulo.core.file.rfile.RFile;
-import org.apache.accumulo.core.volume.NonConfiguredVolume;
+import org.apache.accumulo.core.spi.fs.VolumeChooser;
+import org.apache.accumulo.core.util.threads.ThreadPools;
 import org.apache.accumulo.core.volume.Volume;
 import org.apache.accumulo.core.volume.VolumeConfiguration;
-import org.apache.accumulo.server.fs.VolumeChooser.VolumeChooserException;
-import org.apache.commons.lang3.ArrayUtils;
-import org.apache.commons.lang3.StringUtils;
+import org.apache.accumulo.core.volume.VolumeImpl;
 import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.fs.ContentSummary;
 import org.apache.hadoop.fs.CreateFlag;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
+import org.apache.hadoop.fs.LocatedFileStatus;
 import org.apache.hadoop.fs.Path;
+import org.apache.hadoop.fs.RemoteIterator;
 import org.apache.hadoop.fs.Trash;
 import org.apache.hadoop.fs.permission.FsPermission;
 import org.apache.hadoop.hdfs.DistributedFileSystem;
+import org.apache.hadoop.hdfs.protocol.ErasureCodingPolicy;
 import org.apache.hadoop.hdfs.protocol.HdfsConstants.SafeModeAction;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -68,17 +75,14 @@ public class VolumeManagerImpl implements VolumeManager {
 
   private final Map<String,Volume> volumesByName;
   private final Multimap<URI,Volume> volumesByFileSystemUri;
-  private final Volume defaultVolume;
   private final VolumeChooser chooser;
   private final Configuration hadoopConf;
 
-  protected VolumeManagerImpl(Map<String,Volume> volumes, Volume defaultVolume,
-      AccumuloConfiguration conf, Configuration hadoopConf) {
+  protected VolumeManagerImpl(Map<String,Volume> volumes, AccumuloConfiguration conf,
+      Configuration hadoopConf) {
     this.volumesByName = volumes;
-    this.defaultVolume = defaultVolume;
     // We may have multiple directories used in a single FileSystem (e.g. testing)
-    this.volumesByFileSystemUri = HashMultimap.create();
-    invertVolumesByFileSystem(volumesByName, volumesByFileSystemUri);
+    this.volumesByFileSystemUri = invertVolumesByFileSystem(volumesByName);
     ensureSyncIsEnabled();
     // if they supplied a property and we cannot load it, then fail hard
     VolumeChooser chooser1;
@@ -90,31 +94,27 @@ public class VolumeManagerImpl implements VolumeManager {
       // null chooser handled below
     }
     if (chooser1 == null) {
-      throw new VolumeChooserException(
+      throw new RuntimeException(
           "Failed to load volume chooser specified by " + Property.GENERAL_VOLUME_CHOOSER);
     }
     chooser = chooser1;
     this.hadoopConf = hadoopConf;
   }
 
-  private void invertVolumesByFileSystem(Map<String,Volume> forward,
-      Multimap<URI,Volume> inverted) {
-    for (Volume volume : forward.values()) {
-      inverted.put(volume.getFileSystem().getUri(), volume);
-    }
+  private Multimap<URI,Volume> invertVolumesByFileSystem(Map<String,Volume> forward) {
+    Multimap<URI,Volume> inverted = HashMultimap.create();
+    forward.values().forEach(volume -> inverted.put(volume.getFileSystem().getUri(), volume));
+    return inverted;
   }
 
-  public static org.apache.accumulo.server.fs.VolumeManager getLocal(String localBasePath)
-      throws IOException {
+  // for testing only
+  public static VolumeManager getLocalForTesting(String localBasePath) throws IOException {
     AccumuloConfiguration accConf = DefaultConfiguration.getInstance();
     Configuration hadoopConf = new Configuration();
-    Volume defaultLocalVolume =
-        VolumeConfiguration.create(FileSystem.getLocal(hadoopConf), localBasePath);
-
-    // The default volume gets placed in the map, but local filesystem is only used for testing
-    // purposes
-    return new VolumeManagerImpl(Collections.singletonMap(DEFAULT, defaultLocalVolume),
-        defaultLocalVolume, accConf, hadoopConf);
+    FileSystem localFS = FileSystem.getLocal(hadoopConf);
+    Volume defaultLocalVolume = new VolumeImpl(localFS, localBasePath);
+    return new VolumeManagerImpl(Collections.singletonMap("", defaultLocalVolume), accConf,
+        hadoopConf);
   }
 
   @Override
@@ -124,7 +124,11 @@ public class VolumeManagerImpl implements VolumeManager {
       try {
         volume.getFileSystem().close();
       } catch (IOException e) {
-        ex = e;
+        if (ex == null) {
+          ex = e;
+        } else {
+          ex.addSuppressed(e);
+        }
       }
     }
     if (ex != null) {
@@ -134,45 +138,30 @@ public class VolumeManagerImpl implements VolumeManager {
 
   @Override
   public FSDataOutputStream create(Path path) throws IOException {
-    requireNonNull(path);
-
-    Volume v = getVolumeByPath(path);
-
-    return v.getFileSystem().create(path);
+    return getFileSystemByPath(path).create(path);
   }
 
   @Override
-  public FSDataOutputStream create(Path path, boolean overwrite) throws IOException {
-    requireNonNull(path);
-
-    Volume v = getVolumeByPath(path);
-
-    return v.getFileSystem().create(path, overwrite);
+  public FSDataOutputStream overwrite(Path path) throws IOException {
+    return getFileSystemByPath(path).create(path, true);
   }
 
   private static long correctBlockSize(Configuration conf, long blockSize) {
     if (blockSize <= 0)
-      blockSize = conf.getLong("dfs.block.size", 67108864);
-
+      blockSize = conf.getLong("dfs.block.size", 67108864); // 64MB default
     int checkSum = conf.getInt("io.bytes.per.checksum", 512);
     blockSize -= blockSize % checkSum;
-    blockSize = Math.max(blockSize, checkSum);
-    return blockSize;
+    return Math.max(blockSize, checkSum);
   }
 
   private static int correctBufferSize(Configuration conf, int bufferSize) {
-    if (bufferSize <= 0)
-      bufferSize = conf.getInt("io.file.buffer.size", 4096);
-    return bufferSize;
+    return bufferSize <= 0 ? conf.getInt("io.file.buffer.size", 4096) : bufferSize;
   }
 
   @Override
   public FSDataOutputStream create(Path path, boolean overwrite, int bufferSize, short replication,
       long blockSize) throws IOException {
-    requireNonNull(path);
-
-    Volume v = getVolumeByPath(path);
-    FileSystem fs = v.getFileSystem();
+    FileSystem fs = getFileSystemByPath(path);
     blockSize = correctBlockSize(fs.getConf(), blockSize);
     bufferSize = correctBufferSize(fs.getConf(), bufferSize);
     return fs.create(path, overwrite, bufferSize, replication, blockSize);
@@ -180,17 +169,13 @@ public class VolumeManagerImpl implements VolumeManager {
 
   @Override
   public boolean createNewFile(Path path) throws IOException {
-    requireNonNull(path);
-
-    Volume v = getVolumeByPath(path);
-    return v.getFileSystem().createNewFile(path);
+    return getFileSystemByPath(path).createNewFile(path);
   }
 
   @Override
   public FSDataOutputStream createSyncable(Path logPath, int bufferSize, short replication,
       long blockSize) throws IOException {
-    Volume v = getVolumeByPath(logPath);
-    FileSystem fs = v.getFileSystem();
+    FileSystem fs = getFileSystemByPath(logPath);
     blockSize = correctBlockSize(fs.getConf(), blockSize);
     bufferSize = correctBufferSize(fs.getConf(), bufferSize);
     EnumSet<CreateFlag> set = EnumSet.of(CreateFlag.SYNC_BLOCK, CreateFlag.CREATE);
@@ -206,22 +191,22 @@ public class VolumeManagerImpl implements VolumeManager {
 
   @Override
   public boolean delete(Path path) throws IOException {
-    return getVolumeByPath(path).getFileSystem().delete(path, false);
+    return getFileSystemByPath(path).delete(path, false);
   }
 
   @Override
   public boolean deleteRecursively(Path path) throws IOException {
-    return getVolumeByPath(path).getFileSystem().delete(path, true);
+    return getFileSystemByPath(path).delete(path, true);
   }
 
   protected void ensureSyncIsEnabled() {
-    for (Entry<String,Volume> entry : getFileSystems().entrySet()) {
+    for (Entry<String,Volume> entry : volumesByName.entrySet()) {
       FileSystem fs = entry.getValue().getFileSystem();
 
       if (fs instanceof DistributedFileSystem) {
         // Avoid use of DFSConfigKeys since it's private
-        final String DFS_SUPPORT_APPEND = "dfs.support.append",
-            DFS_DATANODE_SYNCONCLOSE = "dfs.datanode.synconclose";
+        final String DFS_SUPPORT_APPEND = "dfs.support.append";
+        final String DFS_DATANODE_SYNCONCLOSE = "dfs.datanode.synconclose";
         final String ticketMessage = "See ACCUMULO-623 and ACCUMULO-1637 for more details.";
 
         // If either of these parameters are configured to be false, fail.
@@ -251,70 +236,63 @@ public class VolumeManagerImpl implements VolumeManager {
 
   @Override
   public boolean exists(Path path) throws IOException {
-    return getVolumeByPath(path).getFileSystem().exists(path);
+    return getFileSystemByPath(path).exists(path);
   }
 
   @Override
   public FileStatus getFileStatus(Path path) throws IOException {
-    return getVolumeByPath(path).getFileSystem().getFileStatus(path);
+    return getFileSystemByPath(path).getFileStatus(path);
   }
 
   @Override
-  public Volume getVolumeByPath(Path path) {
-    if (path.toString().contains(":")) {
-      try {
-        FileSystem desiredFs = path.getFileSystem(hadoopConf);
-        URI desiredFsUri = desiredFs.getUri();
-        Collection<Volume> candidateVolumes = volumesByFileSystemUri.get(desiredFsUri);
-        if (candidateVolumes != null) {
-          for (Volume candidateVolume : candidateVolumes) {
-            if (candidateVolume.isValidPath(path)) {
-              return candidateVolume;
-            }
-          }
-        } else {
-          log.debug("Could not determine volume for Path: {}", path);
-        }
-
-        return new NonConfiguredVolume(desiredFs);
-      } catch (IOException ex) {
-        throw new UncheckedIOException(ex);
-      }
+  public FileSystem getFileSystemByPath(Path path) {
+    FileSystem desiredFs;
+    try {
+      desiredFs = requireNonNull(path).getFileSystem(hadoopConf);
+    } catch (IOException ex) {
+      throw new UncheckedIOException(ex);
+    }
+    URI desiredFsUri = desiredFs.getUri();
+    Collection<Volume> candidateVolumes = volumesByFileSystemUri.get(desiredFsUri);
+    if (candidateVolumes != null) {
+      return candidateVolumes.stream().filter(volume -> volume.containsPath(path))
+          .map(Volume::getFileSystem).findFirst().orElse(desiredFs);
+    } else {
+      log.debug("Could not determine volume for Path: {}", path);
+      return desiredFs;
     }
-
-    return defaultVolume;
   }
 
-  private Map<String,Volume> getFileSystems() {
-    return volumesByName;
+  @Override
+  public RemoteIterator<LocatedFileStatus> listFiles(final Path path, final boolean recursive)
+      throws IOException {
+    return getFileSystemByPath(path).listFiles(path, recursive);
   }
 
   @Override
   public FileStatus[] listStatus(Path path) throws IOException {
-    return getVolumeByPath(path).getFileSystem().listStatus(path);
+    return getFileSystemByPath(path).listStatus(path);
   }
 
   @Override
   public boolean mkdirs(Path path) throws IOException {
-    return getVolumeByPath(path).getFileSystem().mkdirs(path);
+    return getFileSystemByPath(path).mkdirs(path);
   }
 
   @Override
   public boolean mkdirs(Path path, FsPermission permission) throws IOException {
-    return getVolumeByPath(path).getFileSystem().mkdirs(path, permission);
+    return getFileSystemByPath(path).mkdirs(path, permission);
   }
 
   @Override
   public FSDataInputStream open(Path path) throws IOException {
-    return getVolumeByPath(path).getFileSystem().open(path);
+    return getFileSystemByPath(path).open(path);
   }
 
   @Override
   public boolean rename(Path path, Path newPath) throws IOException {
-    Volume srcVolume = getVolumeByPath(path);
-    Volume destVolume = getVolumeByPath(newPath);
-    FileSystem source = srcVolume.getFileSystem();
-    FileSystem dest = destVolume.getFileSystem();
+    FileSystem source = getFileSystemByPath(path);
+    FileSystem dest = getFileSystemByPath(newPath);
     if (source != dest) {
       throw new UnsupportedOperationException(
           "Cannot rename files across volumes: " + path + " -> " + newPath);
@@ -322,57 +300,91 @@ public class VolumeManagerImpl implements VolumeManager {
     return source.rename(path, newPath);
   }
 
+  @Override
+  public void bulkRename(Map<Path,Path> oldToNewPathMap, int poolSize, String poolName,
+      String transactionId) throws IOException {
+    List<Future<Void>> results = new ArrayList<>();
+    ExecutorService workerPool =
+        ThreadPools.getServerThreadPools().createFixedThreadPool(poolSize, poolName, false);
+    oldToNewPathMap.forEach((oldPath, newPath) -> results.add(workerPool.submit(() -> {
+      boolean success;
+      try {
+        success = rename(oldPath, newPath);
+      } catch (IOException e) {
+        // The rename could have failed because this is the second time its running (failures
+        // could cause this to run multiple times).
+        if (!exists(newPath) || exists(oldPath)) {
+          throw e;
+        }
+        log.debug(
+            "Ignoring rename exception for {} because destination already exists. orig: {} new: {}",
+            transactionId, oldPath, newPath, e);
+        success = true;
+      }
+      if (!success && (!exists(newPath) || exists(oldPath))) {
+        throw new IOException("Rename operation " + transactionId + " returned false. orig: "
+            + oldPath + " new: " + newPath);
+      } else if (log.isTraceEnabled()) {
+        log.trace("{} moved {} to {}", transactionId, oldPath, newPath);
+      }
+      return null;
+    })));
+    workerPool.shutdown();
+    try {
+      while (!workerPool.awaitTermination(1000L, TimeUnit.MILLISECONDS)) {}
+      for (Future<Void> future : results) {
+        future.get();
+      }
+    } catch (InterruptedException | ExecutionException e) {
+      throw new IOException(e);
+    }
+  }
+
   @Override
   public boolean moveToTrash(Path path) throws IOException {
-    FileSystem fs = getVolumeByPath(path).getFileSystem();
+    FileSystem fs = getFileSystemByPath(path);
     Trash trash = new Trash(fs, fs.getConf());
     return trash.moveToTrash(path);
   }
 
   @Override
   public short getDefaultReplication(Path path) {
-    Volume v = getVolumeByPath(path);
-    return v.getFileSystem().getDefaultReplication(path);
+    return getFileSystemByPath(path).getDefaultReplication(path);
   }
 
-  private static final String DEFAULT = "";
-
   public static VolumeManager get(AccumuloConfiguration conf, final Configuration hadoopConf)
       throws IOException {
     final Map<String,Volume> volumes = new HashMap<>();
 
+    Set<String> volumeStrings = VolumeConfiguration.getVolumeUris(conf);
+
     // The "default" Volume for Accumulo (in case no volumes are specified)
-    for (String volumeUriOrDir : VolumeConfiguration.getVolumeUris(conf, hadoopConf)) {
-      if (volumeUriOrDir.equals(DEFAULT))
-        throw new IllegalArgumentException("Cannot re-define the default volume");
+    for (String volumeUriOrDir : volumeStrings) {
+      if (volumeUriOrDir.isBlank())
+        throw new IllegalArgumentException("Empty volume specified in configuration");
 
       if (volumeUriOrDir.startsWith("viewfs"))
         throw new IllegalArgumentException("Cannot use viewfs as a volume");
 
       // We require a URI here, fail if it doesn't look like one
       if (volumeUriOrDir.contains(":")) {
-        volumes.put(volumeUriOrDir,
-            VolumeConfiguration.create(new Path(volumeUriOrDir), hadoopConf));
+        volumes.put(volumeUriOrDir, new VolumeImpl(new Path(volumeUriOrDir), hadoopConf));
       } else {
         throw new IllegalArgumentException("Expected fully qualified URI for "
             + Property.INSTANCE_VOLUMES.getKey() + " got " + volumeUriOrDir);
       }
     }
 
-    Volume defaultVolume = VolumeConfiguration.getDefaultVolume(hadoopConf, conf);
-    return new VolumeManagerImpl(volumes, defaultVolume, conf, hadoopConf);
+    return new VolumeManagerImpl(volumes, conf, hadoopConf);
   }
 
   @Override
   public boolean isReady() throws IOException {
-    for (Volume volume : getFileSystems().values()) {
+    for (Volume volume : volumesByName.values()) {
       final FileSystem fs = volume.getFileSystem();
-
       if (!(fs instanceof DistributedFileSystem))
         continue;
-
       final DistributedFileSystem dfs = (DistributedFileSystem) fs;
-
       // Returns true when safemode is on
       if (dfs.setSafeMode(SafeModeAction.SAFEMODE_GET)) {
         return false;
@@ -383,127 +395,70 @@ public class VolumeManagerImpl implements VolumeManager {
 
   @Override
   public FileStatus[] globStatus(Path pathPattern) throws IOException {
-    return getVolumeByPath(pathPattern).getFileSystem().globStatus(pathPattern);
+    return getFileSystemByPath(pathPattern).globStatus(pathPattern);
   }
 
   @Override
-  public Path getFullPath(Key key) {
-    // TODO sanity check col fam
-    String relPath = key.getColumnQualifierData().toString();
-    byte[] tableId = KeyExtent.tableOfMetadataRow(key.getRow());
-    return getFullPath(TableId.of(new String(tableId)), relPath);
+  public Path matchingFileSystem(Path source, Set<String> options) {
+    URI sourceUri = source.toUri();
+    return options.stream().filter(opt -> {
+      URI optUri = URI.create(opt);
+      return sourceUri.getScheme().equals(optUri.getScheme())
+          && Objects.equals(sourceUri.getAuthority(), optUri.getAuthority());
+    }).map((String opt) -> new Path(opt)).findFirst().orElse(null);
   }
 
   @Override
-  public Path matchingFileSystem(Path source, String[] options) {
-    try {
-      if (ViewFSUtils.isViewFS(source, hadoopConf)) {
-        return ViewFSUtils.matchingFileSystem(source, options, hadoopConf);
-      }
-    } catch (IOException e) {
-      throw new RuntimeException(e);
-    }
-
-    URI uri1 = source.toUri();
-    for (String option : options) {
-      URI uri3 = URI.create(option);
-      if (uri1.getScheme().equals(uri3.getScheme())) {
-        String a1 = uri1.getAuthority();
-        String a2 = uri3.getAuthority();
-        if ((a1 == null && a2 == null) || (a1 != null && a1.equals(a2)))
-          return new Path(option);
-      }
-    }
-    return null;
-  }
-
-  @Override
-  public Path getFullPath(TableId tableId, String path) {
-    if (path.contains(":"))
-      return new Path(path);
-
-    if (path.startsWith("../"))
-      path = path.substring(2);
-    else if (path.startsWith("/"))
-      path = "/" + tableId.canonical() + path;
-    else
-      throw new IllegalArgumentException("Unexpected path prefix " + path);
-
-    return getFullPath(FileType.TABLE, path);
-  }
-
-  private static final String RFILE_SUFFIX = "." + RFile.EXTENSION;
-
-  @Override
-  public Path getFullPath(FileType fileType, String path) {
-    int colon = path.indexOf(':');
-    if (colon > -1) {
-      // Check if this is really an absolute path or if this is a 1.4 style relative path for a WAL
-      if (fileType == FileType.WAL && path.charAt(colon + 1) != '/') {
-        path = path.substring(path.indexOf('/'));
-      } else {
-        return new Path(path);
-      }
-    }
-
-    if (path.startsWith("/"))
-      path = path.substring(1);
-
-    // ACCUMULO-2974 To ensure that a proper absolute path is created, the caller needs to include
-    // the table ID
-    // in the relative path. Fail when this doesn't appear to happen.
-    if (fileType == FileType.TABLE) {
-      // Trailing slash doesn't create an additional element
-      String[] pathComponents = StringUtils.split(path, Path.SEPARATOR_CHAR);
-
-      // Is an rfile
-      if (path.endsWith(RFILE_SUFFIX)) {
-        if (pathComponents.length < 3) {
-          throw new IllegalArgumentException("Fewer components in file path than expected");
-        }
-      } else {
-        // is a directory
-        if (pathComponents.length < 2) {
-          throw new IllegalArgumentException("Fewer components in directory path than expected");
-        }
-      }
-    }
-
-    // normalize the path
-    Path fullPath = new Path(defaultVolume.getBasePath(), fileType.getDirectory());
-    fullPath = new Path(fullPath, path);
-
-    FileSystem fs = getVolumeByPath(fullPath).getFileSystem();
-    return fs.makeQualified(fullPath);
-  }
-
-  @Override
-  public ContentSummary getContentSummary(Path dir) throws IOException {
-    return getVolumeByPath(dir).getFileSystem().getContentSummary(dir);
-  }
-
-  @Override
-  public String choose(VolumeChooserEnvironment env, String[] options) {
+  public String choose(org.apache.accumulo.core.spi.fs.VolumeChooserEnvironment env,
+      Set<String> options) {
     final String choice;
     choice = chooser.choose(env, options);
-
-    if (!(ArrayUtils.contains(options, choice))) {
+    if (!options.contains(choice)) {
       String msg = "The configured volume chooser, '" + chooser.getClass()
           + "', or one of its delegates returned a volume not in the set of options provided";
-      throw new VolumeChooserException(msg);
+      throw new RuntimeException(msg);
     }
-
     return choice;
   }
 
   @Override
-  public Volume getDefaultVolume() {
-    return defaultVolume;
+  public Set<String> choosable(org.apache.accumulo.core.spi.fs.VolumeChooserEnvironment env,
+      Set<String> options) {
+    final Set<String> choices = chooser.choosable(env, options);
+    for (String choice : choices) {
+      if (!options.contains(choice)) {
+        String msg = "The configured volume chooser, '" + chooser.getClass()
+            + "', or one of its delegates returned a volume not in the set of options provided";
+        throw new RuntimeException(msg);
+      }
+    }
+    return choices;
+  }
+
+  @Override
+  public boolean canSyncAndFlush(Path path) {
+    // the assumption is all filesystems support sync/flush except
+    // for HDFS erasure coding. not checking hdfs config options
+    // since that's already checked in ensureSyncIsEnabled()
+    FileSystem fs = getFileSystemByPath(path);
+    if (fs instanceof DistributedFileSystem) {
+      DistributedFileSystem dfs = (DistributedFileSystem) fs;
+      try {
+        ErasureCodingPolicy currEC = dfs.getErasureCodingPolicy(path);
+        if (currEC != null && !currEC.isReplicationPolicy()) {
+          return false;
+        }
+      } catch (IOException e) {
+        // don't spam warnings...if dir doesn't exist or not EC
+        // we don't really care if the above failed
+        log.debug("exception getting EC policy for " + path, e);
+      }
+    }
+    return true;
   }
 
   @Override
   public Collection<Volume> getVolumes() {
     return volumesByName.values();
   }
-
 }
