@@ -1,34 +1,37 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
-
 package org.apache.accumulo.server.master.balancer;
 
 import static com.google.common.base.Preconditions.checkArgument;
 import static com.google.common.base.Preconditions.checkState;
+import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.LOCATION;
+import static org.apache.accumulo.core.metadata.schema.TabletMetadata.ColumnType.PREV_ROW;
 
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
+import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.Objects;
 import java.util.Set;
 import java.util.SortedMap;
 import java.util.function.Function;
@@ -36,13 +39,14 @@ import java.util.function.Function;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
 import org.apache.accumulo.core.master.thrift.TabletServerStatus;
+import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.metadata.schema.TabletsMetadata;
 import org.apache.accumulo.core.util.ComparablePair;
 import org.apache.accumulo.core.util.MapCounter;
 import org.apache.accumulo.core.util.Pair;
-import org.apache.accumulo.server.master.state.TServerInstance;
 import org.apache.accumulo.server.master.state.TabletMigration;
 import org.apache.commons.lang3.mutable.MutableInt;
+import org.slf4j.LoggerFactory;
 
 import com.google.common.collect.HashBasedTable;
 import com.google.common.collect.HashMultimap;
@@ -61,7 +65,10 @@ import com.google.common.collect.Multimap;
  * <p>
  * To use this balancer you must extend it and implement {@link #getPartitioner()}. See
  * {@link RegexGroupBalancer} as an example.
+ *
+ * @deprecated since 2.1.0. Use {@link org.apache.accumulo.core.spi.balancer.GroupBalancer} instead.
  */
+@Deprecated(since = "2.1.0")
 public abstract class GroupBalancer extends TabletBalancer {
 
   private final TableId tableId;
@@ -74,23 +81,22 @@ public abstract class GroupBalancer extends TabletBalancer {
 
   public GroupBalancer(TableId tableId) {
     this.tableId = tableId;
+
+    LoggerFactory.getLogger(getClass().getName())
+        .warn("{} has been deprecated and will be "
+            + "removed in a future release. Please update your configuration to use the equivalent "
+            + "{} instead.", getClass().getName(),
+            org.apache.accumulo.core.spi.balancer.GroupBalancer.class.getName());
+
   }
 
-  protected Iterable<Pair<KeyExtent,Location>> getLocationProvider() {
-    return () -> {
-      try {
-        return TabletsMetadata.builder().forTable(tableId).fetchLocation().fetchPrev()
-            .build(context).stream().map(tm -> {
-              Location loc = Location.NONE;
-              if (tm.hasCurrent()) {
-                loc = new Location(new TServerInstance(tm.getLocation()));
-              }
-              return new Pair<>(tm.getExtent(), loc);
-            }).iterator();
-      } catch (Exception e) {
-        throw new RuntimeException(e);
-      }
-    };
+  protected Map<KeyExtent,TServerInstance> getLocationProvider() {
+    Map<KeyExtent,TServerInstance> tablets = new LinkedHashMap<>();
+    for (var tm : TabletsMetadata.builder(context).forTable(tableId).fetch(LOCATION, PREV_ROW)
+        .build()) {
+      tablets.put(tm.getExtent(), tm.getLocation());
+    }
+    return tablets;
   }
 
   /**
@@ -118,7 +124,7 @@ public abstract class GroupBalancer extends TabletBalancer {
     }
 
     for (KeyExtent keyExtent : migrations) {
-      if (keyExtent.getTableId().equals(tableId)) {
+      if (keyExtent.tableId().equals(tableId)) {
         return false;
       }
     }
@@ -130,7 +136,7 @@ public abstract class GroupBalancer extends TabletBalancer {
   public void getAssignments(SortedMap<TServerInstance,TabletServerStatus> current,
       Map<KeyExtent,TServerInstance> unassigned, Map<KeyExtent,TServerInstance> assignments) {
 
-    if (current.size() == 0) {
+    if (current.isEmpty()) {
       return;
     }
 
@@ -142,11 +148,11 @@ public abstract class GroupBalancer extends TabletBalancer {
       if (last != null) {
         // Maintain locality
         String fakeSessionID = " ";
-        TServerInstance simple = new TServerInstance(last.getLocation(), fakeSessionID);
+        TServerInstance simple = new TServerInstance(last.getHostAndPort(), fakeSessionID);
         Iterator<TServerInstance> find = current.tailMap(simple).keySet().iterator();
         if (find.hasNext()) {
           TServerInstance tserver = find.next();
-          if (tserver.host().equals(last.host())) {
+          if (tserver.getHost().equals(last.getHost())) {
             assignments.put(entry.getKey(), tserver);
             continue;
           }
@@ -237,16 +243,16 @@ public abstract class GroupBalancer extends TabletBalancer {
     Function<KeyExtent,String> partitioner = getPartitioner();
 
     // collect stats about current state
-    for (Pair<KeyExtent,Location> entry : getLocationProvider()) {
-      String group = partitioner.apply(entry.getFirst());
-      Location loc = entry.getSecond();
+    for (var tablet : getLocationProvider().entrySet()) {
+      String group = partitioner.apply(tablet.getKey());
+      var loc = tablet.getValue();
 
-      if (loc.equals(Location.NONE) || !tservers.containsKey(loc.getTserverInstance())) {
+      if (loc == null || !tservers.containsKey(loc)) {
         return 5000;
       }
 
       groupCounts.increment(group, 1);
-      TserverGroupInfo tgi = tservers.get(loc.getTserverInstance());
+      TserverGroupInfo tgi = tservers.get(loc);
       tgi.addGroup(group);
     }
 
@@ -292,40 +298,6 @@ public abstract class GroupBalancer extends TabletBalancer {
     return 5000;
   }
 
-  public static class Location {
-    public static final Location NONE = new Location();
-    private final TServerInstance tserverInstance;
-
-    public Location() {
-      this(null);
-    }
-
-    public Location(TServerInstance tsi) {
-      tserverInstance = tsi;
-    }
-
-    public TServerInstance getTserverInstance() {
-      return tserverInstance;
-    }
-
-    @Override
-    public int hashCode() {
-      return Objects.hashCode(tserverInstance);
-    }
-
-    @Override
-    public boolean equals(Object o) {
-      if (o instanceof Location) {
-        Location ol = ((Location) o);
-        if (tserverInstance == ol.tserverInstance) {
-          return true;
-        }
-        return tserverInstance.equals(ol.tserverInstance);
-      }
-      return false;
-    }
-  }
-
   static class TserverGroupInfo {
 
     private Map<String,Integer> expectedCounts;
@@ -455,7 +427,7 @@ public abstract class GroupBalancer extends TabletBalancer {
 
     @Override
     public String toString() {
-      return tsi.toString();
+      return tsi.getHostPortSession();
     }
 
   }
@@ -505,7 +477,7 @@ public abstract class GroupBalancer extends TabletBalancer {
       move.count--;
       if (move.count == 0) {
         srcMoves.remove(srcMoves.size() - 1);
-        if (srcMoves.size() == 0) {
+        if (srcMoves.isEmpty()) {
           moves.remove(src, group);
         }
       }
@@ -534,7 +506,7 @@ public abstract class GroupBalancer extends TabletBalancer {
     ArrayList<TServerInstance> serversToRemove = new ArrayList<>();
 
     for (TserverGroupInfo destTgi : tservers.values()) {
-      if (surplusExtra.size() == 0) {
+      if (surplusExtra.isEmpty()) {
         break;
       }
 
@@ -561,7 +533,7 @@ public abstract class GroupBalancer extends TabletBalancer {
           }
         }
 
-        if (serversToRemove.size() > 0) {
+        if (!serversToRemove.isEmpty()) {
           surplusExtra.columnKeySet().removeAll(serversToRemove);
         }
 
@@ -590,7 +562,7 @@ public abstract class GroupBalancer extends TabletBalancer {
     }
 
     balanceExtraMultiple(tservers, maxExtraGroups, moves, extraMultiple, false);
-    if (moves.size() < getMaxMigrations() && extraMultiple.size() > 0) {
+    if (moves.size() < getMaxMigrations() && !extraMultiple.isEmpty()) {
       // no place to move so must exceed maxExtra temporarily... subsequent balancer calls will
       // smooth things out
       balanceExtraMultiple(tservers, maxExtraGroups, moves, extraMultiple, true);
@@ -634,7 +606,7 @@ public abstract class GroupBalancer extends TabletBalancer {
           extraMultiple.remove(pair.getFirst(), pair.getSecond());
         }
 
-        if (extraMultiple.size() == 0 || moves.size() >= getMaxMigrations()) {
+        if (extraMultiple.isEmpty() || moves.size() >= getMaxMigrations()) {
           break;
         }
       }
@@ -658,7 +630,7 @@ public abstract class GroupBalancer extends TabletBalancer {
     ArrayList<TServerInstance> emptyServers = new ArrayList<>();
     ArrayList<Pair<String,TServerInstance>> emptyServerGroups = new ArrayList<>();
     for (TserverGroupInfo destTgi : tservers.values()) {
-      if (extraSurplus.size() == 0) {
+      if (extraSurplus.isEmpty()) {
         break;
       }
 
@@ -693,7 +665,7 @@ public abstract class GroupBalancer extends TabletBalancer {
           }
         }
 
-        if (emptyServers.size() > 0) {
+        if (!emptyServers.isEmpty()) {
           extraSurplus.columnKeySet().removeAll(emptyServers);
         }
 
@@ -758,18 +730,18 @@ public abstract class GroupBalancer extends TabletBalancer {
 
     Function<KeyExtent,String> partitioner = getPartitioner();
 
-    for (Pair<KeyExtent,Location> entry : getLocationProvider()) {
-      String group = partitioner.apply(entry.getFirst());
-      Location loc = entry.getSecond();
+    for (var tablet : getLocationProvider().entrySet()) {
+      String group = partitioner.apply(tablet.getKey());
+      var loc = tablet.getValue();
 
-      if (loc.equals(Location.NONE) || !current.contains(loc.getTserverInstance())) {
+      if (loc == null || !current.contains(loc)) {
         migrationsOut.clear();
         return;
       }
 
-      TServerInstance dest = moves.removeMove(loc.getTserverInstance(), group);
+      TServerInstance dest = moves.removeMove(loc, group);
       if (dest != null) {
-        migrationsOut.add(new TabletMigration(entry.getFirst(), loc.getTserverInstance(), dest));
+        migrationsOut.add(new TabletMigration(tablet.getKey(), loc, dest));
         if (moves.size() == 0) {
           break;
         }
