@@ -1,21 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.master.balancer;
 
+import static java.util.stream.Collectors.toList;
+
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
@@ -27,22 +31,26 @@ import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
 import org.apache.accumulo.core.conf.Property;
 import org.apache.accumulo.core.data.TableId;
 import org.apache.accumulo.core.dataImpl.KeyExtent;
+import org.apache.accumulo.core.manager.balancer.AssignmentParamsImpl;
+import org.apache.accumulo.core.manager.balancer.BalanceParamsImpl;
 import org.apache.accumulo.core.master.thrift.TabletServerStatus;
+import org.apache.accumulo.core.metadata.TServerInstance;
 import org.apache.accumulo.core.rpc.ThriftUtil;
-import org.apache.accumulo.core.tabletserver.thrift.TabletClientService;
+import org.apache.accumulo.core.rpc.clients.ThriftClientTypes;
+import org.apache.accumulo.core.spi.balancer.BalancerEnvironment;
 import org.apache.accumulo.core.tabletserver.thrift.TabletClientService.Client;
 import org.apache.accumulo.core.tabletserver.thrift.TabletStats;
 import org.apache.accumulo.core.trace.TraceUtil;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.conf.ServerConfigurationFactory;
-import org.apache.accumulo.server.master.state.TServerInstance;
+import org.apache.accumulo.server.manager.balancer.BalancerEnvironmentImpl;
 import org.apache.accumulo.server.master.state.TabletMigration;
 import org.apache.thrift.TException;
 import org.apache.thrift.transport.TTransportException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import com.google.common.collect.Iterables;
+import edu.umd.cs.findbugs.annotations.SuppressFBWarnings;
 
 /**
  * This class is responsible for managing the distribution of tablets throughout an Accumulo
@@ -54,20 +62,48 @@ import com.google.common.collect.Iterables;
  * Implementations may wish to store configuration in Accumulo's system configuration using the
  * {@link Property#GENERAL_ARBITRARY_PROP_PREFIX}. They may also benefit from using per-table
  * configuration using {@link Property#TABLE_ARBITRARY_PROP_PREFIX}.
+ *
+ * @deprecated since 2.1.0. Use {@link org.apache.accumulo.core.spi.balancer.TabletBalancer}
+ *             instead.
  */
-public abstract class TabletBalancer {
+@Deprecated(since = "2.1.0")
+@SuppressFBWarnings(value = "NM_SAME_SIMPLE_NAME_AS_INTERFACE",
+    justification = "Class is deprecated and will be removed.")
+public abstract class TabletBalancer
+    implements org.apache.accumulo.core.spi.balancer.TabletBalancer {
 
   private static final Logger log = LoggerFactory.getLogger(TabletBalancer.class);
 
   protected ServerContext context;
 
+  @Override
+  public void init(BalancerEnvironment balancerEnvironment) {
+    var bei = (BalancerEnvironmentImpl) balancerEnvironment;
+    init(bei.getContext());
+  }
+
+  @Override
+  public void getAssignments(AssignmentParameters params) {
+    AssignmentParamsImpl api = (AssignmentParamsImpl) params;
+    getAssignments(api.thriftCurrentStatus(), api.thriftUnassigned(), api.thriftAssignmentsOut());
+  }
+
+  @Override
+  public long balance(BalanceParameters params) {
+    BalanceParamsImpl bpi = (BalanceParamsImpl) params;
+    List<TabletMigration> migrationsOut = new ArrayList<>();
+    long result = balance(bpi.thriftCurrentStatus(), bpi.thriftCurrentMigrations(), migrationsOut);
+    migrationsOut.forEach(mo -> bpi.addMigration(mo.tablet, mo.oldServer, mo.newServer));
+    return result;
+  }
+
   /**
    * Initialize the TabletBalancer. This gives the balancer the opportunity to read the
    * configuration.
    *
    * @deprecated since 2.0.0; use {@link #init(ServerContext)} instead.
    */
-  @Deprecated
+  @Deprecated(since = "2.0.0")
   public void init(ServerConfigurationFactory conf) {
     init(conf.getServerContext());
   }
@@ -83,7 +119,7 @@ public abstract class TabletBalancer {
   }
 
   /**
-   * Assign tablets to tablet servers. This method is called whenever the master finds tablets that
+   * Assign tablets to tablet servers. This method is called whenever the manager finds tablets that
    * are unassigned.
    *
    * @param current
@@ -177,12 +213,8 @@ public abstract class TabletBalancer {
     @Override
     public void run() {
       balancerLog.warn("Not balancing due to {} outstanding migrations.", migrations.size());
-      /*
-       * TODO ACCUMULO-2938 redact key extents in this output to avoid leaking protected
-       * information.
-       */
       balancerLog.debug("Sample up to 10 outstanding migrations: {}",
-          Iterables.limit(migrations, 10));
+          migrations.stream().limit(10).collect(toList()));
     }
   }
 
@@ -191,14 +223,14 @@ public abstract class TabletBalancer {
    * provided logging handler more often than TIME_BETWEEN_BALANCER_WARNINGS
    */
   protected void constraintNotMet(BalancerProblem cause) {
-    if (!stuck) {
-      stuck = true;
-      stuckNotificationTime = System.currentTimeMillis();
-    } else {
+    if (stuck) {
       if ((System.currentTimeMillis() - stuckNotificationTime) > TIME_BETWEEN_BALANCER_WARNINGS) {
         cause.run();
         stuckNotificationTime = System.currentTimeMillis();
       }
+    } else {
+      stuck = true;
+      stuckNotificationTime = System.currentTimeMillis();
     }
   }
 
@@ -226,14 +258,14 @@ public abstract class TabletBalancer {
   public List<TabletStats> getOnlineTabletsForTable(TServerInstance tserver, TableId tableId)
       throws ThriftSecurityException, TException {
     log.debug("Scanning tablet server {} for table {}", tserver, tableId);
-    Client client = ThriftUtil.getClient(new TabletClientService.Client.Factory(),
-        tserver.getLocation(), context);
+    Client client =
+        ThriftUtil.getClient(ThriftClientTypes.TABLET_SERVER, tserver.getHostAndPort(), context);
     try {
       return client.getTabletStats(TraceUtil.traceInfo(), context.rpcCreds(), tableId.canonical());
     } catch (TTransportException e) {
       log.error("Unable to connect to {}: ", tserver, e);
     } finally {
-      ThriftUtil.returnClient(client);
+      ThriftUtil.returnClient(client, context);
     }
     return null;
   }
