@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.replication;
 
@@ -26,6 +28,7 @@ import org.apache.accumulo.server.zookeeper.DistributedWorkQueue;
 
 import com.google.common.collect.Maps;
 
+@Deprecated
 public class DistributedWorkQueueWorkAssignerHelper {
 
   public static final String KEY_SEPARATOR = "|";
@@ -70,7 +73,7 @@ public class DistributedWorkQueueWorkAssignerHelper {
     int thirdIndex = queueKey.indexOf(KEY_SEPARATOR, secondIndex + 1);
     if (thirdIndex == -1) {
       throw new IllegalArgumentException(
-          "Could not find expected seperator in queue key '" + queueKey + "'");
+          "Could not find expected separator in queue key '" + queueKey + "'");
     }
 
     return Maps.immutableEntry(filename,
