@@ -1,33 +1,33 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.security;
 
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
+import java.util.Set;
+import java.util.stream.Collectors;
 
 import org.apache.accumulo.core.client.TableNotFoundException;
 import org.apache.accumulo.core.clientImpl.Credentials;
-import org.apache.accumulo.core.clientImpl.Tables;
-import org.apache.accumulo.core.clientImpl.Translator;
 import org.apache.accumulo.core.clientImpl.thrift.ThriftSecurityException;
 import org.apache.accumulo.core.data.Column;
 import org.apache.accumulo.core.data.NamespaceId;
@@ -38,7 +38,7 @@ import org.apache.accumulo.core.dataImpl.thrift.IterInfo;
 import org.apache.accumulo.core.dataImpl.thrift.TColumn;
 import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.TRange;
-import org.apache.accumulo.core.master.thrift.FateOperation;
+import org.apache.accumulo.core.manager.thrift.FateOperation;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.security.SystemPermission;
@@ -64,17 +64,9 @@ public class AuditedSecurityOperation extends SecurityOperation {
     super(context, author, authent, pm);
   }
 
-  public static synchronized SecurityOperation getInstance(ServerContext context) {
-    if (instance == null) {
-      instance = new AuditedSecurityOperation(context, getAuthorizor(context),
-          getAuthenticator(context), getPermHandler(context));
-    }
-    return instance;
-  }
-
   private String getTableName(TableId tableId) {
     try {
-      return Tables.getTableName(context, tableId);
+      return context.getTableName(tableId);
     } catch (TableNotFoundException e) {
       return "Unknown Table with ID " + tableId;
     }
@@ -129,7 +121,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_SCAN_AUDIT_TEMPLATE =
-      "action: scan;" + " targetTable: %s; authorizations: %s; range: %s; columns: %s;"
+      "action: scan; targetTable: %s; authorizations: %s; range: %s; columns: %s;"
           + " iterators: %s; iteratorOptions: %s;";
   private static final int MAX_ELEMENTS_TO_LOG = 10;
 
@@ -154,7 +146,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
     if (shouldAudit(credentials, tableId)) {
       Range convertedRange = new Range(range);
       List<String> convertedColumns =
-          truncate(Translator.translate(columns, new Translator.TColumnTranslator()));
+          truncate(columns.stream().map(Column::new).collect(Collectors.toList()));
       String tableName = getTableName(tableId);
 
       try {
@@ -174,7 +166,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_SCAN_BATCH_AUDIT_TEMPLATE =
-      "action: scan;" + " targetTable: %s; authorizations: %s; range: %s; columns: %s;"
+      "action: scan; targetTable: %s; authorizations: %s; range: %s; columns: %s;"
           + " iterators: %s; iteratorOptions: %s;";
 
   @Override
@@ -183,16 +175,15 @@ public class AuditedSecurityOperation extends SecurityOperation {
       Map<String,Map<String,String>> ssio, List<ByteBuffer> authorizations)
       throws ThriftSecurityException {
     if (shouldAudit(credentials, tableId)) {
-      @SuppressWarnings({"unchecked", "rawtypes"})
-      Map<KeyExtent,List<Range>> convertedBatch =
-          Translator.translate(tbatch, new Translator.TKeyExtentTranslator(),
-              new Translator.ListTranslator(new Translator.TRangeTranslator()));
-      Map<KeyExtent,List<String>> truncated = new HashMap<>();
-      for (Entry<KeyExtent,List<Range>> entry : convertedBatch.entrySet()) {
-        truncated.put(entry.getKey(), truncate(entry.getValue()));
-      }
+
+      // @formatter:off
+      Map<KeyExtent, List<String>> truncated = tbatch.entrySet().stream().collect(Collectors.toMap(
+                      entry -> KeyExtent.fromThrift(entry.getKey()),
+                      entry -> truncate(entry.getValue().stream().map(Range::new).collect(Collectors.toList()))
+      ));
+      // @formatter:on
       List<Column> convertedColumns =
-          Translator.translate(tcolumns, new Translator.TColumnTranslator());
+          tcolumns.stream().map(Column::new).collect(Collectors.toList());
       String tableName = getTableName(tableId);
 
       try {
@@ -212,7 +203,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CHANGE_AUTHORIZATIONS_AUDIT_TEMPLATE =
-      "action:" + " changeAuthorizations; targetUser: %s; authorizations: %s";
+      "action: changeAuthorizations; targetUser: %s; authorizations: %s";
 
   @Override
   public void changeAuthorizations(TCredentials credentials, String user,
@@ -227,7 +218,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CHANGE_PASSWORD_AUDIT_TEMPLATE =
-      "action:" + " changePassword; targetUser: %s;";
+      "action: changePassword; targetUser: %s;";
 
   @Override
   public void changePassword(TCredentials credentials, Credentials newInfo)
@@ -242,7 +233,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CREATE_USER_AUDIT_TEMPLATE =
-      "action: createUser;" + " targetUser: %s; Authorizations: %s;";
+      "action: createUser; targetUser: %s; Authorizations: %s;";
 
   @Override
   public void createUser(TCredentials credentials, Credentials newUser,
@@ -257,7 +248,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_CREATE_TABLE_AUDIT_TEMPLATE =
-      "action:" + " createTable; targetTable: %s;";
+      "action: createTable; targetTable: %s;";
 
   @Override
   public boolean canCreateTable(TCredentials c, String tableName, NamespaceId namespaceId)
@@ -273,7 +264,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_DELETE_TABLE_AUDIT_TEMPLATE =
-      "action:" + " deleteTable; targetTable: %s;";
+      "action: deleteTable; targetTable: %s:%s";
 
   @Override
   public boolean canDeleteTable(TCredentials c, TableId tableId, NamespaceId namespaceId)
@@ -290,7 +281,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_RENAME_TABLE_AUDIT_TEMPLATE =
-      "action:" + " renameTable; targetTable: %s; newTableName: %s;";
+      "action: renameTable; targetTable: %s; newTableName: %s;";
 
   @Override
   public boolean canRenameTable(TCredentials c, TableId tableId, String oldTableName,
@@ -306,7 +297,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_SPLIT_TABLE_AUDIT_TEMPLATE =
-      "action:" + " splitTable; targetTable: %s; targetNamespace: %s;";
+      "action: splitTable; targetTable: %s; targetNamespace: %s;";
 
   @Override
   public boolean canSplitTablet(TCredentials credentials, TableId table, NamespaceId namespaceId)
@@ -322,7 +313,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_PERFORM_SYSTEM_ACTION_AUDIT_TEMPLATE =
-      "action:" + " performSystemAction; principal: %s;";
+      "action: performSystemAction; principal: %s;";
 
   @Override
   public boolean canPerformSystemActions(TCredentials credentials) throws ThriftSecurityException {
@@ -338,7 +329,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_FLUSH_TABLE_AUDIT_TEMPLATE =
-      "action:" + " flushTable; targetTable: %s; targetNamespace: %s;";
+      "action: flushTable; targetTable: %s; targetNamespace: %s;";
 
   @Override
   public boolean canFlush(TCredentials c, TableId tableId, NamespaceId namespaceId)
@@ -354,7 +345,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_ALTER_TABLE_AUDIT_TEMPLATE =
-      "action:" + " alterTable; targetTable: %s; targetNamespace: %s;";
+      "action: alterTable; targetTable: %s; targetNamespace: %s;";
 
   @Override
   public boolean canAlterTable(TCredentials c, TableId tableId, NamespaceId namespaceId)
@@ -370,7 +361,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_CLONE_TABLE_AUDIT_TEMPLATE =
-      "action:" + " cloneTable; targetTable: %s; newTableName: %s";
+      "action: cloneTable; targetTable: %s; newTableName: %s";
 
   @Override
   public boolean canCloneTable(TCredentials c, TableId tableId, String tableName,
@@ -389,7 +380,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_DELETE_RANGE_AUDIT_TEMPLATE =
-      "action:" + " deleteData; targetTable: %s; startRange: %s; endRange: %s;";
+      "action: deleteData; targetTable: %s; startRange: %s; endRange: %s;";
 
   @Override
   public boolean canDeleteRange(TCredentials c, TableId tableId, String tableName, Text startRow,
@@ -407,7 +398,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_BULK_IMPORT_AUDIT_TEMPLATE =
-      "action:" + " bulkImport; targetTable: %s; dataDir: %s; failDir: %s;";
+      "action: bulkImport; targetTable: %s; dataDir: %s; failDir: %s;";
 
   @Override
   public boolean canBulkImport(TCredentials c, TableId tableId, String tableName, String dir,
@@ -423,7 +414,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_COMPACT_TABLE_AUDIT_TEMPLATE =
-      "action:" + " compactTable; targetTable: %s; targetNamespace: %s;";
+      "action: compactTable; targetTable: %s; targetNamespace: %s;";
 
   @Override
   public boolean canCompact(TCredentials c, TableId tableId, NamespaceId namespaceId)
@@ -439,7 +430,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_CHANGE_AUTHORIZATIONS_AUDIT_TEMPLATE =
-      "action:" + " changeAuthorizations; targetUser: %s;";
+      "action: changeAuthorizations; targetUser: %s;";
 
   @Override
   public boolean canChangeAuthorizations(TCredentials c, String user)
@@ -455,7 +446,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_CHANGE_PASSWORD_AUDIT_TEMPLATE =
-      "action:" + " changePassword; targetUser: %s;";
+      "action: changePassword; targetUser: %s;";
 
   @Override
   public boolean canChangePassword(TCredentials c, String user) throws ThriftSecurityException {
@@ -499,7 +490,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_GRANT_SYSTEM_AUDIT_TEMPLATE =
-      "action:" + " grantSystem; targetUser: %s; targetPermission: %s;";
+      "action: grantSystem; targetUser: %s; targetPermission: %s;";
 
   @Override
   public boolean canGrantSystem(TCredentials c, String user, SystemPermission sysPerm)
@@ -517,7 +508,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_GRANT_TABLE_AUDIT_TEMPLATE =
-      "action:" + " grantTable; targetUser: %s; targetTable: %s; targetNamespace: %s;";
+      "action: grantTable; targetUser: %s; targetTable: %s; targetNamespace: %s;";
 
   @Override
   public boolean canGrantTable(TCredentials c, String user, TableId table, NamespaceId namespaceId)
@@ -533,7 +524,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_REVOKE_SYSTEM_AUDIT_TEMPLATE =
-      "action:" + " revokeSystem; targetUser: %s;, targetPermission: %s;";
+      "action: revokeSystem; targetUser: %s;, targetPermission: %s;";
 
   @Override
   public boolean canRevokeSystem(TCredentials c, String user, SystemPermission sysPerm)
@@ -549,7 +540,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_REVOKE_TABLE_AUDIT_TEMPLATE =
-      "action:" + " revokeTable; targetUser: %s; targetTable %s; targetNamespace: %s;";
+      "action: revokeTable; targetUser: %s; targetTable %s; targetNamespace: %s;";
 
   @Override
   public boolean canRevokeTable(TCredentials c, String user, TableId table, NamespaceId namespaceId)
@@ -565,24 +556,24 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_IMPORT_AUDIT_TEMPLATE =
-      "action: import;" + " targetTable: %s; dataDir: %s;";
+      "action: import; targetTable: %s; dataDir: %s;";
 
   @Override
-  public boolean canImport(TCredentials credentials, String tableName, String importDir,
+  public boolean canImport(TCredentials credentials, String tableName, Set<String> importDirs,
       NamespaceId namespaceId) throws ThriftSecurityException {
 
     try {
-      boolean result = super.canImport(credentials, tableName, importDir, namespaceId);
-      audit(credentials, result, CAN_IMPORT_AUDIT_TEMPLATE, tableName, importDir);
+      boolean result = super.canImport(credentials, tableName, importDirs, namespaceId);
+      audit(credentials, result, CAN_IMPORT_AUDIT_TEMPLATE, tableName, importDirs);
       return result;
     } catch (ThriftSecurityException ex) {
-      audit(credentials, ex, CAN_IMPORT_AUDIT_TEMPLATE, tableName, importDir);
+      audit(credentials, ex, CAN_IMPORT_AUDIT_TEMPLATE, tableName, importDirs);
       throw ex;
     }
   }
 
   public static final String CAN_EXPORT_AUDIT_TEMPLATE =
-      "action: export;" + " targetTable: %s; dataDir: %s;";
+      "action: export; targetTable: %s; dataDir: %s;";
 
   @Override
   public boolean canExport(TCredentials credentials, TableId tableId, String tableName,
@@ -612,7 +603,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String GRANT_SYSTEM_PERMISSION_AUDIT_TEMPLATE =
-      "action:" + " grantSystemPermission; permission: %s; targetUser: %s;";
+      "action: grantSystemPermission; permission: %s; targetUser: %s;";
 
   @Override
   public void grantSystemPermission(TCredentials credentials, String user,
@@ -627,7 +618,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String GRANT_TABLE_PERMISSION_AUDIT_TEMPLATE =
-      "action:" + " grantTablePermission; permission: %s; targetTable: %s; targetUser: %s;";
+      "action: grantTablePermission; permission: %s; targetTable: %s; targetUser: %s;";
 
   @Override
   public void grantTablePermission(TCredentials credentials, String user, TableId tableId,
@@ -643,7 +634,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String REVOKE_SYSTEM_PERMISSION_AUDIT_TEMPLATE =
-      "action:" + " revokeSystemPermission; permission: %s; targetUser: %s;";
+      "action: revokeSystemPermission; permission: %s; targetUser: %s;";
 
   @Override
   public void revokeSystemPermission(TCredentials credentials, String user,
@@ -659,7 +650,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String REVOKE_TABLE_PERMISSION_AUDIT_TEMPLATE =
-      "action:" + " revokeTablePermission; permission: %s; targetTable: %s; targetUser: %s;";
+      "action: revokeTablePermission; permission: %s; targetTable: %s; targetUser: %s;";
 
   @Override
   public void revokeTablePermission(TCredentials credentials, String user, TableId tableId,
@@ -675,7 +666,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String HAS_SYSTEM_PERMISSION_AUDIT_TEMPLATE =
-      "action:" + " hasSystemPermission; permission: %s; targetUser: %s;";
+      "action: hasSystemPermission; permission: %s; targetUser: %s;";
 
   @Override
   public boolean hasSystemPermission(TCredentials credentials, String user,
@@ -691,7 +682,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_ONLINE_OFFLINE_TABLE_AUDIT_TEMPLATE =
-      "action:" + " %s; targetTable: %s;";
+      "action: %s; targetTable: %s:%s";
 
   @Override
   public boolean canOnlineOfflineTable(TCredentials credentials, TableId tableId, FateOperation op,
@@ -715,7 +706,7 @@ public class AuditedSecurityOperation extends SecurityOperation {
   }
 
   public static final String CAN_MERGE_TABLE_AUDIT_TEMPLATE =
-      "action:" + " mergeTable; targetTable: %s; targetNamespace: %s;";
+      "action: mergeTable; targetTable: %s; targetNamespace: %s;";
 
   @Override
   public boolean canMerge(TCredentials c, TableId tableId, NamespaceId namespaceId)
