@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.security;
 
@@ -22,6 +24,7 @@ import java.nio.ByteBuffer;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.function.Supplier;
 
 import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.client.AccumuloSecurityException;
@@ -39,16 +42,15 @@ import org.apache.accumulo.core.dataImpl.thrift.IterInfo;
 import org.apache.accumulo.core.dataImpl.thrift.TColumn;
 import org.apache.accumulo.core.dataImpl.thrift.TKeyExtent;
 import org.apache.accumulo.core.dataImpl.thrift.TRange;
-import org.apache.accumulo.core.master.thrift.FateOperation;
+import org.apache.accumulo.core.fate.zookeeper.ZooCache;
+import org.apache.accumulo.core.manager.thrift.FateOperation;
 import org.apache.accumulo.core.metadata.MetadataTable;
 import org.apache.accumulo.core.metadata.RootTable;
-import org.apache.accumulo.core.replication.ReplicationTable;
 import org.apache.accumulo.core.security.Authorizations;
 import org.apache.accumulo.core.security.NamespacePermission;
 import org.apache.accumulo.core.security.SystemPermission;
 import org.apache.accumulo.core.security.TablePermission;
 import org.apache.accumulo.core.securityImpl.thrift.TCredentials;
-import org.apache.accumulo.fate.zookeeper.ZooCache;
 import org.apache.accumulo.server.ServerContext;
 import org.apache.accumulo.server.security.handler.Authenticator;
 import org.apache.accumulo.server.security.handler.Authorizor;
@@ -61,47 +63,39 @@ import org.apache.hadoop.io.Text;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.google.common.base.Suppliers;
+
 /**
  * Utility class for performing various security operations with the appropriate checks
  */
 public class SecurityOperation {
   private static final Logger log = LoggerFactory.getLogger(SecurityOperation.class);
 
-  protected Authorizor authorizor;
-  protected Authenticator authenticator;
-  protected PermissionHandler permHandle;
-  protected boolean isKerberos;
-  private static String rootUserName = null;
+  private final Authorizor authorizor;
+  private final Authenticator authenticator;
+  private final PermissionHandler permHandle;
+  private final boolean isKerberos;
+  private final Supplier<String> rootUserName;
   private final ZooCache zooCache;
-  private final String ZKUserPath;
+  private final String zkUserPath;
 
   protected final ServerContext context;
 
-  static SecurityOperation instance;
-
-  public static synchronized SecurityOperation getInstance(ServerContext context) {
-    if (instance == null) {
-      instance = new SecurityOperation(context, getAuthorizor(context), getAuthenticator(context),
-          getPermHandler(context));
-    }
-    return instance;
-  }
-
-  protected static Authorizor getAuthorizor(ServerContext context) {
+  public static Authorizor getAuthorizor(ServerContext context) {
     Authorizor toRet = Property.createInstanceFromPropertyName(context.getConfiguration(),
         Property.INSTANCE_SECURITY_AUTHORIZOR, Authorizor.class, new ZKAuthorizor());
     toRet.initialize(context);
     return toRet;
   }
 
-  protected static Authenticator getAuthenticator(ServerContext context) {
+  public static Authenticator getAuthenticator(ServerContext context) {
     Authenticator toRet = Property.createInstanceFromPropertyName(context.getConfiguration(),
         Property.INSTANCE_SECURITY_AUTHENTICATOR, Authenticator.class, new ZKAuthenticator());
     toRet.initialize(context);
     return toRet;
   }
 
-  protected static PermissionHandler getPermHandler(ServerContext context) {
+  public static PermissionHandler getPermHandler(ServerContext context) {
     PermissionHandler toRet = Property.createInstanceFromPropertyName(context.getConfiguration(),
         Property.INSTANCE_SECURITY_PERMISSION_HANDLER, PermissionHandler.class,
         new ZKPermHandler());
@@ -109,15 +103,12 @@ public class SecurityOperation {
     return toRet;
   }
 
-  protected SecurityOperation(ServerContext context) {
-    this.context = context;
-    ZKUserPath = Constants.ZROOT + "/" + context.getInstanceID() + "/users";
-    zooCache = new ZooCache(context.getZooReaderWriter(), null);
-  }
-
-  public SecurityOperation(ServerContext context, Authorizor author, Authenticator authent,
+  protected SecurityOperation(ServerContext context, Authorizor author, Authenticator authent,
       PermissionHandler pm) {
-    this(context);
+    this.context = context;
+    zkUserPath = Constants.ZROOT + "/" + context.getInstanceID() + "/users";
+    zooCache = new ZooCache(context.getZooReader(), null);
+    rootUserName = Suppliers.memoize(() -> new String(zooCache.get(zkUserPath), UTF_8));
     authorizor = author;
     authenticator = authent;
     permHandle = pm;
@@ -126,7 +117,7 @@ public class SecurityOperation {
         || !authenticator.validSecurityHandlers()
         || !permHandle.validSecurityHandlers(authent, author))
       throw new RuntimeException(authorizor + ", " + authenticator + ", and " + pm
-          + " do not play nice with eachother. Please choose authentication and"
+          + " do not play nice with each other. Please choose authentication and"
           + " authorization mechanisms that are compatible with one another.");
 
     isKerberos = KerberosAuthenticator.class.isAssignableFrom(authenticator.getClass());
@@ -150,10 +141,8 @@ public class SecurityOperation {
     }
   }
 
-  public synchronized String getRootUsername() {
-    if (rootUserName == null)
-      rootUserName = new String(zooCache.get(ZKUserPath), UTF_8);
-    return rootUserName;
+  private String getRootUsername() {
+    return rootUserName.get();
   }
 
   public boolean isSystemUser(TCredentials credentials) {
@@ -162,7 +151,7 @@ public class SecurityOperation {
   }
 
   protected void authenticate(TCredentials credentials) throws ThriftSecurityException {
-    if (!credentials.getInstanceId().equals(context.getInstanceID()))
+    if (!credentials.getInstanceId().equals(context.getInstanceID().canonical()))
       throw new ThriftSecurityException(credentials.getPrincipal(),
           SecurityErrorCode.INVALID_INSTANCEID);
 
@@ -179,7 +168,7 @@ public class SecurityOperation {
               SecurityErrorCode.BAD_CREDENTIALS);
         }
       } else {
-        if (!(context.getCredentials().equals(creds))) {
+        if (!context.getCredentials().equals(creds)) {
           log.debug("Provided credentials did not match server's expected"
               + " credentials. Expected {} but got {}", context.getCredentials(), creds);
           throw new ThriftSecurityException(creds.getPrincipal(),
@@ -225,19 +214,18 @@ public class SecurityOperation {
     }
   }
 
-  public boolean canAskAboutUser(TCredentials credentials, String user)
-      throws ThriftSecurityException {
-    // Authentication done in canPerformSystemActions
-    if (!(canPerformSystemActions(credentials) || credentials.getPrincipal().equals(user)))
-      throw new ThriftSecurityException(credentials.getPrincipal(),
-          SecurityErrorCode.PERMISSION_DENIED);
-    return true;
-  }
-
   public boolean authenticateUser(TCredentials credentials, TCredentials toAuth)
       throws ThriftSecurityException {
-    canAskAboutUser(credentials, toAuth.getPrincipal());
-    // User is already authenticated from canAskAboutUser
+    authenticate(credentials); // authenticate the current user first
+
+    // if the user to authenticate is not the current user, and the current user lacks
+    // the SYSTEM permission, then deny the request
+    if (!credentials.getPrincipal().equals(toAuth.getPrincipal())
+        && !hasSystemPermission(credentials, SystemPermission.SYSTEM, false))
+      throw new ThriftSecurityException(credentials.getPrincipal(),
+          SecurityErrorCode.PERMISSION_DENIED);
+
+    // the user is already authenticated above if the credentials to authenticate are the same
     if (credentials.equals(toAuth))
       return true;
     try {
@@ -362,12 +350,15 @@ public class SecurityOperation {
    *
    * @return true if a user exists and has permission; false otherwise
    */
-  protected boolean _hasTablePermission(String user, TableId table, TablePermission permission,
+  private boolean _hasTablePermission(String user, TableId table, TablePermission permission,
       boolean useCached) throws ThriftSecurityException {
     targetUserExists(user);
 
+    @SuppressWarnings("deprecation")
+    TableId replicationTableId = org.apache.accumulo.core.replication.ReplicationTable.ID;
+
     if ((table.equals(MetadataTable.ID) || table.equals(RootTable.ID)
-        || table.equals(ReplicationTable.ID)) && permission.equals(TablePermission.READ))
+        || table.equals(replicationTableId)) && permission.equals(TablePermission.READ))
       return true;
 
     try {
@@ -385,7 +376,7 @@ public class SecurityOperation {
    *
    * @return true if a user exists and has permission; false otherwise
    */
-  protected boolean _hasNamespacePermission(String user, NamespaceId namespace,
+  private boolean _hasNamespacePermission(String user, NamespaceId namespace,
       NamespacePermission permission, boolean useCached) throws ThriftSecurityException {
     if (permission == null)
       return false;
@@ -682,7 +673,7 @@ public class SecurityOperation {
     }
   }
 
-  protected void _createUser(TCredentials credentials, Credentials newUser)
+  private void _createUser(TCredentials credentials, Credentials newUser)
       throws ThriftSecurityException {
     try {
       AuthenticationToken token = newUser.getToken();
@@ -886,7 +877,7 @@ public class SecurityOperation {
     return hasTablePermission(credentials, tableId, namespaceId, TablePermission.READ, false);
   }
 
-  public boolean canImport(TCredentials credentials, String tableName, String importDir,
+  public boolean canImport(TCredentials credentials, String tableName, Set<String> importDir,
       NamespaceId namespaceId) throws ThriftSecurityException {
     authenticate(credentials);
     return hasSystemPermissionWithNamespaceId(credentials, SystemPermission.CREATE_TABLE,
@@ -930,4 +921,11 @@ public class SecurityOperation {
     return hasTablePermission(credentials, tableId, namespaceId, TablePermission.GET_SUMMARIES,
         false);
   }
+
+  public boolean validateStoredUserCreditentials() {
+    if (authenticator instanceof ZKAuthenticator) {
+      return !((ZKAuthenticator) authenticator).hasOutdatedHashes();
+    }
+    return true;
+  }
 }
