@@ -7,15 +7,15 @@
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
-
 package org.apache.accumulo.server.security.delegation;
 
 import static com.google.common.base.Preconditions.checkArgument;
@@ -33,6 +33,8 @@ import org.apache.accumulo.core.client.AccumuloException;
 import org.apache.accumulo.core.client.admin.DelegationTokenConfig;
 import org.apache.accumulo.core.clientImpl.AuthenticationTokenIdentifier;
 import org.apache.accumulo.core.clientImpl.DelegationTokenImpl;
+import org.apache.accumulo.core.data.InstanceId;
+import org.apache.accumulo.core.securityImpl.thrift.TAuthenticationTokenIdentifier;
 import org.apache.hadoop.io.Text;
 import org.apache.hadoop.security.token.SecretManager;
 import org.apache.hadoop.security.token.Token;
@@ -47,8 +49,8 @@ import com.google.common.collect.Maps;
  * Manages an internal list of secret keys used to sign new authentication tokens as they are
  * generated, and to validate existing tokens used for authentication.
  *
- * Each TabletServer, in addition to the Master, has an instance of this {@link SecretManager} so
- * that each can authenticate requests from clients presenting delegation tokens. The Master will
+ * Each TabletServer, in addition to the Manager, has an instance of this {@link SecretManager} so
+ * that each can authenticate requests from clients presenting delegation tokens. The Manager will
  * also run an instance of {@link AuthenticationTokenKeyManager} which handles generation of new
  * keys and removal of old keys. That class will call the methods here to ensure the in-memory cache
  * is consistent with what is advertised in ZooKeeper.
@@ -57,7 +59,7 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
 
   private static final Logger log = LoggerFactory.getLogger(AuthenticationTokenSecretManager.class);
 
-  private final String instanceID;
+  private final InstanceId instanceID;
   private final long tokenMaxLifetime;
   private final ConcurrentHashMap<Integer,AuthenticationKey> allKeys = new ConcurrentHashMap<>();
   private AuthenticationKey currentKey;
@@ -70,31 +72,18 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
    * @param tokenMaxLifetime
    *          Maximum age (in milliseconds) before a token expires and is no longer valid
    */
-  public AuthenticationTokenSecretManager(String instanceID, long tokenMaxLifetime) {
+  public AuthenticationTokenSecretManager(InstanceId instanceID, long tokenMaxLifetime) {
     requireNonNull(instanceID);
     checkArgument(tokenMaxLifetime > 0, "Max lifetime must be positive");
     this.instanceID = instanceID;
     this.tokenMaxLifetime = tokenMaxLifetime;
   }
 
-  @Override
-  protected byte[] createPassword(AuthenticationTokenIdentifier identifier) {
-    DelegationTokenConfig cfg = identifier.getConfig();
-
+  private byte[] createPassword(AuthenticationTokenIdentifier identifier,
+      DelegationTokenConfig cfg) {
     long now = System.currentTimeMillis();
-    final AuthenticationKey secretKey;
-    synchronized (this) {
-      secretKey = currentKey;
-    }
-    identifier.setKeyId(secretKey.getKeyId());
     identifier.setIssueDate(now);
-    long expiration = now + tokenMaxLifetime;
-    // Catch overflow
-    if (expiration < now) {
-      expiration = Long.MAX_VALUE;
-    }
-    identifier.setExpirationDate(expiration);
-
+    identifier.setExpirationDate(calculateExpirationDate());
     // Limit the lifetime if the user requests it
     if (cfg != null) {
       long requestedLifetime = cfg.getTokenLifetime(TimeUnit.MILLISECONDS);
@@ -113,8 +102,32 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
         identifier.setExpirationDate(requestedExpirationDate);
       }
     }
+    return createPassword(identifier);
+  }
 
+  private long calculateExpirationDate() {
+    long now = System.currentTimeMillis();
+    long expiration = now + tokenMaxLifetime;
+    // Catch overflow
+    if (expiration < now) {
+      expiration = Long.MAX_VALUE;
+    }
+    return expiration;
+  }
+
+  @Override
+  protected byte[] createPassword(AuthenticationTokenIdentifier identifier) {
+    final AuthenticationKey secretKey;
+    synchronized (this) {
+      secretKey = currentKey;
+    }
+    identifier.setKeyId(secretKey.getKeyId());
     identifier.setInstanceId(instanceID);
+
+    if (!identifier.isSetIssueDate())
+      identifier.setIssueDate(System.currentTimeMillis());
+    if (!identifier.isSetExpirationDate())
+      identifier.setExpirationDate(calculateExpirationDate());
     return createPassword(identifier.getBytes(), secretKey.getKey());
   }
 
@@ -127,18 +140,18 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
     if (identifier.getIssueDate() > now) {
       throw new InvalidToken("Token issued in the future");
     }
-    AuthenticationKey masterKey = allKeys.get(identifier.getKeyId());
-    if (masterKey == null) {
-      throw new InvalidToken("Unknown master key for token (id=" + identifier.getKeyId() + ")");
+    AuthenticationKey managerKey = allKeys.get(identifier.getKeyId());
+    if (managerKey == null) {
+      throw new InvalidToken("Unknown manager key for token (id=" + identifier.getKeyId() + ")");
     }
     // regenerate the password
-    return createPassword(identifier.getBytes(), masterKey.getKey());
+    return createPassword(identifier.getBytes(), managerKey.getKey());
   }
 
   @Override
   public AuthenticationTokenIdentifier createIdentifier() {
     // Return our TokenIdentifier implementation
-    return new AuthenticationTokenIdentifier();
+    return new AuthenticationTokenIdentifier(new TAuthenticationTokenIdentifier());
   }
 
   /**
@@ -155,7 +168,7 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
     requireNonNull(username);
     requireNonNull(cfg);
 
-    final AuthenticationTokenIdentifier id = new AuthenticationTokenIdentifier(username, cfg);
+    var id = new AuthenticationTokenIdentifier(new TAuthenticationTokenIdentifier(username));
 
     final StringBuilder svcName = new StringBuilder(DelegationTokenImpl.SERVICE_NAME);
     if (id.getInstanceId() != null) {
@@ -165,7 +178,7 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
     // before serializing the identifier
     byte[] password;
     try {
-      password = createPassword(id);
+      password = createPassword(id, cfg);
     } catch (RuntimeException e) {
       throw new AccumuloException(e.getMessage());
     }
@@ -204,7 +217,7 @@ public class AuthenticationTokenSecretManager extends SecretManager<Authenticati
   synchronized boolean removeKey(Integer keyId) {
     requireNonNull(keyId);
 
-    log.debug("Removing AuthenticatioKey with keyId {}", keyId);
+    log.debug("Removing AuthenticationKey with keyId {}", keyId);
 
     return allKeys.remove(keyId) != null;
   }
