@@ -1,18 +1,20 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- *     http://www.apache.org/licenses/LICENSE-2.0
+ *   https://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.accumulo.server.tables;
 
@@ -22,26 +24,25 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Map;
-import java.util.Map.Entry;
 import java.util.Set;
 
 import org.apache.accumulo.core.Constants;
 import org.apache.accumulo.core.client.NamespaceNotFoundException;
-import org.apache.accumulo.core.clientImpl.Tables;
+import org.apache.accumulo.core.data.InstanceId;
 import org.apache.accumulo.core.data.NamespaceId;
 import org.apache.accumulo.core.data.TableId;
-import org.apache.accumulo.core.master.state.tables.TableState;
+import org.apache.accumulo.core.fate.zookeeper.ZooCache;
+import org.apache.accumulo.core.fate.zookeeper.ZooReaderWriter;
+import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeExistsPolicy;
+import org.apache.accumulo.core.fate.zookeeper.ZooUtil.NodeMissingPolicy;
+import org.apache.accumulo.core.manager.state.tables.TableState;
 import org.apache.accumulo.core.util.Pair;
-import org.apache.accumulo.fate.zookeeper.IZooReaderWriter;
-import org.apache.accumulo.fate.zookeeper.IZooReaderWriter.Mutator;
-import org.apache.accumulo.fate.zookeeper.ZooCache;
-import org.apache.accumulo.fate.zookeeper.ZooReaderWriter;
-import org.apache.accumulo.fate.zookeeper.ZooUtil;
-import org.apache.accumulo.fate.zookeeper.ZooUtil.NodeExistsPolicy;
-import org.apache.accumulo.fate.zookeeper.ZooUtil.NodeMissingPolicy;
+import org.apache.accumulo.core.util.tables.TableNameUtil;
 import org.apache.accumulo.server.ServerContext;
-import org.apache.accumulo.server.util.TablePropUtil;
-import org.apache.commons.lang3.StringUtils;
+import org.apache.accumulo.server.conf.store.NamespacePropKey;
+import org.apache.accumulo.server.conf.store.PropStore;
+import org.apache.accumulo.server.conf.store.TablePropKey;
+import org.apache.accumulo.server.util.PropUtil;
 import org.apache.zookeeper.KeeperException;
 import org.apache.zookeeper.WatchedEvent;
 import org.apache.zookeeper.Watcher;
@@ -61,33 +62,43 @@ public class TableManager {
 
   private final ServerContext context;
   private final String zkRoot;
-  private final String instanceID;
+  private final InstanceId instanceID;
   private final ZooReaderWriter zoo;
-  private ZooCache zooStateCache;
+  private final ZooCache zooStateCache;
 
-  public static void prepareNewNamespaceState(IZooReaderWriter zoo, String instanceId,
-      NamespaceId namespaceId, String namespace, NodeExistsPolicy existsPolicy)
-      throws KeeperException, InterruptedException {
+  public static void prepareNewNamespaceState(ZooReaderWriter zoo, final PropStore propStore,
+      InstanceId instanceId, NamespaceId namespaceId, String namespace,
+      NodeExistsPolicy existsPolicy) throws KeeperException, InterruptedException {
     log.debug("Creating ZooKeeper entries for new namespace {} (ID: {})", namespace, namespaceId);
     String zPath = Constants.ZROOT + "/" + instanceId + Constants.ZNAMESPACES + "/" + namespaceId;
 
     zoo.putPersistentData(zPath, new byte[0], existsPolicy);
     zoo.putPersistentData(zPath + Constants.ZNAMESPACE_NAME, namespace.getBytes(UTF_8),
         existsPolicy);
-    zoo.putPersistentData(zPath + Constants.ZNAMESPACE_CONF, new byte[0], existsPolicy);
+    var propKey = NamespacePropKey.of(instanceId, namespaceId);
+    if (!propStore.exists(propKey)) {
+      propStore.create(propKey, Map.of());
+    }
   }
 
-  public static void prepareNewTableState(IZooReaderWriter zoo, String instanceId, TableId tableId,
-      NamespaceId namespaceId, String tableName, TableState state, NodeExistsPolicy existsPolicy)
+  public static void prepareNewNamespaceState(final ServerContext context, NamespaceId namespaceId,
+      String namespace, NodeExistsPolicy existsPolicy)
+      throws KeeperException, InterruptedException {
+    prepareNewNamespaceState(context.getZooReaderWriter(), context.getPropStore(),
+        context.getInstanceID(), namespaceId, namespace, existsPolicy);
+  }
+
+  public static void prepareNewTableState(ZooReaderWriter zoo, PropStore propStore,
+      InstanceId instanceId, TableId tableId, NamespaceId namespaceId, String tableName,
+      TableState state, NodeExistsPolicy existsPolicy)
       throws KeeperException, InterruptedException {
     // state gets created last
     log.debug("Creating ZooKeeper entries for new table {} (ID: {}) in namespace (ID: {})",
         tableName, tableId, namespaceId);
-    Pair<String,String> qualifiedTableName = Tables.qualify(tableName);
+    Pair<String,String> qualifiedTableName = TableNameUtil.qualify(tableName);
     tableName = qualifiedTableName.getSecond();
     String zTablePath = Constants.ZROOT + "/" + instanceId + Constants.ZTABLES + "/" + tableId;
     zoo.putPersistentData(zTablePath, new byte[0], existsPolicy);
-    zoo.putPersistentData(zTablePath + Constants.ZTABLE_CONF, new byte[0], existsPolicy);
     zoo.putPersistentData(zTablePath + Constants.ZTABLE_NAMESPACE,
         namespaceId.canonical().getBytes(UTF_8), existsPolicy);
     zoo.putPersistentData(zTablePath + Constants.ZTABLE_NAME, tableName.getBytes(UTF_8),
@@ -97,6 +108,17 @@ public class TableManager {
     zoo.putPersistentData(zTablePath + Constants.ZTABLE_COMPACT_CANCEL_ID, ZERO_BYTE, existsPolicy);
     zoo.putPersistentData(zTablePath + Constants.ZTABLE_STATE, state.name().getBytes(UTF_8),
         existsPolicy);
+    var propKey = TablePropKey.of(instanceId, tableId);
+    if (!propStore.exists(propKey)) {
+      propStore.create(propKey, Map.of());
+    }
+  }
+
+  public static void prepareNewTableState(final ServerContext context, TableId tableId,
+      NamespaceId namespaceId, String tableName, TableState state, NodeExistsPolicy existsPolicy)
+      throws KeeperException, InterruptedException {
+    prepareNewTableState(context.getZooReaderWriter(), context.getPropStore(),
+        context.getInstanceID(), tableId, namespaceId, tableName, state, existsPolicy);
   }
 
   public TableManager(ServerContext context) {
@@ -112,78 +134,44 @@ public class TableManager {
     return tableStateCache.get(tableId);
   }
 
-  public static class IllegalTableTransitionException extends Exception {
-    private static final long serialVersionUID = 1L;
-
-    final TableState oldState;
-    final TableState newState;
-    final String message;
-
-    public IllegalTableTransitionException(TableState oldState, TableState newState) {
-      this(oldState, newState, "");
-    }
-
-    public IllegalTableTransitionException(TableState oldState, TableState newState,
-        String message) {
-      this.oldState = oldState;
-      this.newState = newState;
-
-      if (StringUtils.isNotEmpty(message))
-        this.message = message;
-      else {
-        this.message = "Error transitioning from " + oldState + " state to " + newState + " state";
-      }
-    }
-
-    @Override
-    public String getMessage() {
-      return message;
-    }
-
-  }
-
   public synchronized void transitionTableState(final TableId tableId, final TableState newState) {
     Preconditions.checkArgument(newState != TableState.UNKNOWN);
     String statePath = zkRoot + Constants.ZTABLES + "/" + tableId + Constants.ZTABLE_STATE;
 
     try {
-      zoo.mutate(statePath, newState.name().getBytes(UTF_8), ZooUtil.PUBLIC, new Mutator() {
-        @Override
-        public byte[] mutate(byte[] oldData) throws Exception {
-          TableState oldState = TableState.UNKNOWN;
-          if (oldData != null)
-            oldState = TableState.valueOf(new String(oldData, UTF_8));
+      zoo.mutateOrCreate(statePath, newState.name().getBytes(UTF_8), oldData -> {
+        TableState oldState = TableState.UNKNOWN;
+        if (oldData != null)
+          oldState = TableState.valueOf(new String(oldData, UTF_8));
 
-          // this check makes the transition operation idempotent
-          if (oldState == newState)
-            return null; // already at desired state, so nothing to do
+        // this check makes the transition operation idempotent
+        if (oldState == newState)
+          return null; // already at desired state, so nothing to do
 
-          boolean transition = true;
-          // +--------+
-          // v |
-          // NEW -> (ONLINE|OFFLINE)+--- DELETING
-          switch (oldState) {
-            case NEW:
-              transition = (newState == TableState.OFFLINE || newState == TableState.ONLINE);
-              break;
-            case ONLINE: // fall-through intended
-            case UNKNOWN:// fall through intended
-            case OFFLINE:
-              transition = (newState != TableState.NEW);
-              break;
-            case DELETING:
-              // Can't transition to any state from DELETING
-              transition = false;
-              break;
-          }
-          if (!transition)
-            throw new IllegalTableTransitionException(oldState, newState);
-          log.debug("Transitioning state for table {} from {} to {}", tableId, oldState, newState);
-          return newState.name().getBytes(UTF_8);
+        boolean transition = true;
+        // +--------+
+        // v |
+        // NEW -> (ONLINE|OFFLINE)+--- DELETING
+        switch (oldState) {
+          case NEW:
+            transition = (newState == TableState.OFFLINE || newState == TableState.ONLINE);
+            break;
+          case ONLINE: // fall-through intended
+          case UNKNOWN:// fall through intended
+          case OFFLINE:
+            transition = (newState != TableState.NEW);
+            break;
+          case DELETING:
+            // Can't transition to any state from DELETING
+            transition = false;
+            break;
         }
+        if (!transition)
+          throw new IllegalTableTransitionException(oldState, newState);
+        log.debug("Transitioning state for table {} from {} to {}", tableId, oldState, newState);
+        return newState.name().getBytes(UTF_8);
       });
     } catch (Exception e) {
-      // ACCUMULO-3651 Changed level to error and added FATAL to message for slf4j compatibility
       log.error("FATAL Failed to transition table to state {}", newState);
       throw new RuntimeException(e);
     }
@@ -216,32 +204,27 @@ public class TableManager {
     }
   }
 
-  public void addTable(TableId tableId, NamespaceId namespaceId, String tableName,
-      NodeExistsPolicy existsPolicy)
+  public void addTable(TableId tableId, NamespaceId namespaceId, String tableName)
       throws KeeperException, InterruptedException, NamespaceNotFoundException {
-    prepareNewTableState(zoo, instanceID, tableId, namespaceId, tableName, TableState.NEW,
-        existsPolicy);
+    prepareNewTableState(zoo, context.getPropStore(), instanceID, tableId, namespaceId, tableName,
+        TableState.NEW, NodeExistsPolicy.OVERWRITE);
     updateTableStateCache(tableId);
   }
 
   public void cloneTable(TableId srcTableId, TableId tableId, String tableName,
-      NamespaceId namespaceId, Map<String,String> propertiesToSet, Set<String> propertiesToExclude,
-      NodeExistsPolicy existsPolicy) throws KeeperException, InterruptedException {
-    prepareNewTableState(zoo, instanceID, tableId, namespaceId, tableName, TableState.NEW,
-        existsPolicy);
+      NamespaceId namespaceId, Map<String,String> propertiesToSet, Set<String> propertiesToExclude)
+      throws KeeperException, InterruptedException {
+    prepareNewTableState(zoo, context.getPropStore(), instanceID, tableId, namespaceId, tableName,
+        TableState.NEW, NodeExistsPolicy.OVERWRITE);
 
     String srcTablePath = Constants.ZROOT + "/" + instanceID + Constants.ZTABLES + "/" + srcTableId
-        + Constants.ZTABLE_CONF;
-    String newTablePath = Constants.ZROOT + "/" + instanceID + Constants.ZTABLES + "/" + tableId
-        + Constants.ZTABLE_CONF;
-    zoo.recursiveCopyPersistent(srcTablePath, newTablePath, NodeExistsPolicy.OVERWRITE);
+        + Constants.ZCONFIG;
+    String newTablePath =
+        Constants.ZROOT + "/" + instanceID + Constants.ZTABLES + "/" + tableId + Constants.ZCONFIG;
+    zoo.recursiveCopyPersistentOverwrite(srcTablePath, newTablePath);
 
-    for (Entry<String,String> entry : propertiesToSet.entrySet())
-      TablePropUtil.setTableProperty(context, tableId, entry.getKey(), entry.getValue());
-
-    for (String prop : propertiesToExclude)
-      zoo.recursiveDelete(Constants.ZROOT + "/" + instanceID + Constants.ZTABLES + "/" + tableId
-          + Constants.ZTABLE_CONF + "/" + prop, NodeMissingPolicy.SKIP);
+    PropUtil.setProperties(context, TablePropKey.of(context, tableId), propertiesToSet);
+    PropUtil.removeProperties(context, TablePropKey.of(context, tableId), propertiesToExclude);
 
     updateTableStateCache(tableId);
   }
@@ -294,7 +277,7 @@ public class TableManager {
           if (zPath != null && zPath.equals(tablesPrefix)) {
             updateTableStateCache();
           } else {
-            log.warn("Unexpected path {}", zPath);
+            log.warn("Unexpected path {} in {}", zPath, event);
           }
           break;
         case NodeCreated:
@@ -310,15 +293,14 @@ public class TableManager {
         case NodeDeleted:
           if (zPath != null && tableId != null
               && (zPath.equals(tablesPrefix + "/" + tableId + Constants.ZTABLE_STATE)
-                  || zPath.equals(tablesPrefix + "/" + tableId + Constants.ZTABLE_CONF)
+                  || zPath.equals(tablesPrefix + "/" + tableId + Constants.ZCONFIG)
                   || zPath.equals(tablesPrefix + "/" + tableId + Constants.ZTABLE_NAME)))
             tableStateCache.remove(tableId);
           break;
         case None:
           switch (event.getState()) {
             case Expired:
-              if (log.isTraceEnabled())
-                log.trace("Session expired {}", event);
+              log.trace("Session expired; {}", event);
               synchronized (observers) {
                 for (TableObserver to : observers)
                   to.sessionExpired();
@@ -326,12 +308,11 @@ public class TableManager {
               break;
             case SyncConnected:
             default:
-              if (log.isTraceEnabled())
-                log.trace("Ignored {}", event);
+              log.trace("Ignored {}", event);
           }
           break;
         default:
-          log.warn("Unandled {}", event);
+          log.warn("Unhandled {}", event);
       }
     }
   }
